@@ -185,7 +185,9 @@ define('io.ox/backbone/mini-views/datepicker', [
                     };
 
                     self.nodes.timeField.combobox(comboboxHours).addClass('');
-                    self.nodes.timeField.on('change', _.bind(self.updateModel, self));
+                    self.nodes.timeField.on('change', _.bind(self.updateModel, self)).on('click', function () {
+                        self.trigger('click:time');
+                    });
                     self.toggleTimeInput(!self.isFullTime());
 
                     def.resolve();
