@@ -90,8 +90,6 @@ define('io.ox/backbone/mini-views/help', ['gettext!io.ox/core'], function (gt) {
                 .append(this.options.content)
                 .attr({
                     href: '#',
-                    role: 'button',
-                    tabindex: this.options.tabindex,
                     target: '_blank',
                     'aria-label': gt('Online help')
                 });
