@@ -279,6 +279,10 @@ define('io.ox/calendar/main', [
             };
 
             app.grid = new VGrid(app.left, gridOptions);
+            app.left.attr({
+                role: 'navigation',
+                'aria-label': 'Appointment list'
+            });
 
             app.getGrid = function () {
                 return this.grid;
@@ -297,18 +301,26 @@ define('io.ox/calendar/main', [
          */
         'folder-view': function (app) {
 
-            // tree view
-            var tree = new TreeView({ app: app, contextmenu: true, flat: true, indent: false, module: 'calendar' });
-
-            // initialize folder view
-            FolderView.initialize({ app: app, tree: tree });
+            app.treeView = new TreeView({ app: app, contextmenu: true, flat: true, indent: false, module: 'calendar' });
+            FolderView.initialize({ app: app, tree: app.treeView });
             app.folderView.resize.enable();
+            app.folderView.tree.$el.attr('aria-label', gt('Calendars'));
         },
 
         'premium-area': function (app) {
-            commons.addPremiumFeatures(app, {
-                upsellId: 'folderview/calendar/bottom',
-                upsellRequires: 'caldav'
+
+            ext.point('io.ox/calendar/sidepanel').extend({
+                id: 'premium-area',
+                index: 10000,
+                draw: function () {
+                    this.append(
+                        commons.addPremiumFeatures(app, {
+                            append: false,
+                            upsellId: 'folderview/calendar/bottom',
+                            upsellRequires: 'caldav'
+                        })
+                    );
+                }
             });
         },
 
@@ -475,51 +487,18 @@ define('io.ox/calendar/main', [
         'change:layout': function (app) {
             app.props.on('change:layout', function (model, value) {
                 // no animations on desktop
-                ox.ui.Perspective.show(app, value, { disableAnimations: true });
+                ox.ui.Perspective.show(app, value, { disableAnimations: true }).done(function () {
+                    // specific flexbox/scrolling issue (see bugs 43799, 44938, 45501, 46950)
+                    $('#io-ox-windowmanager').scrollTop(0);
+                });
             });
         },
 
         /*
          * change to default folder on no permission or folder not found errors
          */
-        'no-permission': function (app) {
-            // use debounce, so errors from folder and app api are only handled once.
-            var handleError = _.debounce(function (error) {
-                // work with (error) and (event, error) arguments
-                if (error && !error.error) {
-                    if (arguments[1] && arguments[1].error) {
-                        error = arguments[1];
-                    } else {
-                        return;
-                    }
-                }
-                // only change if folder is currently displayed
-                if (error.error_params[0] && String(app.folder.get()) !== String(error.error_params[0])) {
-                    return;
-                }
-                require(['io.ox/core/yell'], function (yell) {
-                    yell(error);
-                    // try to load the default folder
-                    // guests do not have a default folder, so the first visible one is chosen
-                    app.folder.setDefault();
-                });
-            }, 300);
-
-            folderAPI.on('error:FLD-0008', handleError);
-            api.on('error:FLD-0008', handleError);
-            api.on('error:APP-0013', function (e, error) {
-                // check if folder is currently displayed
-                if (String(app.folder.get()) !== String(error.error_params[0])) {
-                    return;
-                }
-                // see if we can still access the folder, although we are not allowed to view the contents
-                // this is important because otherwise we would not be able to change permissions (because the view jumps to the default folder all the time)
-                folderAPI.get(app.folder.get(), { cache: false }).fail(function (error) {
-                    if (error.code === 'FLD-0003') {
-                        handleError(error);
-                    }
-                });
-            });
+        'folder-error': function (app) {
+            app.folder.handleErrors();
         },
 
         /*
@@ -623,6 +602,21 @@ define('io.ox/calendar/main', [
             };
         },
 
+        'sidepanel': function (app) {
+
+            ext.point('io.ox/calendar/sidepanel').extend({
+                id: 'tree',
+                index: 100,
+                draw: function (baton) {
+                    // add border & render tree and add to DOM
+                    this.addClass('border-right').append(baton.app.treeView.$el);
+                }
+            });
+
+            var node = app.getWindow().nodes.sidepanel;
+            ext.point('io.ox/calendar/sidepanel').invoke('draw', node, ext.Baton({ app: app }));
+        },
+
         'metrics': function (app) {
 
             function getFolderType(folder) {
@@ -801,6 +795,36 @@ define('io.ox/calendar/main', [
         }
     });
 
+    // set what to do if the app is started again
+    // this way we can react to given options, like for example a different folder
+    app.setResume(function (options) {
+        var ret = $.when();
+        // only consider folder option and persepective option
+        if (options) {
+            var defs = [],
+                appNode = this.getWindow();
+            appNode.busy();
+            if (options.folder && options.folder !== this.folder.get()) {
+                defs.push(this.folder.set(options.folder));
+            }
+            if (options.perspective && options.perspective !== app.props.get('layout')) {
+                var perspective = options.perspective;
+                if (_.device('smartphone') && _.indexOf(['week:workweek', 'week:week', 'calendar'], perspective) >= 0) {
+                    perspective = 'week:day';
+                } else if (perspective === 'calendar') {
+                    // corrupt data fix
+                    perspective = 'week:workweek';
+                }
+                defs.push(app.props.set('layout', perspective));
+            }
+            ret = $.when.apply(this, defs);
+            ret.always(function () {
+                appNode.idle();
+            });
+        }
+        return ret;
+    });
+
     return {
         getApp: app.getInstance
     };
