@@ -21,8 +21,9 @@ define('io.ox/calendar/month/perspective', [
     'io.ox/core/print',
     'io.ox/core/folder/api',
     'settings!io.ox/calendar',
-    'gettext!io.ox/calendar'
-], function (View, api, ext, dialogs, detailView, conflictView, print, folderAPI, settings, gt) {
+    'gettext!io.ox/calendar',
+    'less!io.ox/calendar/print-style'
+], function (View, api, ext, dialogs, detailView, conflictView, print, folderAPI, settings, gt, printStyle) {
 
     'use strict';
 
@@ -224,7 +225,7 @@ define('io.ox/calendar/month/perspective', [
             for (var i = 0; i < weeks; i++, curWeek.add(8, 'd').startOf('week')) {
                 var day = curWeek.valueOf(),
                     endDate = curWeek.clone().endOf('week'),
-                    monthDelimiter = curWeek.clone().endOf('month').isBefore(endDate.clone().add(1, 'd'));
+                    monthDelimiter = curWeek.clone().endOf('month').isSameOrBefore(endDate);
 
                 // add collection for week
                 self.collections[day] = new MonthAppointmentCollection([]);
@@ -417,7 +418,9 @@ define('io.ox/calendar/month/perspective', [
          */
         print: function () {
             var win, data = null,
-                folderID = this.folder.id || this.folder.folder;
+                folderID = this.folder.id || this.folder.folder,
+                styleNode = $('<style type="text/css">').text(printStyle);
+
             if (folderID && folderID !== 'virtual/all-my-appointments') {
                 data = { folder_id: folderID };
             }
@@ -426,6 +429,16 @@ define('io.ox/calendar/month/perspective', [
                 start: moment(this.current).utc(true).valueOf(),
                 end: moment(this.current).add(1, 'month').utc(true).valueOf()
             });
+
+            if (this.app.props.get('colorScheme') === 'custom') {
+                // apply custom colors
+                win.onload = function () {
+                    $(win.document.head).append(styleNode);
+                    $(win.document.body).addClass('print-view-custom-colors');
+                    win.onload = null;
+                };
+            }
+
             // firefox opens every window with about:blank, then loads the url. If we are to fast we will just print a blank page(see bug 33415)
             if (_.browser.firefox) {
                 var limit = 50,
@@ -433,10 +446,10 @@ define('io.ox/calendar/month/perspective', [
                     interval;
                 // onLoad does not work with firefox on mac, so ugly polling is used
                 interval = setInterval(function () {
-                    counter++;
-                    if (counter === limit || win.location.pathname === (ox.apiRoot + '/printCalendar')) {
-                        win.print();
+                    if (++counter === limit || win.location.pathname === (ox.apiRoot + '/printCalendar')) {
                         clearInterval(interval);
+                        // add another extra delay for firefox (see bug 48949)
+                        setTimeout(function () { win.print(); }, 300);
                     }
                 }, 100);
             } else {
@@ -464,8 +477,8 @@ define('io.ox/calendar/month/perspective', [
                 .addClass('month-view')
                 .empty()
                 .attr({
-                    'role': 'navigation',
-                    'aria-label': gt('Appointment list')
+                    'role': 'main',
+                    'aria-label': gt('Calendar Month View')
                 })
                 .append(this.scaffold = View.drawScaffold());
 
