@@ -37,15 +37,17 @@ define('io.ox/contacts/api', [
         },
         convertResponseToGregorian = function (response) {
             if (response.id) {
-                // single contact: convert birthdays with year 1 from julian to gregorian calendar
-                if (response.birthday && moment.utc(response.birthday).year() === 1) {
+                // single contact: convert birthdays with year 1 or earlier from julian to gregorian calendar
+                // year might be 0 if birthday is on 1.1 or 1.2. (year 1 - 2days difference)
+                if (response.birthday && moment.utc(response.birthday).year() <= 1) {
                     response.birthday = util.julianToGregorian(response.birthday);
                 }
                 return response;
             }
-            // array of contacts: convert birthdays with year 1 from julian to gregorian calendar
+            // array of contacts: convert birthdays with year 1 or earlier from julian to gregorian calendar
+            // year might be 0 if birthday is on 1.1 or 1.2. (year 1 - 2days difference)
             _(response).each(function (contact) {
-                if (contact.birthday && moment.utc(contact.birthday).year() === 1) {
+                if (contact.birthday && moment.utc(contact.birthday).year() <= 1) {
                     // birthday without year
                     contact.birthday = util.julianToGregorian(contact.birthday);
                 }
@@ -543,6 +545,14 @@ define('io.ox/contacts/api', [
         api.caches.get.clear();
     });
 
+    // refresh.all caused by import
+    api.on('refresh.all:import', function () {
+        api.caches.list.clear();
+        fetchCache.clear();
+        api.caches.get.clear();
+        api.trigger('import');
+    });
+
     /** @define {object} simple contact cache */
     var fetchCache = new cache.SimpleCache('contacts-fetching');
 
@@ -646,15 +656,6 @@ define('io.ox/contacts/api', [
         });
 
         function load(node, url, opt) {
-            function fail() {
-                node.css('background-image', 'url(' + fallback + ')').off('.lazyload');
-                node = url = opt = null;
-            }
-            function success() {
-                cachesURLs[url] = url;
-                node.css('background-image', 'url(' + url + ')').off('.lazyload');
-                node = url = opt = null;
-            }
             _.defer(function () {
                 // use lazyload?
                 opt.container = opt.container || _.first(node.closest('.scrollpane, .scrollable, .scrollpane-lazyload'));
@@ -662,7 +663,12 @@ define('io.ox/contacts/api', [
                     node.css('background-image', 'url(' + fallback + ')')
                         .attr('data-original', url)
                         .on('load.lazyload error.lazyload', function (e, image) {
-                            (image.width === 1 ? fail : success)();
+                            if (image.width === 1) url = fallback;
+                            else cachesURLs[url] = url;
+                            node.attr('data-original', url)
+                                .css('background-image', 'url(' + url + ')');
+                            node = url = opt = null;
+                            $(this).off('.lazyload');
                         })
                         .lazyload();
                 } else {
@@ -723,7 +729,10 @@ define('io.ox/contacts/api', [
                     // scale
                     width: opt.width,
                     height: opt.height,
-                    scaleType: opt.scaleType
+                    scaleType: opt.scaleType,
+                    user: ox.user_id,
+                    context: ox.context_id,
+                    sequence: data.last_modified
                 });
                 url = data.image1_url.replace(/^\/ajax/, ox.apiRoot) + '&' + $.param(params);
 
@@ -759,7 +768,11 @@ define('io.ox/contacts/api', [
                 width: opt.width,
                 height: opt.height,
                 scaleType: opt.scaleType,
-                uniq: uniq
+                uniq: uniq,
+                user: ox.user_id,
+                context: ox.context_id,
+                // mails don't have a last modified attribute, just use 1
+                sequence: data.last_modified || 1
             });
 
             // remove empty values
@@ -805,7 +818,7 @@ define('io.ox/contacts/api', [
 
         // set node content
         set = function (name) {
-            if (options.halo && /\@/.test(data.email)) {
+            if (options.halo && /\@/.test(data.email) && capabilities.has('contacts')) {
                 node
                 .addClass('halo-link')
                 .attr('href', '#')
