@@ -147,7 +147,7 @@ define('io.ox/contacts/edit/view-form', [
     });
 
     // Remove attachment handling when infostore is not present
-    if (!capabilities.has('infostore')) {
+    if (!capabilities.has('filestore')) {
         delete meta.sections.attachments;
         delete meta.i18n.attachments;
     }
@@ -235,7 +235,7 @@ define('io.ox/contacts/edit/view-form', [
             index: 100,
             id: 'save',
             draw: function (baton) {
-                this.append($('<button type="button" class="btn btn-primary save" data-action="save" >')
+                this.append($('<button type="button" class="btn btn-primary save" data-action="save" tabindex="1">')
                     .text(gt('Save'))
                     .on('click', function () {
                         actions.invoke(ref + '/actions/edit/save', this, baton);
@@ -249,7 +249,7 @@ define('io.ox/contacts/edit/view-form', [
             index: 200,
             id: 'discard',
             draw: function (baton) {
-                this.append($('<button type="button" class="btn btn-default discard" data-action="discard" >')
+                this.append($('<button type="button" class="btn btn-default discard" data-action="discard" tabindex="1">')
                     .text(gt('Discard'))
                     .on('click', function () {
                         actions.invoke(ref + '/actions/edit/discard', this, baton);
@@ -267,7 +267,8 @@ define('io.ox/contacts/edit/view-form', [
                         $('<input>')
                             .addClass('toggle-check')
                             .attr({
-                                type: 'checkbox'
+                                type: 'checkbox',
+                                tabindex: 1
                             })
                             .on('change', function (e) {
                                 e.preventDefault();
@@ -279,6 +280,37 @@ define('io.ox/contacts/edit/view-form', [
             }
         });
 
+        ext.point(ref + '/edit/buttons').extend({
+            index: 100,
+            id: 'metrics',
+            draw: function () {
+                var self = this;
+                require(['io.ox/metrics/main'], function (metrics) {
+                    if (!metrics.isEnabled()) return;
+                    // buttons
+                    self.delegate('[data-action]', 'mousedown', function (e) {
+                        var node =  $(e.target);
+                        metrics.trackEvent({
+                            app: 'calendar',
+                            target: 'edit/contact/toolbar',
+                            type: 'click',
+                            action: node.attr('data-action') || node.attr('data-name'),
+                            detail: node.attr('data-value')
+                        });
+                    });
+                    // toggle
+                    self.delegate('.checkbox-inline', 'mousedown', function () {
+                        metrics.trackEvent({
+                            app: 'calendar',
+                            target: 'edit/contact/toolbar',
+                            type: 'click',
+                            action: 'show-all-fields'
+                        });
+                    });
+                });
+            }
+        });
+
         point.basicExtend({
             id: 'autoExpand',
             index: 1000000000000,
@@ -383,6 +415,27 @@ define('io.ox/contacts/edit/view-form', [
             }
         });
 
+        point.basicExtend({
+            id: 'final_metrics',
+            index: 1000000000001,
+            draw: function (baton) {
+                require(['io.ox/metrics/main'], function (metrics) {
+                    if (!metrics.isEnabled()) return;
+                    baton.$.form.find('.file-input')
+                        .on('change', function track() {
+                        // metrics
+                            metrics.trackEvent({
+                                app: 'contacts',
+                                target: 'edit/contacts',
+                                type: 'click',
+                                action: 'add-attachment'
+                            });
+                        });
+                });
+            }
+        });
+
+
         // attachment Drag & Drop
         ext.point('io.ox/contacts/edit/dnd/actions').extend({
             id: 'attachment',
