@@ -173,7 +173,7 @@ define('io.ox/contacts/main', [
             app.right = right.addClass('default-content-padding f6-target')
                 .attr({
                     'tabindex': 1,
-                    'role': 'complementary',
+                    'role': 'main',
                     'aria-label': gt('Contact Details')
                 }).scrollable();
         },
@@ -608,11 +608,8 @@ define('io.ox/contacts/main', [
          */
         'folder-view': function (app) {
 
-            // tree view
-            var tree = new TreeView({ app: app, contextmenu: true, flat: true, indent: false, module: 'contacts' });
-
-            // initialize folder view
-            FolderView.initialize({ app: app, tree: tree });
+            app.treeView = new TreeView({ app: app, contextmenu: true, flat: true, indent: false, module: 'contacts' });
+            FolderView.initialize({ app: app, tree: app.treeView });
             app.folderView.resize.enable();
         },
 
@@ -765,53 +762,27 @@ define('io.ox/contacts/main', [
         },
 
         'premium-area': function (app) {
-            commons.addPremiumFeatures(app, {
-                upsellId: 'folderview/contacts/bottom',
-                upsellRequires: 'carddav'
+
+            ext.point('io.ox/contacts/sidepanel').extend({
+                id: 'premium-area',
+                index: 10000,
+                draw: function () {
+                    this.append(
+                        commons.addPremiumFeatures(app, {
+                            append: false,
+                            upsellId: 'folderview/contacts/bottom',
+                            upsellRequires: 'carddav'
+                        })
+                    );
+                }
             });
         },
 
         /*
          * change to default folder on no permission or folder not found errors
          */
-        'no-permission': function (app) {
-            // use debounce, so errors from folder and app api are only handled once.
-            var handleError = _.debounce(function (error) {
-                // work with (error) and (event, error) arguments
-                if (error && !error.error) {
-                    if (arguments[1] && arguments[1].error) {
-                        error = arguments[1];
-                    } else {
-                        return;
-                    }
-                }
-                // only change if folder is currently displayed
-                if (error.error_params[0] && String(app.folder.get()) !== String(error.error_params[0])) {
-                    return;
-                }
-                require(['io.ox/core/yell'], function (yell) {
-                    yell(error);
-                    // try to load the default folder
-                    // guests do not have a default folder, so the first visible one is chosen
-                    app.folder.setDefault();
-                });
-            }, 300);
-
-            folderAPI.on('error:FLD-0008', handleError);
-            api.on('error:FLD-0008', handleError);
-            api.on('error:CON-0104', function (e, error) {
-                // check if folder is currently displayed
-                if (String(app.folder.get()) !== String(error.error_params[0])) {
-                    return;
-                }
-                // see if we can still access the folder, although we are not allowed to view the contents
-                // this is important because otherwise we would not be able to change permissions (because the view jumps to the default folder all the time)
-                folderAPI.get(app.folder.get(), { cache: false }).fail(function (error) {
-                    if (error.code === 'FLD-0003') {
-                        handleError(error);
-                    }
-                });
-            });
+        'folder-error': function (app) {
+            app.folder.handleErrors();
         },
 
         'api-events': function (app) {
@@ -820,6 +791,13 @@ define('io.ox/contacts/main', [
             });
         },
 
+        'import': function () {
+            api.on('import', function () {
+                //update current detailview
+                api.trigger('update:' + _.ecid(app.currentContact));
+            });
+        },
+
         'api-create-event': function (app) {
             if (_.device('smartphone')) return;
 
@@ -851,6 +829,21 @@ define('io.ox/contacts/main', [
             };
         },
 
+        'sidepanel': function (app) {
+
+            ext.point('io.ox/contacts/sidepanel').extend({
+                id: 'tree',
+                index: 100,
+                draw: function (baton) {
+                    // add border & render tree and add to DOM
+                    this.addClass('border-right').append(baton.app.treeView.$el);
+                }
+            });
+
+            var node = app.getWindow().nodes.sidepanel;
+            ext.point('io.ox/contacts/sidepanel').invoke('draw', node, ext.Baton({ app: app }));
+        },
+
         'metrics': function (app) {
 
             function getFolderType(folder) {
@@ -942,7 +935,7 @@ define('io.ox/contacts/main', [
         app.gridContainer = $('<div class="abs border-left border-right contact-grid-container">')
             .attr({
                 role: 'navigation',
-                'aria-label': gt('Item List')
+                'aria-label': gt('Contacts')
             });
 
         app.grid = new VGrid(app.gridContainer, {
@@ -952,6 +945,8 @@ define('io.ox/contacts/main', [
             //swipeRightHandler: swipeRightHandler,
         });
 
+        app.gridContainer.find('.vgrid-toolbar').attr('aria-label', gt('Contacts toolbar'));
+
         commons.wireGridAndWindow(app.grid, win);
         commons.wireFirstRefresh(app, api);
         commons.wireGridAndRefresh(app.grid, api, win);
@@ -961,6 +956,8 @@ define('io.ox/contacts/main', [
             return app.grid;
         };
 
+        if (capabilities.has('gab !alone') && !options.folder && app.settings.get('startInGlobalAddressbook', true)) options.folder = '6';
+
         // go!
         commons.addFolderSupport(app, app.grid, 'contacts', options.folder)
             .always(function () {
@@ -969,6 +966,20 @@ define('io.ox/contacts/main', [
             });
     });
 
+    // set what to do if the app is started again
+    // this way we can react to given options, like for example a different folder
+    app.setResume(function (options) {
+        // only consider folder option for now
+        if (options && options.folder && options.folder !== this.folder.get()) {
+            var appNode = this.getWindow();
+            appNode.busy();
+            return this.folder.set(options.folder).always(function () {
+                appNode.idle();
+            });
+        }
+        return $.when();
+    });
+
     return {
         getApp: app.getInstance
     };
