@@ -134,9 +134,9 @@ define('io.ox/contacts/util', [
             if (htmlOutput === true) {
                 copy = {};
                 _(['title', 'first_name', 'last_name', 'display_name']).each(function (id) {
-                    if ($.trim(obj[id])) {
-                        copy[id] = '<span class="' + id + '">' + _.escape(obj[id]) + '</span>';
-                    }
+                    if (!$.trim(obj[id])) return;
+                    var tagName = id === 'last_name' ? 'b' : 'span';
+                    copy[id] = '<' + tagName + ' class="' + id + '">' + _.escape(obj[id]) + '</' + tagName + '>';
                 });
             }
             fmt = this.getFullNameFormat(copy);
@@ -170,16 +170,19 @@ define('io.ox/contacts/util', [
          * parameters to gettext.format to obtain the full name.
          */
         getMailFullNameFormat: function (obj) {
+            var first_name = $.trim(obj.first_name),
+                last_name = $.trim(obj.last_name),
+                display_name = $.trim(obj.display_name);
 
             // combine first name and last name
-            if (obj.last_name && obj.first_name) {
+            if (last_name && first_name) {
                 return {
                     format:
                         //#. Name in mail addresses
                         //#. %1$s is the first name
                         //#. %2$s is the last name
                         gt.pgettext('mail address', '%1$s %2$s'),
-                    params: [_.noI18n(obj.first_name), _.noI18n(obj.last_name)]
+                    params: [_.noI18n(first_name), _.noI18n(last_name)]
                 };
             }
 
@@ -188,14 +191,14 @@ define('io.ox/contacts/util', [
             // and this should be same order as getFullNameFormat()
 
             // fallback #1: just last_name
-            if (obj.last_name) return single(2, obj.last_name);
+            if (last_name) return single(2, last_name);
 
             // fallback #2: just first_name
-            if (obj.first_name) return single(1, obj.first_name);
+            if (first_name) return single(1, first_name);
 
             // fallback #3: use existing display name?
-            if (obj.display_name) {
-                return single(4, util.unescapeDisplayName(obj.display_name));
+            if (display_name) {
+                return single(4, util.unescapeDisplayName(display_name));
             }
 
             return { format: _.noI18n(''), params: [] };
@@ -226,7 +229,7 @@ define('io.ox/contacts/util', [
 
         getMail: function (obj) {
             // get the first mail address
-            return obj ? (obj.email1 || obj.email2 || obj.email3 || obj.mail || '').toLowerCase() : '';
+            return obj ? (obj.email1 || obj.email2 || obj.email3 || obj.mail || '').trim().toLowerCase() : '';
         },
 
         getJob: function (obj) {
@@ -292,7 +295,71 @@ define('io.ox/contacts/util', [
             return birthday.format(
                 moment.localeData().longDateFormat('l').replace(/[\/\-]*Y+[\/\-]*/, '')
             );
-        }
+        },
+
+        // @arg is either a string (image1_url) or an object with image1_url
+        getImage: function (arg, options) {
+
+            if (_.isObject(arg)) arg = arg.image1_url;
+            if (!arg) return '';
+
+            options = _.extend({ width: 40, height: 40, scaleType: 'cover' }, options);
+
+            // use double size for retina displays
+            if (_.device('retina')) {
+                options.width *= 2;
+                options.height *= 2;
+            }
+
+            return arg.replace(/^https?\:\/\/[^\/]+/i, '').replace(/^\/ajax/, ox.apiRoot) + '&' + $.param(options);
+        },
+
+        getInitials: (function () {
+
+            var regFirst = /^.*?([a-z0-9\xC0-\xFF])/i,
+                regLast = /\s.*?([a-z0-9\xC0-\xFF])\S*$/i;
+
+            function first(str) {
+                var match = regFirst.exec(str);
+                return ((match && match[1]) || '');
+            }
+
+            function last(str) {
+                var match = regLast.exec(str);
+                return ((match && match[1]) || '');
+            }
+
+            function get(obj) {
+
+                var first_name = $.trim(obj.first_name),
+                    last_name = $.trim(obj.last_name),
+                    display_name = $.trim(obj.display_name);
+
+                // yep, both first()
+                if (first_name && last_name) return first(first_name) + first(last_name);
+                if (display_name) return first(display_name) + last(display_name);
+                // again, first() only
+                if (last_name) return first(last_name);
+                if (first_name) return first(first_name);
+
+                return '';
+            }
+
+            return function (obj) {
+                return get(obj).toUpperCase();
+            };
+        }()),
+
+        getInitialsColor: (function () {
+
+            var colors = ['red', 'orange', 'yellow', 'green', 'cyan', 'blue', 'purple', 'pink'],
+                modulo = colors.length;
+
+            return function (initials) {
+                if (!initials) return 'gray';
+                return colors[initials[0].charCodeAt() % modulo];
+            };
+        }())
     };
 
     return that;
