@@ -28,8 +28,9 @@ define('io.ox/contacts/view-detail', [
     'settings!io.ox/contacts',
     'io.ox/core/tk/attachments',
     'io.ox/core/http',
+    'static/3rd.party/purify.min.js',
     'less!io.ox/contacts/style'
-], function (ext, util, api, actions, model, pViews, pModel, BreadcrumbView, links, coreUtil, capabilities, gt, settings, attachments, http) {
+], function (ext, util, api, actions, model, pViews, pModel, BreadcrumbView, links, coreUtil, capabilities, gt, settings, attachments, http, DOMPurify) {
 
     'use strict';
 
@@ -405,21 +406,39 @@ define('io.ox/contacts/view-detail', [
             //#. %3$s is the city
             //#. %4$s is the state
             //#. %5$s is the country
-            gt('%1$s\n%2$s %3$s\n%4$s\n%5$s', data);
+            gt('%1$s\n%2$s %3$s\n%4$s\n%5$s', data[0], data[1], data[2], data[3], data[4]);
+
+        var services = {
+            google: { label: gt('Google Maps'), url: 'https://www.google.com/maps?q=' },
+            osm: { label: gt('Open Street Map'), url: 'https://www.openstreetmap.org/search?query=' },
+            apple: { label: gt('Apple Maps'), url: 'https://maps.apple.com/?q=' }
+        };
 
         return function () {
+
+            var address = $('<address>').attr('data-property', type).text($.trim(text)),
+                service = settings.get('mapService', 'google');
+
+            // Apple Maps only works on iOS and MacOS
+            if (service === 'apple' && !_.device('ios || macos')) service = 'none';
+
+            if (service === 'none') {
+                return $(this).append(address);
+            }
+
+            var query = encodeURIComponent(text.replace(/\n*/, '\n').trim().replace(/\n/g, ', '));
+
             $(this).append(
-                $('<a class="google-maps" target="_blank" rel="noopener">')
-                    .attr('href', 'http://www.google.com/maps?q=' + encodeURIComponent(text.replace(/\n*/, '\n').trim().replace(/\n/g, ', ')))
-                    .attr('data-property', type)
-                    .append(
-                        $('<address>').text($.trim(text)),
-                        $('<p>').append(
-                            $('<i class="fa fa-external-link" aria-hidden="true">'),
-                            // \u2122 = &trade;
-                            $.txt(' Google Maps \u2122')
-                        )
+                $('<a class="maps-service" target="_blank" rel="noopener">')
+                .attr('href', services[service].url + query)
+                .append(
+                    address,
+                    $('<p>').append(
+                        $('<i class="fa fa-external-link" aria-hidden="true">'),
+                        //#. %1$s is a map service, like "Google Maps"
+                        $.txt(' ' + gt('Open in %1$s', services[service].label))
                     )
+                )
             );
         };
     }
@@ -460,7 +479,9 @@ define('io.ox/contacts/view-detail', [
                         simple(data, 'suffix'),
                         simple(data, 'nickname'),
                         row('birthday', function () {
-                            if (baton.data.birthday) {
+                            // check if null, undefined, empty string
+                            // 0 is valid (1.1.1970)
+                            if (_.isNumber(baton.data.birthday)) {
                                 return util.getBirthday(baton.data.birthday);
                             }
                         }),
@@ -468,13 +489,18 @@ define('io.ox/contacts/view-detail', [
                             var url = $.trim(baton.data.url);
                             if (!url) return;
                             if (!/^https?:\/\//i.test(url)) url = 'http://' + url;
-                            return $('<a target="_blank" rel="noopener">').attr('href', url).text(url);
+                            var node = $('<a target="_blank" rel="noopener">').attr('href', encodeURI(decodeURI(url))).text(url);
+                            return DOMPurify.sanitize(node.get(0), { ALLOW_TAGS: ['a'], SAFE_FOR_JQUERY: true, RETURN_DOM_FRAGMENT: true });
                         }),
                         // --- rare ---
                         simple(data, 'marital_status'),
                         simple(data, 'number_of_children'),
                         simple(data, 'spouse_name'),
-                        simple(data, 'anniversary')
+                        row('anniversary', function () {
+                            if (baton.data.anniversary) {
+                                return new moment(baton.data.anniversary).utc().format('l');
+                            }
+                        })
                     )
                     .attr('data-block', 'personal')
                 );
