@@ -23,7 +23,8 @@ define('io.ox/core/api/account', [
     var idHash = {},
         typeHash = {},
         // default separator
-        separator = settings.get('defaultseparator', '/');
+        separator = settings.get('defaultseparator', '/'),
+        altnamespace = settings.get('namespace', 'INBOX/') === '';
 
     var process = function (data) {
 
@@ -32,35 +33,34 @@ define('io.ox/core/api/account', [
 
         var rPath = /^default\d+/,
 
-            fix = function (account, id, title) {
-                var prefix = 'default' + account.id + separator,
-                    field = id + '_fullname';
-                if (account.id === 0 && !account[field]) {
-                    var folder = settings.get(['folder', id]);
-                    // folder isn't available in config
+            fix = function (type) {
+                var prefix = 'default' + this.id + separator,
+                    field = type + '_fullname',
+                    folder;
+                // check if folder path is not defined
+                if (!this[field]) {
+                    // only fix primary account (see US 91604548 / Bug 37439)
+                    if (this.id !== 0) return;
+                    folder = settings.get(['folder', type]);
                     if (!folder) {
-                        // educated guess
-                        folder = settings.get('folder/inbox') + separator + (account[id] || title);
+                        // fix fullname only if we have a short name
+                        if (this[type]) {
+                            folder = altnamespace ? 'default0' : settings.get('folder/inbox');
+                            folder += separator + this[type];
+                        } else {
+                            // empty string simply to avoid null value
+                            folder = '';
+                        }
                     }
-                    account[field] = folder;
-                } else if (!account[field]) {
-                    // US 91604548 / Bug 37439: remove legacy code
-                    // educated guess
-                    // account[field] = prefix + (account[id] || title);
-                } else if (!rPath.test(account[field])) {
+                    this[field] = folder;
+                } else if (!rPath.test(this[field])) {
                     // missing prefix
-                    account[field] = prefix + account[field];
+                    this[field] = prefix + this[field];
                 }
             };
 
         _(data).each(function (account) {
-            fix(account, 'trash', 'Trash');
-            fix(account, 'sent', 'Sent');
-            fix(account, 'drafts', 'Drafts');
-            fix(account, 'spam', 'Spam');
-            fix(account, 'archive', 'Archive');
-            fix(account, 'confirmed_spam', 'Confirmed Spam');
-            fix(account, 'confirmed_ham', 'Confirmed Ham');
+            _(['trash', 'sent', 'drafts', 'spam', 'archive', 'confirmed_spam', 'confirmed_ham']).each(fix, account);
         });
 
         return isArray ? data : data[0];
@@ -274,11 +274,8 @@ define('io.ox/core/api/account', [
             if (!account) return $.Deferred().reject(account);
 
             // use user-setting for primary account and unified folders
-            if (account_id === 0 || api.isUnified(account_id)) {
-                return require(['settings!io.ox/mail']).then(function (settings) {
-                    var defaultSendAddress = $.trim(settings.get('defaultSendAddress', ''));
-                    return [account.personal, defaultSendAddress || account.primary_address];
-                });
+            if (account_id === 0 || !account.transport_url || api.isUnified(account_id)) {
+                return api.getDefaultAddress();
             }
 
             return [account.personal, account.primary_address];
@@ -288,6 +285,15 @@ define('io.ox/core/api/account', [
         });
     };
 
+    api.getDefaultAddress = function () {
+        return require(['settings!io.ox/mail']).then(function (settings) {
+            return api.get(0).then(ensureDisplayName).then(function (account) {
+                var defaultSendAddress = $.trim(settings.get('defaultSendAddress', ''));
+                return [account.personal, defaultSendAddress || account.primary_address];
+            });
+        });
+    };
+
     /*
      * get valid address for account
      */
@@ -400,6 +406,13 @@ define('io.ox/core/api/account', [
     api.getAllSenderAddresses = function () {
 
         return api.all()
+        .then(function (list) {
+            // only consider external accounts with a transport_url (see bug 48344)
+            // primary account is assumed to always work even without a transport_url
+            return _(list).filter(function (account) {
+                return account.id === 0 || !!account.transport_url;
+            });
+        })
         .then(function (list) {
             return $.when.apply($, _(list).map(ensureDisplayName));
         })
@@ -639,7 +652,8 @@ define('io.ox/core/api/account', [
             params: {
                 action: 'get',
                 email: data.email,
-                password: data.password
+                password: data.password,
+                force_secure: data.force_secure
             }
         });
     };
