@@ -81,7 +81,7 @@ define('io.ox/core/api/attachment', [
          */
         create: function (options, data) {
             var self = this;
-            var params = { action: 'attach' },
+            var params = { action: 'attach', force_json_response: true },
                 json = {
                     module: options.module,
                     attached: options.id,
@@ -165,11 +165,16 @@ define('io.ox/core/api/attachment', [
          * builds URL to download/preview File
          * @param  {object} data
          * @param  {string} mode
+         * @param  {object} options
          * @return { string} url
          */
-        getUrl: function (data, mode) {
+        getUrl: function (data, mode, options) {
+            options = options || {};
+
+            var url = ox.apiRoot + '/attachment',
+                // scaling options
+                scaling = options.width && options.height ? '&scaleType=' + options.scaleType + '&width=' + options.width + '&height=' + options.height : '';
 
-            var url = ox.apiRoot + '/attachment';
             // inject filename for more convenient file downloads
             url += (data.filename ? '/' + encodeURIComponent(data.filename) : '') + '?' +
                 $.param({
@@ -185,7 +190,7 @@ define('io.ox/core/api/attachment', [
             switch (mode) {
                 case 'view':
                 case 'open':
-                    return url + '&delivery=view';
+                    return url + '&delivery=view' + scaling;
                 case 'download':
                     return url + '&delivery=download';
                 default:
