@@ -112,6 +112,8 @@ define('io.ox/core/api/collection-loader', ['io.ox/core/api/collection-pool', 'i
             var collection;
 
             params = this.getQueryParams(params || {});
+            // params are false for virtual folders
+            if (params === false) return;
             params.limit = '0,' + this.PRIMARY_PAGE_SIZE;
             collection = this.collection = this.getCollection(params);
             this.loading = false;
@@ -217,6 +219,10 @@ define('io.ox/core/api/collection-loader', ['io.ox/core/api/collection-pool', 'i
             this.after(offset, params, data);
         },
 
+        noSelect: function () {
+            return false;
+        },
+
         virtual: function () {
             return false;
         },
@@ -230,6 +236,7 @@ define('io.ox/core/api/collection-loader', ['io.ox/core/api/collection-pool', 'i
             var module = this.module,
                 key = module + '/' + _.param(_.extend({ session: ox.session }, params)),
                 rampup = ox.rampup[key],
+                noSelect = this.noSelect(params),
                 virtual = this.virtual(params),
                 self = this;
 
@@ -238,9 +245,8 @@ define('io.ox/core/api/collection-loader', ['io.ox/core/api/collection-pool', 'i
                 return $.when(rampup);
             }
 
-            if (virtual) {
-                return $.when(virtual);
-            }
+            if (noSelect) return $.when([]);
+            if (virtual) return $.when(virtual);
 
             return http.wait().then(function () {
                 return self.httpGet(module, params).then(function (data) {
