@@ -27,7 +27,8 @@ define('io.ox/core/boot/util', [], function () {
             $('<div role="alert" class="selectable-text alert alert-info">').append(
                 node
             )
-        ).show();
+        );
+
     }
     var feedbackNode = null;
     // var feedbackType = null;
@@ -102,6 +103,8 @@ define('io.ox/core/boot/util', [], function () {
                                 // error_params[0] should contain a url to password change manager or sth.
                                 .attr('href', error.error_params[0])];
                 });
+            } else if (error && error.code === 'LGI-0016' && (error.error_params || []).length === 1) {
+                window.location.href = error.error_params[0];
             } else {
                 this.feedback('error', $.txt(_.formatError(error, '%1$s (%2$s)')));
             }
@@ -138,7 +141,7 @@ define('io.ox/core/boot/util', [], function () {
     //
 
     ox.relogin = function () {
-        exports.gotoSignin('login_type=none');
+        exports.gotoSignin('login_type=useForm');
     };
 
     ox.on('relogin:required', ox.relogin);
