@@ -181,6 +181,7 @@ define('io.ox/core/desktop', [
             state: 'ready',
             saveRestorePointTimer: null,
             launch: function () { return $.when(); },
+            resume: function () { return $.when(); },
             quit: function () { return $.when(); }
         },
 
@@ -346,7 +347,55 @@ define('io.ox/core/desktop', [
 
                     destroy: function () {
                         that = win = grid = null;
-                    }
+                    },
+
+                    handleErrors: (function () {
+
+                        var process = _.debounce(function (error) {
+                            // refresh parent folder or if flat all
+                            var model = api.pool.getModel(self.folder.get());
+                            if (model) api.list(model.get('folder_id'), { cache: false });
+                            self.folder.setDefault();
+                            notifications.yell(error);
+                        }, 1000, true);
+
+                        var regexStr = '(' +
+                                // permission denied (calendar)
+                                'APP-0013|' +
+                                // permission denied (contacts)
+                                'CON-0104|' +
+                                // permission denied
+                                'FLD-0003|' +
+                                // not found
+                                'FLD-0008|' +
+                                // folder storage service no longer available
+                                'FLD-1004|' +
+                                // mail folder "..." could not be found on mail server
+                                'IMAP-1002|' +
+                                // imap no read permission
+                                'IMAP-2041|' +
+                                // infostore no read permission
+                                'IFO-0400|' +
+                                // The provided "..." (e.g. dropbox) resource does not exist
+                                'FILE_STORAGE-0005|' +
+                                'FILE_STORAGE-0055|' +
+                                // permission denied (tasks)
+                                'TSK-0023' +
+                            ')',
+                            regex = new RegExp(regexStr);
+
+                        return function () {
+                            self.listenTo(ox, 'http:error', function (error, request) {
+                                var folder = request.params.folder || request.data.folder || error.folder || request.params.id;
+                                if (folder !== self.folder.get()) return;
+                                if (!regex.test(error.code)) return;
+                                // special handling for no permission. if api.get fails, 'http-error' is triggered again
+                                if (/(IMAP-2041|IFO-0400|APP-0013|CON-0104|TSK-0023)/.test(error.code)) return api.get(self.folder.get(), { cache: false });
+                                process(error);
+                            });
+                        };
+                    }())
+
                 };
 
                 return that;
@@ -358,6 +407,11 @@ define('io.ox/core/desktop', [
             return this;
         },
 
+        setResume: function (fn) {
+            this.set('resume', fn);
+            return this;
+        },
+
         setQuit: function (fn) {
             this.set('quit', fn);
             return this;
@@ -532,6 +586,16 @@ define('io.ox/core/desktop', [
                 this.get('window').show();
                 this.trigger('resume', this);
                 ox.trigger('app:resume', this);
+
+                if (name) {
+                    ext.point(name + '/main').invoke('resume', this, options);
+                }
+                try {
+                    var fnResume = this.get('resume');
+                    deferred = fnResume.call(this, options) || $.when();
+                } catch (e) {
+                    console.error('Error while resuming application:', e.message, e, this);
+                }
                 // if image previews were already displayed in the files app, it might happen that another app (e.g. latest files widget) did some changes to the pool
                 // and the previews were redrawn but not displayed since the 'appear' event has not been triggered
                 $(window).trigger('resize.lazyload');
@@ -626,6 +690,7 @@ define('io.ox/core/desktop', [
             var uniqueID = this.get('uniqueID');
             ox.ui.App.removeRestorePoint(uniqueID);
         }
+
     });
 
     // static methods
@@ -1111,8 +1176,14 @@ define('io.ox/core/desktop', [
                 }
 
                 this.setHeader = function (node) {
-                    this.nodes.header.append(node.addClass('container'));
-                    this.nodes.outer.addClass('header-top');
+                    var position = _.device('!desktop') ? 'top' : coreConfig.get('features/windowHeaderPosition', 'bottom');
+                    if (position === 'top') {
+                        this.nodes.header.append(node.addClass('container'));
+                        this.nodes.outer.addClass('header-top');
+                    } else {
+                        this.nodes.footer.append(node.addClass('container'));
+                        this.nodes.outer.addClass('header-bottom');
+                    }
                     considerScrollbarWidth(this.nodes.header);
                     return this.nodes.header;
                 };
@@ -1434,8 +1505,8 @@ define('io.ox/core/desktop', [
                         // blocker
                         win.nodes.blocker = $('<div class="abs window-blocker">').hide().append(
                             $('<div class="abs header">'),
-                            $('<div class="progress progress-striped active first"><div class="progress-bar" style="width: 0%;"></div></div>').hide(),
-                            $('<div class="progress progress-striped progress-warning active second"><div class="progress-bar" style="width: 0%;"></div></div>').hide(),
+                            $('<div class="progress progress-striped active first"><div class="progress-bar" style="width:0"></div></div>').hide(),
+                            $('<div class="progress progress-striped progress-warning active second"><div class="progress-bar" style="width:0"></div></div>').hide(),
                             $('<div class="abs footer">')
                         ),
                         // window HEAD
@@ -1446,7 +1517,9 @@ define('io.ox/core/desktop', [
                         // window SIDEPANEL
                         win.nodes.sidepanel = $('<div class="window-sidepanel collapsed">'),
                         // window BODY
-                        win.nodes.body = $('<div class="window-body" role="main">').attr('aria-label', gt('Main window'))
+                        win.nodes.body = $('<div class="window-body">'),
+
+                        win.nodes.footer = $('<div class="window-footer">')
                     )
                     // capture controller events
                     .on('controller:quit', function () {
@@ -1498,6 +1571,7 @@ define('io.ox/core/desktop', [
                     index: 200,
                     draw: function (baton) {
                         baton.$.viewnode.append(
+                            $('<div class="sr-only arialive" role="status" aria-live="polite">'),
                             baton.$.box = $('<form class="search-box">'),
                             baton.$.boxfilter = $('<div class="search-box-filter">')
                         );
@@ -1629,7 +1703,7 @@ define('io.ox/core/desktop', [
                 buttonTimer = setTimeout(function () {
                     // add button to abort
                     if (!$blocker[0].firstChild) {
-                        var button = $('<button type="button" class="btn btn-primary">').text(gt('Cancel')).fadeIn();
+                        var button = $('<button type="button" class="btn btn-primary" tabindex="1">').text(gt('Cancel')).fadeIn();
                         button.on('click', function () {
                             def.reject(true);
                             clear(blockerTimer);
