@@ -174,6 +174,14 @@ define('io.ox/core/extensions', ['io.ox/core/event'], function (Events) {
                 // skip duplicates (= same id)
                 if (!has(extension.id)) {
 
+                    if ('enabled' in extension) {
+                        if (_.isObject(extension.enabled)) {
+                            return console.error("Extending of '" + this.id + "' with '" + extension.id + "' failed. Ensure extensions 'enabled' property is a primitive.");
+                        }
+                        if (!extension.enabled) this.disable(extension.id);
+                        delete extension.enabled;
+                    }
+
                     extension.invoke = createInvoke(this, extension);
 
                     if (replacements[extension.id]) {
@@ -184,6 +192,11 @@ define('io.ox/core/extensions', ['io.ox/core/event'], function (Events) {
                     extensions.push(extension);
                     sort();
 
+                    if ('enabled' in extension) {
+                        if (!extension.enabled) this.disable(extension.id);
+                        delete extension.enabled;
+                    }
+
                     if (!extension.metadata) {
                         extension.metadata = function (name, args) {
                             if (this[name]) {
