@@ -81,10 +81,10 @@ define('io.ox/core/folder/actions/move', [
                         // files API returns array on error; mail just a single object
                         // contacts a double array of undefined; tasks the new object.
                         // so every API seems to behave differently.
-                        if (_.isArray(response)) response = _(response).compact()[0];
+                        if (!options.fullResponse && _.isArray(response)) response = _(response).compact()[0];
                         // custom callback?
                         if (options.successCallback) {
-                            options.successCallback(response);
+                            options.successCallback(response, { input: input, target: target, options: options.all });
                         } else if (_.isObject(response) && response.error) {
                             // fail?
                             notifications.yell(response);
@@ -117,6 +117,9 @@ define('io.ox/core/folder/actions/move', [
                 open: options.open,
                 settings: settings,
                 title: options.title,
+                type: options.type,
+                initialize: options.pickerInit || $.noop,
+                close: options.pickerClose || $.noop,
 
                 done: function (id) {
                     if (type === 'copy' || id !== current) commit(id);
