@@ -223,7 +223,7 @@ define('io.ox/core/folder/api', [
 
         // checks if the folder supports a capability
         supports: function (capability) {
-            return _(this.get('supported_capabilities')).indexOf(capability) > -1;
+            return util.supports(capability, this.attributes);
         },
 
         // convenience function / maps to folderAPI.is(type, folder)
@@ -304,6 +304,8 @@ define('io.ox/core/folder/api', [
             // update collection
             var collection = this.getCollection(id),
                 type = collection.fetched ? 'set' : 'reset';
+            // not expired
+            collection.expired = false;
             // remove old virtual parent references
             if (this.models[id] && isVirtual(id)) {
                 _(collection.models).each(function (model) {
@@ -343,6 +345,10 @@ define('io.ox/core/folder/api', [
             return this.collections[id] || (this.collections[id] = new FolderCollection(id));
         },
 
+        expire: function () {
+            _(this.collections).each(function (collection) { collection.expired = true; });
+        },
+
         unfetch: function (id) {
             if (arguments.length === 0 || id === '0') {
                 // no need for recursion; reset all collections
@@ -599,7 +605,7 @@ define('io.ox/core/folder/api', [
         // already cached?
         var collectionId = getCollectionId(id, options.all),
             collection = pool.getCollection(collectionId);
-        if (collection.fetched && options.cache === true) return $.when(collection.toJSON());
+        if (collection.fetched && !collection.expired && options.cache === true) return $.when(collection.toJSON());
 
         // use rampup data?
         if (rampup[id] && !options.all) {
@@ -1011,20 +1017,25 @@ define('io.ox/core/folder/api', [
         _(pool.collections).invoke('remove', model);
     }
 
-    function remove(id) {
+    function remove(ids) {
 
-        // get model
-        var model = pool.getModel(id), data = model.toJSON();
+        // ensure array
+        if (!_.isArray(ids)) ids = [ids];
 
-        // trigger event
-        api.trigger('before:remove', data);
+        // local copy for model data
+        var hash = {};
 
-        //set unread to 0 to update subtotal attributes of parent folders (bubbles through the tree)
-        model.set('unread', 0);
-
-        // update collection (now)
-        removeFromAllCollections(model);
-        model.trigger('destroy');
+        _(ids).each(function (id) {
+            // get model
+            var model = pool.getModel(id), data = hash[id] = model.toJSON();
+            // trigger event
+            api.trigger('before:remove', data);
+            //set unread to 0 to update subtotal attributes of parent folders (bubbles through the tree)
+            model.set('unread', 0);
+            // update collection (now)
+            removeFromAllCollections(model);
+            model.trigger('destroy');
+        });
 
         // delete on server
         return http.PUT({
@@ -1032,22 +1043,25 @@ define('io.ox/core/folder/api', [
             params: {
                 action: 'delete',
                 failOnError: true,
-                tree: tree(id)
+                tree: tree(ids[0])
             },
-            data: [id],
+            data: ids,
             appendColumns: false
         })
         .done(function () {
-            api.trigger('remove', id, data);
-            api.trigger('remove:' + id, data);
-            api.trigger('remove:' + data.module, data);
-            if (account.is('trash', id)) {
+            _(ids).each(function (id) {
+                var data = hash[id];
+                api.trigger('remove', id, data);
+                api.trigger('remove:' + id, data);
+                api.trigger('remove:' + data.module, data);
                 // if this is a trash folder trigger special event (quota updates)
-                api.trigger('cleared-trash');
-            }
+                if (account.is('trash', id)) api.trigger('cleared-trash');
+            });
         })
         .fail(function () {
-            api.trigger('remove:fail', id);
+            _(ids).each(function (id) {
+                api.trigger('remove:fail', id);
+            });
         });
     }
 
@@ -1136,6 +1150,7 @@ define('io.ox/core/folder/api', [
         _.chain(arguments).flatten().map(getFolderId).compact().uniq().each(function (id) {
             // register function call once
             if (!reload.hash[id]) reload.hash[id] = _.debounce(get.bind(null, id, { cache: false }), reload.wait);
+            api.trigger('reload:' + id);
             reload.hash[id]();
         });
     }
@@ -1214,8 +1229,10 @@ define('io.ox/core/folder/api', [
     //
 
     function refresh() {
+        pool.expire();
         // pause http layer to get one multiple
         http.pause();
+        var defs = [];
         // loop over all non-flat folders, get all parent folders, apply unique, and reload if they have subfolders
         _(api.pool.models).chain()
             .filter(function (model) {
@@ -1223,16 +1240,21 @@ define('io.ox/core/folder/api', [
             })
             .invoke('get', 'folder_id').uniq().compact().without('0')
             .each(function (id) {
-                list(id, { cache: false });
+                defs.push(list(id, { cache: false }));
             });
         // loop over flat views
         _(getFlatViews()).each(function (module) {
-            flat({ module: module, cache: false });
+            defs.push(flat({ module: module, cache: false }));
         });
-        // go!
-        http.resume().done(function () {
+
+        // we cannot use virtual.refresh right after the multiple returns, because it does not wait for the callback functions of the requests to finish. This would result in outdated models in the pool
+        // use always to keep the behavior of the multiple (ignores errors)
+        $.when.apply($, defs).always(function () {
             virtual.refresh();
         });
+
+        // go!
+        return http.resume();
     }
 
     ox.on('please:refresh refresh^', refresh);
@@ -1276,7 +1298,7 @@ define('io.ox/core/folder/api', [
     function getExistingFolder(type) {
         var defaultId = util.getDefaultFolder(type);
         if (defaultId) return $.Deferred().resolve(defaultId);
-        if (type === 'mail') return $.Deferred().resolve('default0' + mailSettings.get('defaultseparator', '/') + 'INBOX');
+        if (type === 'mail') return $.Deferred().resolve('default0' + getDefaultSeparator() + 'INBOX');
         if (type === 'infostore') return $.Deferred().resolve(10);
         return flat({ module: type }).then(function (data) {
             for (var section in data) {
@@ -1288,6 +1310,19 @@ define('io.ox/core/folder/api', [
         });
     }
 
+    function getDefaultSeparator() {
+        return mailSettings.get('defaultseparator', '/');
+    }
+
+    function getMailFolderSeparator(id) {
+        var base = id.split(getDefaultSeparator())[0],
+            separators = mailSettings.get('separators') || {};
+        if (!/^default\d+$/.test(base)) return '/';
+        base = base.replace('default', '');
+        if (separators[base]) return separators[base];
+        return getDefaultSeparator();
+    }
+
     // publish api
     _.extend(api, {
         FolderModel: FolderModel,
@@ -1323,6 +1358,8 @@ define('io.ox/core/folder/api', [
         getDefaultFolder: util.getDefaultFolder,
         getExistingFolder: getExistingFolder,
         getStandardMailFolders: getStandardMailFolders,
+        getDefaultSeparator: getDefaultSeparator,
+        getMailFolderSeparator: getMailFolderSeparator,
         getTextNode: getTextNode,
         getDeepLink: getDeepLink,
         getFolderTitle: getFolderTitle,
