@@ -16,8 +16,9 @@ define('io.ox/core/folder/node', [
     'io.ox/core/folder/api',
     'io.ox/core/extensions',
     'io.ox/core/api/account',
+    'settings!io.ox/core',
     'gettext!io.ox/core'
-], function (DisposableView, api, ext, account, gt) {
+], function (DisposableView, api, ext, account, settings, gt) {
 
     'use strict';
 
@@ -46,7 +47,7 @@ define('io.ox/core/folder/node', [
         },
 
         reset: function () {
-            if (this.isReset) return;
+            if (this.isReset) return this.trigger('reset');
             if (this.collection.fetched) this.onReset(); else this.list();
         },
 
@@ -89,6 +90,7 @@ define('io.ox/core/folder/node', [
             });
 
             this.isReset = true;
+            this.trigger('reset');
         },
 
         onAdd: function (model) {
@@ -165,6 +167,10 @@ define('io.ox/core/folder/node', [
             this.toggle(!this.options.open);
         },
 
+        isOpen: function () {
+            return this.options.open && this.hasSubFolders();
+        },
+
         hasArrow: function () {
             // return true if icon is not fixed-width, i.e. empty
             return this.$.arrow.find('i.fa-fw').length === 0;
@@ -207,9 +213,7 @@ define('io.ox/core/folder/node', [
         // respond to new sub-folders
         onChangeSubFolders: function () {
             // has subfolders?
-            var o = this.options,
-                hasSubFolders = this.hasSubFolders(),
-                isOpen = o.open && hasSubFolders;
+            var hasSubFolders = this.hasSubFolders(), isOpen = this.isOpen();
             // update arrow
             this.$.arrow
             .toggleClass('invisible', !hasSubFolders)
@@ -221,7 +225,7 @@ define('io.ox/core/folder/node', [
                 /*eslint-enable no-nested-ternary */
             );
             // a11y
-            if (hasSubFolders) this.$el.attr('aria-expanded', isOpen); else this.$el.removeAttr('aria-expanded');
+            if (hasSubFolders && !this.options.headless) this.$el.attr('aria-expanded', isOpen); else this.$el.removeAttr('aria-expanded');
             // toggle subfolder node
             this.$el.toggleClass('open', isOpen);
             // empty?
@@ -232,10 +236,10 @@ define('io.ox/core/folder/node', [
 
         // respond to cursor left/right
         onKeydown: function (e) {
+            if (e.which !== 37 && e.which !== 39) return;
             // already processed?
             if (e.isDefaultPrevented()) return;
             // not cursor right/left?
-            if (e.which !== 37 && e.which !== 39) return;
             // avoid further processing
             e.preventDefault();
             // skip unless folder has subfolders
@@ -316,11 +320,12 @@ define('io.ox/core/folder/node', [
 
             // also set: folder, parent, tree
 
-            this.isVirtual = this.options.virtual || /^virtual/.test(this.folder);
             this.model = api.pool.getModel(o.model_id);
+            this.noSelect = !this.model.can('read');
+            this.isVirtual = this.options.virtual || /^virtual/.test(this.folder);
             this.collection = api.pool.getCollection(o.model_id, o.tree.all);
             this.isReset = false;
-            this.describedbyID = _.uniqueId('description-');
+
             this.$ = {};
 
             // make accessible via DOM
@@ -358,47 +363,63 @@ define('io.ox/core/folder/node', [
                 offset = 22;
             }
 
+            if (!_.isEmpty(o.a11yDescription)) {
+                var uid = _.uniqueId('description-');
+                this.$el.attr('aria-describedby', uid);
+            }
+
+            // folder
+            this.$.selectable = $('<div class="folder-node" aria-hidden="true">')
+                .css('padding-left', (o.level * this.indentation) + offset).append(
+                    this.$.arrow = o.arrow ? $('<div class="folder-arrow invisible"><i class="fa fa-fw"></i></div>') : [],
+                    this.$.icon = $('<div class="folder-icon"><i class="fa fa-fw"></i></div>'),
+                    $('<div class="folder-label">').append(
+                        this.$.label = $('<div>')
+                    ),
+                    this.$.counter = $('<div class="folder-counter">')
+            );
+
+            var a11yuid = _.uniqueId('description-');
+
             // draw scaffold
             this.$el
                 .attr({
-                    id: this.describedbyID,
-                    'aria-label': '',
-                    'aria-level': o.level + 1,
-                    'aria-selected': false,
                     'data-id': this.folder,
                     'data-model': o.model_id,
-                    'data-contextmenu-id': o.contextmenu_id,
-                    'role': 'treeitem',
-                    'tabindex': '-1'
+                    'data-contextmenu-id': o.contextmenu_id
                 })
                 .append(
-                    // folder
-                    this.$.selectable = $('<div class="folder-node" role="presentation">')
-                    .css('padding-left', (o.level * this.indentation) + offset)
-                    .append(
-                        this.$.arrow = o.arrow ? $('<div class="folder-arrow invisible"><i class="fa fa-fw" aria-hidden="true"></i></div>') : [],
-                        this.$.icon = $('<div class="folder-icon"><i class="fa fa-fw" aria-hidden="true"></i></div>'),
-                        $('<div class="folder-label">').append(
-                            this.$.label = $('<div>')
-                        ),
-                        this.$.counter = $('<div class="folder-counter">')
-                    ),
+                    this.$.selectable,
                     // tag for screenreader only (aria-description)
-                    this.$.a11y = $('<span class="sr-only">').attr({ id: this.describedbyID }),
+                    this.$.a11y = $('<span class="sr-only">').attr('id', a11yuid),
                     // subfolders
                     this.$.subfolders = $('<ul class="subfolders" role="group">')
                 );
 
             // headless?
             if (o.headless) {
-                this.$el.removeClass('selectable').removeAttr('tabindex');
-                this.$.selectable.hide();
+                this.$el.removeClass('selectable');
+                this.$.selectable.remove();
+                this.$el.attr({
+                    'role': 'presentation'
+                });
+            } else {
+                this.$el.attr({
+                    'aria-describedby': a11yuid,
+                    'aria-level': o.level + 1,
+                    'aria-selected': false,
+                    'role': 'treeitem',
+                    'tabindex': '-1'
+                });
             }
 
+            // Remove useless a11y nodes
+            if (_.isEmpty(this.options.a11yDescription)) this.$.a11y.remove();
+
             // sortable
             if (o.sortable) this.$el.attr('data-sortable', true);
 
-            // virtual?
+            if (this.noSelect && o.level > 0) this.$el.addClass('no-select');
             if (this.isVirtual) this.$el.addClass('virtual');
 
             // add contextmenu (only if 'app' is defined; should not appear in modal dialogs, for example)
@@ -442,7 +463,8 @@ define('io.ox/core/folder/node', [
         renderCounter: function () {
             var value = this.getCounter();
             this.$.selectable.toggleClass('show-counter', value > 0);
-            this.$.counter.text(value > 99 ? '99+' : value);
+            if (value > 99) value = '99+';
+            this.$.counter.text(value === 0 ? '' : value);
         },
 
         getTitle: function () {
@@ -456,7 +478,9 @@ define('io.ox/core/folder/node', [
 
         renderA11yNode: function () {
             //draw even if there is no description or old descriptions cannot be cleared
-            this.$.a11y.text(this.options.a11yDescription.join('. '));
+            if (!_.isEmpty(this.options.a11yDescription)) {
+                this.$.a11y.text(this.options.a11yDescription.join('. '));
+            }
         },
 
         renderTooltip: function () {
@@ -469,8 +493,7 @@ define('io.ox/core/folder/node', [
             summary = summary.join(', ');
             if (summary) summary = ' (' + summary + ')';
             this.$el.attr({
-                'title': this.model.get('title') + summary,
-                'aria-label': this.model.get('title') + summary
+                'title': this.model.get('title') + summary
             });
         },
 
@@ -480,14 +503,16 @@ define('io.ox/core/folder/node', [
                 .addClass('folder-options contextmenu-control')
                 .attr({
                     'data-contextmenu': this.options.contextmenu || 'default',
-                    'aria-label': gt('Folder-specific actions'),
+                    'aria-label': this.options.title || !this.model.has('title') ?
+                        gt('Folder-specific actions') :
+                        //#. %1$s is the name of the folder
+                        gt('Folder-specific actions for %1$s', this.model.get('title')),
                     href: '#',
                     role: 'button',
                     tabindex: 1
                 })
                 .append(
-                    $('<i class="fa fa-bars" aria-hidden="true">'),
-                    $('<span class="sr-only">').text(gt('Folder-specific actions'))
+                    $('<i class="fa fa-bars" aria-hidden="true">')
                 )
             );
         },
@@ -520,12 +545,17 @@ define('io.ox/core/folder/node', [
             }
 
             var iconClass = '',
-                infostoreDefaultFolder = String(api.getDefaultFolder('infostore'));
+                infostoreDefaultFolder = String(api.getDefaultFolder('infostore')),
+                attachmentView = settings.get('folder/mailattachments', {}),
+                allAttachmentsFolder = String(attachmentView.all);
 
             switch (this.folder) {
                 case 'virtual/myshares':
                     iconClass = 'visible myshares';
                     break;
+                case allAttachmentsFolder:
+                    iconClass = 'visible attachments';
+                    break;
                 case infostoreDefaultFolder:
                     iconClass = 'visible myfiles';
                     break;
