@@ -129,6 +129,10 @@ define('io.ox/core/folder/util', [
                 var hash = coreSettings.get(['folder/hidden'], {});
                 id = _.isObject(data) ? data.id : data;
                 return hash[id] === true;
+            case 'attachmentView':
+                var attachmentView = coreSettings.get('folder/mailattachments', {});
+
+                return _.isEmpty(attachmentView) ? false : (_.values(attachmentView).indexOf(data.id) > -1);
             default:
                 return false;
         }
@@ -185,19 +189,19 @@ define('io.ox/core/folder/util', [
         // switch
         switch (action) {
             case 'read':
-                // can read?
-                // 256 = read own, 512 = read all, 8192 = admin
+                // can read objects? (see bug 28379 and 23933 and 44957)
                 // hide folders where your only permission is to see the foldername (rights !== 1)
-                // return (rights & 256 || rights & 512 || rights & 8192) > 0;
-                // 10: shared files folder
-                return perm(rights, 7) > 0 /*|| (!isSystem && is('public', data) && data.folder_id !== '10') // see bug 28379 and 23933 */&& rights !== 1;
-            // please use parantheses properly OR OR AND or OR AND AND?
+                return perm(rights, 7) > 0 && rights !== 1;
             case 'create':
                 // can create objects?
                 // only folder creation is allowed in system folders
-                // even if permission bit is 4 "create objects and subfolders" because ther is no bit for only create subfolders, see Bug 39598
                 // don't use the isSystem variable because it is also true for standard folders
-                return (perm(rights, 0) > 1 && !is('system', data));
+                if (is('system', data)) return false;
+                // mail is special (no-select folder; see bug 44957)
+                if (isMail && !can('read', data)) return false;
+                // even if permission bit is 4 "create objects and subfolders" because
+                // there is no bit for only create subfolders, see Bug 39598
+                return perm(rights, 0) > 1;
             case 'write':
                 // can write objects
                 return perm(rights, 14) > compareValue;
@@ -240,14 +244,14 @@ define('io.ox/core/folder/util', [
                 return !isMail && !is('account', data) && (data.capabilities & 1);
             case 'publish':
                 // check folder capability
-                if (_(data.supported_capabilities).indexOf('publication') === -1) return false;
+                if (!supports('publication', data)) return false;
                 // contact?
                 if (data.module === 'contacts') return true;
                 // files?
                 return data.module === 'infostore' && can('create', data) && rights !== 1 && rights !== 4;
             case 'subscribe':
                 // check folder capability
-                if (_(data.supported_capabilities).indexOf('subscription') === -1) return false;
+                if (!supports('subscription', data)) return false;
                 // check rights
                 return (/^(contacts|calendar|infostore)$/).test(data.module) && can('write', data);
             case 'subscribe:imap':
@@ -256,11 +260,21 @@ define('io.ox/core/folder/util', [
                 if (rights === 0) return false;
                 if (data.standard_folder && /^(7|9|10|11|12)$/.test(data.standard_folder_type)) return false;
                 return Boolean(data.capabilities & Math.pow(2, 4));
+            case 'change:seen':
+                return supports('STORE_SEEN', data);
+            case 'add:version':
+                return supports('file_versions', data);
             default:
                 return false;
         }
     }
 
+    // simple generic check to see if the folder supports a capability
+    // supports models and objects containing folder data
+    function supports(capability, data) {
+        return data.get ? _(data.get('supported_capabilities')).indexOf(capability) > -1 : _(data.supported_capabilities).indexOf(capability) > -1;
+    }
+
     /*
      * Expects a TreeNodeView and expands this view and all parent views.
      */
@@ -275,6 +289,7 @@ define('io.ox/core/folder/util', [
     return {
         perm: perm,
         bits: bits,
+        supports: supports,
         is: is,
         can: can,
         getDefaultFolder: getDefaultFolder,
