@@ -158,6 +158,7 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
                 '605': 'default_address',
                 '606': 'image1_url',
                 '607': 'sort_name',
+                '608': 'useCount',
                 '610': 'yomiFirstName',
                 '611': 'yomiLastName',
                 '612': 'yomiCompany'
@@ -340,7 +341,9 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
                 '1040': 'meta',
                 '1041': 'archive',
                 '1042': 'archive_fullname',
-                '1043': 'transport_auth'
+                '1043': 'transport_auth',
+                '1044': 'mail_starttls',
+                '1045': 'transport_starttls'
             },
             'attachment': {
                 '1': 'id',
@@ -377,7 +380,9 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
             }
         },
         // extended permissions
-        idMappingExcludes = ['3060', '7010'];
+        idMappingExcludes = ['3060', '7010'],
+        // list of error codes, which are not logged
+        errorBlacklist = ['SVL-0003', 'LGI-0006'];
 
     // extend with commons (not all modules use common columns, e.g. folders)
     $.extend(idMapping.contacts, idMapping.common);
@@ -618,7 +623,8 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
 
         if (isError) {
             // forward all errors to respond to special codes
-            ox.trigger('http:error', response);
+            ox.trigger('http:error:' + response.code, response, o);
+            ox.trigger('http:error', response, o);
             // session expired?
             var isSessionError = (/^SES\-/i).test(response.code),
                 isLogin = o.module === 'login' && o.data && /^(login|autologin|store|tokens)$/.test(o.data.action);
@@ -781,6 +787,7 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
                     that.trigger('reachable');
                     ox.trigger('connection:online connection:up');
                 }
+                if (error.code && errorBlacklist.indexOf(error.code) >= 0) return;
                 error = _.extend({ status: status, took: took }, error);
                 log.add(error, r.o);
             });
@@ -817,6 +824,9 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
                     processResponse(r.def, response, r.o, r.o.type);
                 } else if (r.xhr.dataType === 'json' && response.error !== undefined) {
                     // error handling if JSON (e.g. for UPLOAD)
+                    response.folder = r.o.data.folder;
+                    ox.trigger('http:error:' + response.code, response, r.o);
+                    ox.trigger('http:error', response, r.o);
                     r.def.reject(response);
                 } else if (_.isArray(response.data)) {
                     // Skip Warnings (category: 13)
