@@ -40,7 +40,7 @@ define('io.ox/core/links', ['io.ox/core/yell'], function (yell) {
             // special handling for text and spreadsheet
             options = /^io.ox\/office\//.test(data.app) ?
                 { action: 'load', file: { folder_id: data.folder, id: data.id } } :
-                _(data).pick('folder', 'folder_id', 'id');
+                _(data).pick('folder', 'folder_id', 'id', 'cid');
 
         ox.launch(data.app + '/main', options).done(function () {
             // special handling for settings (bad, but apparently solved differently)
@@ -106,10 +106,6 @@ define('io.ox/core/links', ['io.ox/core/yell'], function (yell) {
                 }
                 sidepopup.show(e, function (popup) {
                     popup.busy();
-                    // fix special id format
-                    if (/^\d+\/\d+.\d+$/.test(data.id)) {
-                        data = _.cid(data.id.replace(/\//, '.'));
-                    }
                     api.get(data).then(
                         function success(data) {
                             popup.idle().append(view.draw(data));
@@ -178,7 +174,7 @@ define('io.ox/core/links', ['io.ox/core/yell'], function (yell) {
         ox.registry.call('mail-compose', 'compose', {
             to: [[name, address]],
             subject: params.subject || '',
-            attachments: params.body ? [{ content: params.body || '' }] : undefined
+            attachments: [{ content: params.body || '', disp: 'inline' }]
         });
     });
 });
