@@ -51,18 +51,6 @@ define('io.ox/core/main', [
         };
     }
 
-    // a11y: fix for role="button"
-    $(document).on('keydown', 'a[role="button"]', function (e) {
-        if (e.which !== 32 || e.isDefaultPrevented()) return;
-        e.preventDefault();
-        $(e.currentTarget).click();
-    });
-
-    // a11y: focus folder tree from top-bar on <enter>
-    $(document).on('keydown', '#io-ox-topbar .active-app a', function (e) {
-        if (e.which === 13) $('.folder-tree:visible .folder.selected').focus();
-    });
-
     debug('core: Loaded');
     ox.trigger('core:load');
 
@@ -227,10 +215,6 @@ define('io.ox/core/main', [
         launcherDropdown = $('.launcher-dropdown ul', topbar);
 
     topbar
-        .attr({
-            'aria-label': gt('Applications'),
-            'role': 'banner'
-        })
         // prevent dragging links
         .on('dragstart', false)
         // make system drop-down accessible
@@ -242,6 +226,12 @@ define('io.ox/core/main', [
         .end()
         .find('i.fa-bars').removeClass('fa-bars').addClass('fa-angle-double-right ');
 
+    launchers
+        .attr({
+            'role': 'navigation',
+            'aria-label': gt('Apps')
+        });
+
     // whatever ...
     gt.pgettext('app', 'Portal');
     gt.pgettext('app', 'Mail');
@@ -298,17 +288,23 @@ define('io.ox/core/main', [
         }
         $('li', launcherDropdown).hide();
 
+
         if (hidden > 0) {
+            // a11y: dropdown menu should only have role menu if it is shown
+            $('.dropdown-menu', launcherDropdown).removeAttr('aria-hidden');
             launcherDropDownIcon.show();
             for (i = hidden; i > 0; i--) {
                 $('li', launcherDropdown).eq(-i).show();
             }
+        } else {
+            // a11y: dropdown menu should only have role menu if it is shown
+            $('.dropdown-menu', launcherDropdown).attr('aria-hidden', true);
         }
     }, 100);
 
     // add launcher
     var addLauncher = function (side, label, fn, arialabel) {
-        var node = $('<li class="launcher" role="presentation">');
+        var node = $('<li class="launcher">');
 
         if (fn) {
             node.on('click', function (e) {
@@ -334,7 +330,7 @@ define('io.ox/core/main', [
         //construct
         node.append(function () {
             if (_.isString(label)) {
-                return $('<a href="#" class="apptitle" tabindex="1" role="menuitem">').text(/*#, dynamic*/gt.pgettext('app', label));
+                return $('<a href="#" class="apptitle" tabindex="1">').text(/*#, dynamic*/gt.pgettext('app', label));
             } else if (label[0].tagName === 'I') {
                 return $('<a>', {
                     href: '#',
@@ -507,6 +503,9 @@ define('io.ox/core/main', [
                             node = $('<span>').text(getString(countdown)),
                             countdownTimer = setInterval(function () {
                                 if (countdown <= 0) {
+                                    //make sure, this does not run again in a second
+                                    clearInterval(countdownTimer);
+
                                     logout({ autologout: true });
                                 } else {
                                     countdown--;
@@ -590,6 +589,11 @@ define('io.ox/core/main', [
             logout: logout.bind(null, { autologout: true })
         };
 
+        settings.on('change:autoLogout', function (ev, val) {
+            if (parseInt(val, 10) === 0) return ox.autoLogout.stop();
+            ox.autoLogout.start();
+        });
+
         start();
 
     }());
@@ -633,7 +637,9 @@ define('io.ox/core/main', [
                         node.find('.apptitle').append(placeholder.find('.topbar-launcherbadge')[0]);
                     }
                 }
+                var restoreFocus = placeholder.children('a')[0] === document.activeElement;
                 placeholder.remove();
+                if (restoreFocus) node.children('a').focus();
             }
         }
 
@@ -756,8 +762,13 @@ define('io.ox/core/main', [
             }
             launchers.children().removeClass('active-app')
                 .filter('[data-app-guid="' + model.guid + '"]').addClass('active-app');
+
             launcherDropdown.children().removeClass('active-app')
                 .filter('[data-app-guid="' + model.guid + '"]').addClass('active-app');
+
+            // A11y: Current app indicator for screen-readers
+            launchers.children().find('a > span.sr-only').remove();
+            launchers.children('.active-app').find('a').append($('<span class="sr-only">').text(gt('(current app)')));
         });
 
         ox.ui.apps.on('change:title', function (model, value) {
@@ -872,10 +883,6 @@ define('io.ox/core/main', [
                     requires: 'active_sync || caldav || carddav',
                     title: 'Upgrade your account',
                     customize: function () {
-                        this.$el.attr({
-                            'role': 'presentation'
-                        });
-
                         $('i', this.$el).css({ 'width': 'auto' });
                     }
                 });
@@ -883,7 +890,7 @@ define('io.ox/core/main', [
                 if (view.visible) {
                     this.append(
                         view.render().$el,
-                        $('<li class="divider" aria-hidden="true" role="presentation">')
+                        $('<li class="divider" role="separator">')
                     );
                 }
             }
@@ -982,13 +989,15 @@ define('io.ox/core/main', [
                 //replaced by module
                 var node = this;
                 node.append(
-                    $('<li class="divider" aria-hidden="true" role="presentation"></li>'),
-                    $('<li role="presentation">', { 'class': 'io-ox-specificHelp' }).append(
+                    $('<li class="divider" role="separator">'),
+                    $('<li role="presentation" class="io-ox-specificHelp">').append(
                         new HelpView({
-                            tabindex: '-1',
                             content: gt('Help'),
                             href: getHelp
-                        }).render().$el
+                        }).render().$el.attr({
+                            'role': 'menuitem',
+                            'tabindex': -1
+                        })
                     )
                 );
             }
@@ -999,7 +1008,7 @@ define('io.ox/core/main', [
             index: 290,
             draw: function () {
                 this.append(
-                    $('<li class="divider" aria-hidden="true" role="presentation">')
+                    $('<li class="divider" role="separator">')
                 );
             }
         });
@@ -1027,7 +1036,7 @@ define('io.ox/core/main', [
             index: 1000,
             draw: function () {
                 this.append(
-                    $('<li class="divider" aria-hidden="true" role="presentation"></li>'),
+                    $('<li class="divider" role="separator">'),
                     $('<li role="presentation">').append(
                         $('<a href="#" data-action="logout" role="menuitem" tabindex="-1">').text(gt('Sign out'))
                     )
@@ -1168,7 +1177,7 @@ define('io.ox/core/main', [
             id: 'default',
             draw: function () {
 
-                var rightbar = $('<ul class="launchers-secondary">');
+                var rightbar = $('<ul class="launchers-secondary">').attr('aria-label', gt('Actions'));
 
                 // right side
                 ext.point('io.ox/core/topbar/right').invoke('draw', rightbar);
@@ -1180,7 +1189,6 @@ define('io.ox/core/main', [
 
                 ext.point('io.ox/core/topbar/launchpad').invoke('draw');
                 ext.point('io.ox/core/topbar/favorites').invoke('draw');
-
                 $(window).resize(tabManager);
                 ox.on('recalculate-topbarsize', tabManager);
             }
@@ -1373,15 +1381,19 @@ define('io.ox/core/main', [
             _.url.hash({ m: null, f: null, i: null, '!!': undefined, '!': null });
 
             // always use portal on small devices!
-            if (_.device('small')) mobileAutoLaunchArray();
+            if (_.device('smartphone')) mobileAutoLaunchArray();
 
             var appURL = _.url.hash('app'),
                 manifest = appURL && ox.manifests.apps[getAutoLaunchDetails(appURL).app],
                 deeplink = looksLikeDeepLink && manifest && manifest.deeplink,
-                mailto = _.url.hash('mailto') !== undefined && (appURL === ox.registry.get('mail-compose').split('/').slice(0, -1).join('/') + ':compose');
+                mailto = _.url.hash('mailto') !== undefined && (appURL === ox.registry.get('mail-compose') + ':compose');
 
-            if (manifest && (manifest.refreshable || deeplink || mailto)) {
+            if (manifest && (manifest.refreshable || deeplink)) {
                 baton.autoLaunch = appURL.split(/,/);
+                // no manifest for mail compose, capabilities check is sufficient
+            } else if (capabilities.has('webmail') && mailto) {
+                // launch main mail app for mailto links
+                baton.autoLaunch = ['io.ox/mail/main'];
             } else {
                 // clear typical parameter?
                 if (manifest) _.url.hash({ app: null, folder: null, id: null });
@@ -1528,7 +1540,7 @@ define('io.ox/core/main', [
                         btn1, btn2;
 
                     $('#io-ox-core').append(
-                        dialog = $('<div class="io-ox-restore-dialog" tabindex="0">').append(
+                        dialog = $('<div class="io-ox-restore-dialog" tabindex="1">').append(
                             $('<div class="header">').append(
                                 $('<h3>').text(gt('Restore applications')),
                                 $('<div>').text(
@@ -1537,8 +1549,8 @@ define('io.ox/core/main', [
                             ),
                             $('<ul class="list-unstyled content">'),
                             $('<div class="footer">').append(
-                                btn1 = $('<button type="button" class="cancel btn btn-default">').text(gt('Cancel')),
-                                btn2 = $('<button type="button" class="continue btn btn-primary">').text(gt('Continue'))
+                                btn1 = $('<button type="button" class="cancel btn btn-default" tabindex="1">').text(gt('Cancel')),
+                                btn2 = $('<button type="button" class="continue btn btn-primary" tabindex="1">').text(gt('Continue'))
                             )
                         )
                     );
@@ -1682,9 +1694,16 @@ define('io.ox/core/main', [
                         // special case: open viewer too?
                         if (hash.app === 'io.ox/files' && hash.id !== undefined) {
                             require(['io.ox/core/viewer/main', 'io.ox/files/api'], function (Viewer, api) {
-                                api.get(hash).done(function (data) {
-                                    new Viewer().launch({ files: [data], folder: hash.folder });
-                                });
+                                folderAPI.get(hash.folder)
+                                    .done(function () {
+                                        api.get(hash).done(function (data) {
+                                            new Viewer().launch({ files: [data], folder: hash.folder });
+                                        });
+                                    })
+                                    .fail(function (error) {
+                                        _.url.hash('id', null);
+                                        notifications.yell(error);
+                                    });
                             });
                         }
                         // explicit call?
@@ -1816,6 +1835,7 @@ define('io.ox/core/main', [
             case 'MSG-1000':
             case 'MSG-1001':
             // INUSE (see bug 37218)
+            // falls through
             case 'MSG-1031':
                 notifications.yell(error);
                 break;
@@ -1848,7 +1868,10 @@ define('io.ox/core/main', [
         var check = function (code, regex) { return regex.test(code); },
             reCodes = [
                 // sharing warnings
-                /^SHR_NOT-\d{4}$/
+                /^SHR_NOT-\d{4}$/,
+                /^RSS-0007/,
+                // IMAP-specific on unified inbox folders (see Bug 50799)
+                /^MSG-1001/
             ];
         return function (code) {
             // return true in case at least one regex matched
