@@ -356,7 +356,7 @@ define('io.ox/core/permissions/permissions', [
                         isFolderAdmin = false;
                     }
 
-                    var options = { top: 60, width: 800, center: false, maximize: true, async: true, help: 'ox.appsuite.user.sect.dataorganisation.rights.defined.html#ox.appsuite.user.concept.rights.roles' };
+                    var options = { top: 60, width: 800, center: false, maximize: true, async: true, help: 'ox.appsuite.user.sect.dataorganisation.sharing.invitation.html#ox.appsuite.user.concept.sharing.invitation' };
                     if (_.device('!desktop')) {
                         options = { top: '40px', center: false, async: true };
                     }
