@@ -232,186 +232,6 @@ define('io.ox/core/tk/attachments', [
         }, options);
     }
 
-    /**
-     * Only used by mail and files: gui widget collecting files user wants to upload
-     * @param {object} options
-     * @param {object} baton
-     */
-    function EditableFileList(options, baton) {
-
-        var self = this,
-            counter = 0,
-            files = [],
-            $el = (options.$el || $('<div>').addClass('row'));
-
-        if (options.registerTo) {
-            _.each([].concat(options.registerTo), function (obj) {
-                obj.fileList = self;
-            });
-        }
-
-        _.extend(this, {
-
-            init: function () {
-                // add preview side-popup
-                this.sidepopup = new dialogs.SidePopup().delegate($el, '.attachment-preview', util.preview);
-                // destroy if removed from DOM
-                $el.on('dispose', this.destroy.bind(this));
-            },
-
-            destroy: function () {
-                this.sidepopup.undelegate($el).destroy();
-                this.sidepopup = $el = self = options = baton = null;
-            },
-
-            render: function () {
-                var self = this,
-                    nodes = $('<div>');
-                $el.empty();
-                if (files && files.length > 0) {
-                    nodes.css('margin-bottom', '20px');
-                }
-                _(files).each(function (file) {
-                    nodes.append(self.renderFile(file));
-                });
-                $el.addClass('io-ox-core-tk-attachment-list').prepend(nodes);
-                return this;
-            },
-
-            renderFile: function (file) {
-                var opt = {
-                    showpreview: options.preview && util.hasPreview(file) && baton.view && baton.view.rightside,
-                    rightside: (baton.view ? baton.view.rightside : undefined),
-                    labelmax: options.labelmax,
-                    ref: options.ref
-                };
-                return util.node.call(this, file, opt);
-            },
-
-            listChanged: function () {
-                this.empty();
-                this.render();
-            },
-
-            empty: function () {
-                //remove all nodes
-                $el.find('.file').parent().remove();
-            },
-
-            get: function (group) {
-                var list = [].concat(files);
-                if (group) {
-                    list = _.filter(list, function (item) {
-                        return item.group === group;
-                    });
-                }
-                return _.map(list, function (file) {
-                    return file.file;
-                });
-            },
-
-            getNode: function () {
-                return $el;
-            },
-
-            clear: function () {
-                files = [];
-                this.listChanged();
-            },
-
-            add: function (file) {
-                var result = this.checkQuota(file);
-                if (result && result.error) {
-                    notifications.yell('error', result.error);
-                }
-            },
-
-            checkQuota: function (file) {
-                var self = this,
-                    list = [].concat(file),
-                    properties = settings.get('properties'),
-                    total = 0,
-                    maxFileSize,
-                    quota,
-                    usage,
-                    isMail = (baton.app && baton.app.app.attributes.name === 'io.ox/mail/compose'),
-                    filesLength = files.length,
-                    autoPublish = require('io.ox/core/capabilities').has('publish_mail_attachments'),
-                    result = { added: [] };
-
-                if (!list.length) return;
-
-                //check
-                if (isMail) {
-                    maxFileSize = autoPublish ? -1 : properties.attachmentQuotaPerFile;
-                    quota = autoPublish ? -1 : properties.attachmentQuota;
-                    usage = 0;
-                } else {
-                    maxFileSize = properties.infostoreMaxUploadSize;
-                    quota = properties.infostoreQuota;
-                    usage = properties.infostoreUsage;
-                }
-
-                _.find(list, function (item) {
-
-                    var fileTitle = item.filename || item.name || item.subject,
-                        fileSize = item.file_size || item.size;
-
-                    if (fileSize) {
-                        total += fileSize;
-                        if (maxFileSize > 0 && fileSize > maxFileSize) {
-                            result.error = gt('The file "%1$s" cannot be uploaded because it exceeds the maximum file size of %2$s', fileTitle, strings.fileSize(maxFileSize));
-                            result.reason = 'filesize';
-                            return true;
-                        }
-                        if (quota > 0 && (total > (quota - usage))) {
-                            result.error = gt('The file "%1$s" cannot be uploaded because it exceeds the quota limit of %2$s', fileTitle, strings.fileSize(quota));
-                            result.reason = 'quota';
-                            return true;
-                        }
-                        if (isMail && autoPublish) {
-                            if (properties.infostoreMaxUploadSize > 0 && fileSize > properties.infostoreMaxUploadSize) {
-                                result.error = gt('The file "%1$s" cannot be uploaded because it exceeds the attachment publication maximum file size of %2$s', fileTitle, strings.fileSize(properties.infostoreMaxUploadSize));
-                                result.reason = 'filesizeAutoPublish';
-                                return true;
-                            }
-                            if (properties.infostoreQuota > 0 && (total > (properties.infostoreQuota - properties.infostoreUsage))) {
-                                result.error = gt('The file "%1$s" cannot be uploaded because it exceeds the infostore quota limit of %2$s', fileTitle, strings.fileSize(properties.infostoreQuota));
-                                result.reason = 'quotaAutoPublish';
-                                return true;
-                            }
-                        }
-                    }
-
-                    result.added.push({
-                        file: (oldMode && item.hiddenField ? item.hiddenField : item),
-                        name: fileTitle,
-                        size: fileSize,
-                        group: item.group || 'unknown',
-                        cid: counter++
-                    });
-                });
-
-                files = files.concat(result.added);
-                if (filesLength !== files.length) self.listChanged();
-
-                return result;
-            },
-
-            remove: function (attachment) {
-                files = _.filter(files, function (att) {
-                    return att.cid !== attachment.cid;
-                });
-                //remove hidden input form field
-                if (attachment.file instanceof $ && attachment.file[0].tagName === 'INPUT') {
-                    attachment.file.remove();
-                }
-                this.listChanged();
-            }
-        }, options);
-
-        this.init();
-    }
 
     function AttachmentListOld(options) {
         var self = this;
@@ -508,7 +328,6 @@ define('io.ox/core/tk/attachments', [
 
     return {
         EditableAttachmentList: EditableAttachmentList,
-        EditableFileList: EditableFileList,
         AttachmentList: AttachmentListOld,
         fileUploadWidget: fileUploadWidget
     };
