@@ -85,6 +85,7 @@ define.async('io.ox/core/tk/contenteditable-editor', [
                     var node = nodes[i], ai = 0, attr;
                     while (attr = node.attributes[ai++]) {
                         if (/^on/i.test(attr.name)) { node.removeAttribute(attr.name); }
+                        if (attr.name === 'data-toggle') { node.removeAttribute(attr.name); }
                     }
                 }
                 e.content = tmp.innerHTML;
@@ -243,7 +244,7 @@ define.async('io.ox/core/tk/contenteditable-editor', [
             advanced: 'styleselect fontselect fontsizeselect | forecolor backcolor | link image',
             toolbar2: '',
             toolbar3: '',
-            plugins: 'autolink oximage oxpaste oxdrop link paste textcolor emoji lists',
+            plugins: 'autolink oximage oxpaste oxdrop link paste textcolor emoji lists code',
             theme: 'unobtanium',
             skin: 'lightgray'
         }, opt);
@@ -277,9 +278,10 @@ define.async('io.ox/core/tk/contenteditable-editor', [
         }
 
         var options = {
-            script_url: (window.cordova ? ox.localFileRoot : ox.base) + '/apps/3rd.party/tinymce/tinymce.jquery.min.js',
+            script_url: (window.cordova ? ox.localFileRoot : ox.base) + '/apps/3rd.party/tinymce/tinymce.min.js',
 
             extended_valid_elements: 'blockquote[type]',
+            invalid_elements: 'object,iframe,script',
 
             inline: true,
 
@@ -383,15 +385,16 @@ define.async('io.ox/core/tk/contenteditable-editor', [
                 }
 
                 var h = $(window).height(),
-                    top = editor.offset().top;
+                    top = editor.offset().top,
+                    bottomMargin = (el.closest('.io-ox-mail-compose-window').hasClass('header-top') ? 39 : 104);
 
-                editor.css('min-height', h - top - 40 + 'px');
+                editor.css('min-height', h - top - bottomMargin + 'px');
                 if (opt.css) editor.css(opt.css);
 
                 var th = $(fixed_toolbar + ' > div').height(),
                     w = $(fixed_toolbar).next().outerWidth();
 
-                if (th) $(fixed_toolbar).css('height', th + 1);
+                if (th) $(fixed_toolbar).css('height', th);
                 if (w) $(fixed_toolbar).css('width', w);
                 return;
             }, 30),
@@ -591,7 +594,11 @@ define.async('io.ox/core/tk/contenteditable-editor', [
 
         // allow jQuery access
         this.find = function (selector) {
-            return $(ed.getDoc()).find(selector);
+            return $(ed.getBody()).find(selector);
+        };
+
+        this.children = function (selector) {
+            return $(ed.getBody()).children(selector);
         };
 
         this.replaceContent = function (str, rep) {
