@@ -14,8 +14,9 @@
 define('io.ox/core/tk/dialogs', [
     'io.ox/core/event',
     'io.ox/core/extensions',
+    'io.ox/core/a11y',
     'io.ox/backbone/mini-views/help'
-], function (Events, ext, HelpView) {
+], function (Events, ext, a11y, HelpView) {
 
     'use strict';
 
@@ -176,9 +177,7 @@ define('io.ox/core/tk/dialogs', [
 
             fnKey = function (e) {
 
-                var items, focus, index;
-
-                switch (e.which || e.keyCode) {
+                switch (e.which) {
                     case 27:
                         // ESC
                         if (!isBusy && self.getBody().find('.open > .dropdown-menu').length === 0) {
@@ -198,27 +197,33 @@ define('io.ox/core/tk/dialogs', [
                         break;
                     case 9:
                         // tab
-                        if (o.tabTrap) {
-                            // get items first
-                            items = $(this).find('[tabindex][tabindex!="-1"][disabled!="disabled"]:visible');
-                            if (items.length) {
-                                e.preventDefault();
-                                focus = $(document.activeElement);
-                                index = (items.index(focus) >= 0) ? items.index(focus) : 0;
-                                index += (e.shiftKey) ? -1 : 1;
-
-                                if (index >= items.length) {
-                                    index = 0;
-                                } else if (index < 0) {
-                                    index = items.length - 1;
-                                }
-                                items.eq(index).focus();
-                            }
-                        }
+                        if (o.tabTrap) a11y.trapFocus(this, e);
                         break;
                     default:
                         break;
                 }
+            },
+
+            /*
+             * This function hides the siblings of the element itself and the siblings of all parents (except body) from screen-readers
+             * by setting aria-hidden="true". It also registers a listener, which restores the aria-hidden attribute after the
+             * dialog has been closed.
+             */
+            ariaHideSiblings = function () {
+                // add aria-hidden="true" to all siblings of the wrapper and all parents of the wrapper
+                $(nodes.wrapper).parentsUntil('body').add(nodes.wrapper).siblings().each(function () {
+                    var el = $(this);
+                    // save aria-hidden value for later restoring
+                    el.data('ox-restore-aria-hidden', el.attr('aria-hidden'));
+                }).attr('aria-hidden', true);
+                self.on('close', function () {
+                    // restore aria-hidden and remove restoring information
+                    $(nodes.wrapper).parentsUntil('body').add(nodes.wrapper).siblings().removeAttr('aria-hidden').each(function () {
+                        var el = $(this);
+                        if (el.data('ox-restore-aria-hidden')) el.attr('aria-hidden', el.data('ox-restore-aria-hidden'));
+                        el.removeData('ox-restore-aria-hidden');
+                    });
+                });
             };
         // pass options to ext point
         ext.point('io.ox/core/dialogs').invoke('customize', this, o);
@@ -367,6 +372,18 @@ define('io.ox/core/tk/dialogs', [
             return addButton(action, label, dataaction, options);
         };
 
+        this.addCheckbox = function (label, action, status) {
+            nodes.footer.prepend(
+                $('<div>').addClass('checkbox').append(
+                    $('<div>').addClass('controls'),
+                    $('<label>').text(label).prepend(
+                        $('<input type="checkbox" tabindex="1">').attr({ 'data-action': action, 'checked': status })
+                    )
+                )
+            );
+            return this;
+        };
+
         this.close = function () {
             if (!o || o.async) {
                 close();
@@ -536,6 +553,7 @@ define('io.ox/core/tk/dialogs', [
                 callback.call(nodes.popup, this);
             }
 
+            ariaHideSiblings();
             this.trigger('show');
 
             return deferred;
@@ -765,9 +783,7 @@ define('io.ox/core/tk/dialogs', [
             })
             .on('keydown', function (e) {
                 // enter
-                if ((e.keyCode || e.which) === 13) {
-                    $(this).trigger('click');
-                }
+                if (e.which === 13) $(this).trigger('click');
             });
 
         function getPct(x) {
