@@ -163,15 +163,22 @@ define('io.ox/core/tk/list', [
             this.$el.scrollTop(0);
         },
 
+        updateEmptyMessage: function () {
+            var baton = ext.Baton({ app: this.app, options: this.options }),
+                point = ext.point(this.ref + '/empty'),
+                isEmpty = !this.collection.length;
+            if (isEmpty && point.keys().length) {
+                point.invoke('draw', this.$('.message-empty'), baton);
+            }
+            this.$('.message-empty-container').toggleClass('hidden', !isEmpty);
+        },
+
         onReset: function () {
             this.empty();
             this.$el.append(
                 this.collection.map(this.renderListItem, this)
             );
 
-            // manage empty message
-            this.$el.find('.message-empty-container').toggleClass('hidden', this.collection.length > 0);
-
             this.trigger('reset', this.collection, this.firstReset);
             if (this.firstReset) {
                 this.trigger('first-reset', this.collection);
@@ -201,9 +208,6 @@ define('io.ox/core/tk/list', [
             if (this.selection) this.selection.remove(cid, li);
             li.remove();
 
-            // manage the empty message
-            this.$el.find('.message-empty-container').toggleClass('hidden', this.collection.length > 0);
-
             this.trigger('remove-mobile');
             // selection changes if removed item was selected
             if (isSelected) this.selection.triggerChange();
@@ -246,7 +250,7 @@ define('io.ox/core/tk/list', [
                 .remove();
 
             // manage the empty message
-            this.$el.find('.message-empty-container').toggleClass('hidden', this.collection.length > 0);
+            this.updateEmptyMessage();
 
             if (!selected) return;
 
@@ -263,31 +267,22 @@ define('io.ox/core/tk/list', [
                 return node && parseInt(node.getAttribute('data-index'), 10);
             }
 
+            // fix for bugs #51594 and #51596
+            // [L3] Drive opens wrong files directly after upload - wrong link in UI
+            //
             return function () {
                 // needless cause added models not drawn yet (debounced renderListItems)
                 if (this.queue.list.length) return;
 
-                var dom, sorted, i, j, length, node, reference, index, done = {};
+                var items, detached, sorted;
 
                 // sort all nodes by index
-                dom = this.getItems().toArray();
-                sorted = _(dom).sortBy(getIndex);
+                items = this.getItems();
+                if (items.length > 1) {
+                    detached = items.detach();
+                    sorted = _.sortBy(detached, getIndex);
 
-                // apply sorting (step by step to keep focus)
-                // the arrays "dom" and "sorted" always have the same length
-                for (i = 0, j = 0, length = sorted.length; i < length; i++) {
-                    node = sorted[i];
-                    reference = dom[j];
-                    // mark as processed
-                    done[i] = true;
-                    // same element?
-                    if (node === reference) {
-                        // fast forward "j" if pointing at processed items
-                        do { index = getIndex(dom[++j]); } while (done[index]);
-                    } else if (reference) {
-                        // change position in dom
-                        this.el.insertBefore(node, reference);
-                    }
+                    this.$el.append(sorted);
                 }
             };
         }()),
@@ -449,7 +444,7 @@ define('io.ox/core/tk/list', [
 
             // selection?
             if (this.options.selection) {
-                this.selection = new Selection(this);
+                this.selection = new Selection(this, this.options.selection);
                 events = {
                     'focus .list-item': 'onItemFocus',
                     'blur .list-item': 'onItemBlur',
@@ -528,8 +523,10 @@ define('io.ox/core/tk/list', [
                 });
             }
 
-            // respond to window resize (see bug 37728)
-            $(window).on('resize.list-view', this.onScroll.bind(this));
+            if (this.options.pagination) {
+                // respond to window resize (see bug 37728)
+                $(window).on('resize.list-view', this.onScroll.bind(this));
+            }
 
             this.on('dispose', function () {
                 $(window).off('resize.list-view');
@@ -586,6 +583,12 @@ define('io.ox/core/tk/list', [
                 // reload
                 'reload': this.idle
             });
+            this.listenTo(collection, {
+                // backbone
+                'add': this.updateEmptyMessage,
+                'remove': this.updateEmptyMessage,
+                'reset': this.updateEmptyMessage
+            });
             if (this.selection) this.selection.reset();
             this.trigger('collection:set');
             return this;
