@@ -47,8 +47,6 @@ define('io.ox/core/tk/typeahead', [
             },
             click: $.noop,
             tabindex: 1,
-            // Max limit for draw operation in dropdown
-            maxResults: 25,
             // Select first element on result callback
             autoselect: true,
             // Typeahead will not show a hint
@@ -75,6 +73,20 @@ define('io.ox/core/tk/typeahead', [
                 'dropdown': 'closed'
             });
 
+            if (o.apiOptions) {
+                // limit per autocomplete/search api
+                var limit  = o.apiOptions.limit !== undefined ? o.apiOptions.limit : 10;
+                o.apiOptions.limit = limit;
+
+                // overall limit
+                if (!o.maxResults) {
+                    // Max limit for draw operation in dropdown depending on used apis
+                    o.maxResults = limit * _(o.apiOptions).filter(function (val) { return val === true; }).length;
+                }
+            } else {
+                o.maxResults = 25;
+            }
+
             // use a clone instead of shared default-options-object
             o = this.options = $.extend({}, this.options, o || {});
 
@@ -91,6 +103,10 @@ define('io.ox/core/tk/typeahead', [
 
             this.api = new AutocompleteAPI(o.apiOptions);
 
+            this.listenTo(ox, 'refresh^', function () {
+                this.api.cache = {};
+            });
+
             this.typeaheadOptions = [{
                 autoselect: o.autoselect,
                 // The minimum character length needed before suggestions start getting rendered
@@ -131,7 +147,7 @@ define('io.ox/core/tk/typeahead', [
                             if (dropdown.is(':visible')) {
                                 self.model.set('dropdown', 'opened');
                             }
-                            self.trigger('typeahead-custom:dropdown-rendered');
+                            if (query) self.trigger('typeahead-custom:dropdown-rendered', dropdown);
                         });
                         self.registered = true;
                     }
@@ -157,7 +173,8 @@ define('io.ox/core/tk/typeahead', [
 
             this.$el.attr({
                 tabindex: this.options.tabindex,
-                placeholder: this.options.placeholder
+                placeholder: this.options.placeholder,
+                'aria-label': this.options.ariaLabel
             }).on({
                 // dirty hack to get a reliable info about open/close state
                 'typeahead:closed': function () {
