@@ -127,8 +127,17 @@ define('io.ox/core/viewer/views/mainview', [
 
         // handler for keyboard events on the viewer
         onKeydown: function (event) {
-            event.stopPropagation();
-            var viewerRootEl = this.$el;
+            var viewerRootEl = this.$el,
+                self = this,
+                handleChangeSlide = _.throttle(function (direction) {
+                    if (direction === 'right') {
+                        self.displayerView.swiper.slideNext();
+                    } else {
+                        self.displayerView.swiper.slidePrev();
+                    }
+                    self.displayerView.focusActiveSlide();
+                }, 200);
+
             // manual TAB traversal handler. 'Traps' TAB traversal inside the viewer root component.
             function tabHandler(event) {
                 var tabableActions = viewerRootEl.find('[tabindex]:not([tabindex^="-"]):visible'),
@@ -154,19 +163,17 @@ define('io.ox/core/viewer/views/mainview', [
                 case 27: // ESC key
                     var escTarget = $(event.target),
                         isDropdownMenuItem = escTarget.parents('.dropdown-menu').length > 0,
-                        isDropdownToggler = escTarget.attr('data-toggle') === 'dropdown';
+                        isDropdownToggler = escTarget.attr('data-toggle') === 'dropdown' && escTarget.attr('aria-expanded') === 'true';
                     // close the viewer only if user is not on a dropdown menu, or a dropdown menu item
                     if (!isDropdownMenuItem && !isDropdownToggler) {
                         this.closeViewer();
                     }
                     break;
                 case 37: // left arrow
-                    this.displayerView.swiper.slidePrev();
-                    this.displayerView.focusActiveSlide();
+                    handleChangeSlide('left');
                     break;
                 case 39: // right arrow
-                    this.displayerView.swiper.slideNext();
-                    this.displayerView.focusActiveSlide();
+                    handleChangeSlide('right');
                     break;
                 case 33: // page up
                     event.preventDefault();
