@@ -14,6 +14,7 @@ define('io.ox/core/viewer/views/sidebarview', [
     'io.ox/backbone/disposable',
     'io.ox/core/viewer/util',
     'io.ox/files/api',
+    'io.ox/core/folder/api',
     'io.ox/core/dropzone',
     'io.ox/core/capabilities',
     'io.ox/core/viewer/settings',
@@ -27,7 +28,7 @@ define('io.ox/core/viewer/views/sidebarview', [
     'io.ox/core/extPatterns/links',
     // prefetch cause all views need the base view
     'io.ox/core/viewer/views/sidebar/panelbaseview'
-], function (DisposableView, Util, FilesAPI, Dropzone, Capabilities, ViewerSettings, ThumbnailView, FileInfoView, FileDescriptionView, FileVersionsView, UploadNewVersionView, ext, gt, links) {
+], function (DisposableView, Util, FilesAPI, folderApi, Dropzone, Capabilities, ViewerSettings, ThumbnailView, FileInfoView, FileDescriptionView, FileVersionsView, UploadNewVersionView, ext, gt, links) {
 
     'use strict';
 
@@ -50,6 +51,8 @@ define('io.ox/core/viewer/views/sidebarview', [
         id: 'file-description',
         index: 200,
         draw: function (baton) {
+            //check if supported
+            if (!(baton.model.isFile() && folderApi.pool.models[baton.data.folder_id] && folderApi.pool.models[baton.data.folder_id].supports('extended_metadata'))) return;
             this.append(new FileDescriptionView({ model: baton.model }).render().el);
         }
     });
@@ -58,6 +61,8 @@ define('io.ox/core/viewer/views/sidebarview', [
         id: 'file-versions',
         index: 300,
         draw: function (baton) {
+            //check if supported
+            if (!(baton.model.isFile() && folderApi.pool.models[baton.data.folder_id] && folderApi.pool.models[baton.data.folder_id].can('add:version'))) return;
             this.append(new FileVersionsView({ model: baton.model }).render().el);
         }
     });
@@ -66,6 +71,8 @@ define('io.ox/core/viewer/views/sidebarview', [
         id: 'upload-new-version',
         index: 400,
         draw: function (baton) {
+            //check if supported
+            if (!(baton.model.isFile() && folderApi.pool.models[baton.data.folder_id] && folderApi.pool.models[baton.data.folder_id].can('add:version'))) return;
             this.append(new UploadNewVersionView({ model: baton.model }).render().el);
         }
     }));
@@ -241,7 +248,8 @@ define('io.ox/core/viewer/views/sidebarview', [
          * and version history.
          */
         renderSections: function () {
-            var detailPane = this.$('.detail-pane');
+
+            var detailPane = this.$('.detail-pane'), folder = folderApi.pool.models[this.model.get('folder_id')];
             // remove previous sections
             detailPane.empty();
             // remove dropzone handler
@@ -255,8 +263,8 @@ define('io.ox/core/viewer/views/sidebarview', [
 
             // load file details
             this.loadFileDetails();
-            // add dropzone for drive files
-            if (this.model.isFile()) {
+            // add dropzone for drive files if the folder supports new versions
+            if (this.model.isFile() && folder && folder.can('add:version')) {
                 this.zone = new Dropzone.Inplace({
                     //#. %1$s is the filename of the current file
                     caption: gt('Drop new version of "%1$s" here', this.model.get('filename'))
@@ -290,7 +298,7 @@ define('io.ox/core/viewer/views/sidebarview', [
          */
         render: function (model) {
             // a11y
-            this.$el.attr({ tabindex: -1, role: 'complementary' }); // TODO: check if we need to set role 'tablist' now instead
+            this.$el.attr({ tabindex: -1, role: 'complementary', 'aria-label': gt('Details') });
             // set device type
             Util.setDeviceClass(this.$el);
             // attach the touch handlers
