@@ -12,15 +12,20 @@
  */
 /* global blankshield */
 define('io.ox/files/actions', [
+
+    'io.ox/core/folder/api',
     'io.ox/files/api',
+    'io.ox/files/util',
+    'io.ox/core/api/filestorage',
+
     'io.ox/core/extensions',
     'io.ox/core/extPatterns/links',
     'io.ox/core/capabilities',
-    'io.ox/files/util',
-    'io.ox/core/folder/api',
+
     'settings!io.ox/files',
     'gettext!io.ox/files'
-], function (api, ext, links, capabilities, util, folderAPI, settings, gt) {
+
+], function (folderAPI, api, util, filestorageApi, ext, links, capabilities, settings, gt) {
 
     'use strict';
 
@@ -220,6 +225,7 @@ define('io.ox/files/actions', [
                 !_.isEmpty(e.baton.data),
                 e.collection.has('some', 'items'),
                 e.baton.openedBy !== 'io.ox/mail/compose',
+                util.isFolderType('!attachmentView', e.baton),
                 util.isFolderType('!trash', e.baton)
             );
         },
@@ -261,6 +267,7 @@ define('io.ox/files/actions', [
                 _.device('!smartphone'),
                 !_.isEmpty(e.baton.data),
                 e.collection.has('some', 'items'),
+                util.isFolderType('!attachmentView', e.baton),
                 util.isFolderType('!trash', e.baton)
             );
         },
@@ -336,12 +343,16 @@ define('io.ox/files/actions', [
     new Action('io.ox/files/actions/lock', {
         capabilities: '!alone',
         requires: function (e) {
-            return _.device('!smartphone') &&
+
+            var preCondition = _.device('!smartphone') &&
                 !_.isEmpty(e.baton.data) &&
                 e.collection.has('some', 'modify', 'items') &&
                 // hide in mail compose preview
                 (e.baton.openedBy !== 'io.ox/mail/compose') &&
                 util.hasStatus('!locked', e);
+
+            // only test the second condition when files are selected, so 'some' and 'items' must be checked in the preCondition
+            return preCondition && folderAPI.get(_.first(e.baton.models).get('folder_id')).then(function (fileModel) { return !folderAPI.isExternalFileStorage(fileModel); });
         },
         multiple: function (list) {
             ox.load(['io.ox/files/actions/lock-unlock']).done(function (action) {
@@ -353,12 +364,16 @@ define('io.ox/files/actions', [
     new Action('io.ox/files/actions/unlock', {
         capabilities: '!alone',
         requires: function (e) {
-            return _.device('!smartphone') &&
+
+            var preCondition = _.device('!smartphone') &&
                 !_.isEmpty(e.baton.data) &&
                 e.collection.has('some', 'modify', 'items') &&
                 // hide in mail compose preview
                 (e.baton.openedBy !== 'io.ox/mail/compose') &&
                 util.hasStatus('lockedByMe', e);
+
+            // only test the second condition when files are selected, so 'some' and 'items' must be checked in the preCondition
+            return preCondition && folderAPI.get(_.first(e.baton.models).get('folder_id')).then(function (fileModel) { return !folderAPI.isExternalFileStorage(fileModel); });
         },
         multiple: function (list) {
             ox.load(['io.ox/files/actions/lock-unlock']).done(function (action) {
@@ -423,12 +438,42 @@ define('io.ox/files/actions', [
         }
     });
 
+    new Action('io.ox/files/actions/save-as-pdf', {
+        capabilities: 'document_preview', // document converter.
+        requires: function (e) {
+            // one?
+            if (!e.collection.has('one')) return false;
+
+            // hide in mail compose preview
+            if (e.baton.openedBy === 'io.ox/mail/compose') return false;
+
+            // is folder?
+            if (e.collection.has('folders')) return false;
+
+            var
+                model         = e.baton.models[0];
+          //    isAccessWrite = folderAPI.can('create', folderAPI.pool.models[model.get('folder_id')].toJSON());
+          //
+          //if (!isAccessWrite(e)) return false;
+
+            // preferred variant over >> return (model.isFile() && !model.isPDF()); <<
+            return (model.isFile() && (model.isOffice() || model.isText()));
+        },
+        action: function (baton) {
+            // files use the file rename action
+            ox.load(['io.ox/files/actions/save-as-pdf']).done(function (action) {
+                action(baton);
+            });
+        }
+    });
+
     new Action('io.ox/files/actions/edit-description', {
         requires: function (e) {
             if (!e.collection.has('one', 'items')) return false;
             if (util.hasStatus('lockedByOthers', e)) return false;
             // hide in mail compose preview
             if (e.baton.openedBy === 'io.ox/mail/compose') return false;
+            if (!(folderAPI.pool.getModel(e.baton.data.folder_id || e.baton.data[0].folder_id).supports('extended_metadata'))) return false;
             // access on folder?
             if (e.collection.has('modify')) return true;
             // check object permission
@@ -444,7 +489,8 @@ define('io.ox/files/actions', [
     new Action('io.ox/files/actions/upload-new-version', {
         requires: function (e) {
             // hide in mail compose preview and only when file backend supports version comments
-            return e.collection.has('one', 'modify', 'items') && util.hasStatus('!lockedByOthers', e) && (e.baton.openedBy !== 'io.ox/mail/compose') && COMMENTS;
+            return e.collection.has('one', 'modify', 'items') && util.hasStatus('!lockedByOthers', e) && (e.baton.openedBy !== 'io.ox/mail/compose') && COMMENTS &&
+                   folderAPI.pool.getModel(e.baton.data.folder_id || e.baton.data[0].folder_id) && folderAPI.pool.getModel(e.baton.data.folder_id || e.baton.data[0].folder_id).can('add:version');
         },
         action: function (baton) {
             ox.load(['io.ox/files/actions/upload-new-version']).done(function (action) {
@@ -468,36 +514,57 @@ define('io.ox/files/actions', [
                 ox.load(['io.ox/files/actions/move-copy']).done(function (action) {
                     var options = {
                         type: type,
+                        fullResponse: true,
                         label: label,
                         success: success,
-                        successCallback: function (response) {
+                        successCallback: function (response, apiInput) {
                             if (!_.isString(response)) {
-                                var conflicts = { warnings: [] };
-                                if (_.isObject(response)) {
+                                var conflicts = { warnings: [] },
+                                    filesLeft = [];
+
+                                if (!_.isArray(response)) {
                                     response = [response];
                                 }
                                 // find possible conflicts with filestorages and offer a dialog with ignore warnings option see(Bug 39039)
                                 _(response).each(function (error) {
                                     if (error.error) {
-                                        if (error.error.categories === 'CONFLICT' && (error.error.code === 'FILE_STORAGE-0045' || error.error.code === 'FLD-1038')) {
+                                        if (error.error.categories === 'CONFLICT' && (error.error.code.indexOf('FILE_STORAGE') === 0 || error.error.code === 'FLD-1038')) {
                                             if (!conflicts.title) {
                                                 conflicts.title = error.error.error;
                                             }
-                                            if (_.isObject(error.error.warnings)) {
-                                                conflicts.warnings.push(error.error.warnings.error);
-                                            } else {
+
+                                            if (_.isArray(error.error.warnings)) {
                                                 _(error.error.warnings).each(function (warning) {
                                                     conflicts.warnings.push(warning.error);
+                                                    if (type === 'move' && !_(filesLeft).findWhere({ id: warning.error_params[3] })) {
+                                                        filesLeft.push(_(list).findWhere({ id: warning.error_params[3] }));
+                                                    }
                                                 });
+                                            } else {
+                                                conflicts.warnings.push(error.error.warnings.error);
+                                                if (type === 'move' && !_(filesLeft).findWhere({ id: error.error.warnings.error_params[3] })) {
+                                                    filesLeft.push(_(list).findWhere({ id: error.error.warnings.error_params[3] }));
+                                                }
+                                            }
+                                            // unfortunately move and copy responses do nt have the same structure
+                                            if (type === 'copy') {
+                                                filesLeft.push(_(list).findWhere({ id: error.error.error_params[1] }));
                                             }
                                         }
                                     }
                                 });
-                                if (conflicts.title) {
+
+                                if (conflicts.title && filesLeft.length) {
                                     require(['io.ox/core/tk/filestorageUtil'], function (filestorageUtil) {
                                         filestorageUtil.displayConflicts(conflicts, {
                                             callbackIgnoreConflicts: function () {
-                                                api[type](list, baton.target, true);
+                                                // if folderpicker is used baton.target is undefined (that's why the folderpicker is needed), use the previous apiInput to get the correct folder
+                                                api[type](filesLeft, baton.target || apiInput.target, true);
+                                            },
+                                            callbackCancel: function () {
+                                                if (baton.data[0].folder_id) {
+                                                    folderAPI.reload(baton.data[0].folder_id);
+                                                }
                                             }
                                         });
                                     });
@@ -509,7 +576,7 @@ define('io.ox/files/actions', [
                                 }
                             } else {
                                 require(['io.ox/core/yell'], function (yell) {
-                                    yell(response);
+                                    yell('error', response);
                                 });
                             }
                         }
@@ -733,6 +800,16 @@ define('io.ox/files/actions', [
 
     ext.point('io.ox/files/links/inline').extend(new links.Link({
         id: 'open',
+        enabled: _.device('!IE'),
+        index: index += 100,
+        prio: 'lo',
+        mobile: 'hi',
+        label: gt('Open in browser'),
+        ref: 'io.ox/files/actions/open'
+    }));
+
+    ext.point('io.ox/files/links/inline').extend(new links.Link({
+        id: 'openviewer',
         index: index += 100,
         prio: 'hi',
         mobile: 'hi',
@@ -821,7 +898,7 @@ define('io.ox/files/actions', [
         id: 'add-to-portal',
         index: index += 100,
         prio: 'lo',
-        mobile: 'lo',
+        mobile: 'none',
         label: gt('Add to portal'),
         ref: 'io.ox/files/actions/add-to-portal',
         section: 'share'
@@ -867,6 +944,16 @@ define('io.ox/files/actions', [
         section: 'edit'
     }));
 
+    //ext.point('io.ox/files/links/inline').extend(new links.Link({
+    //    id: 'save-as-pdf',
+    //    index: index += 100,
+    //    prio: 'lo',
+    //    mobile: 'lo',
+    //    label: gt('Save as PDF'),
+    //    ref: 'io.ox/files/actions/save-as-pdf',
+    //    section: 'save-as'
+    //}));
+
     ext.point('io.ox/files/links/inline').extend(new links.Link({
         id: 'move',
         index: index += 100,
