@@ -20,10 +20,11 @@ define('io.ox/files/api', [
     'io.ox/core/api/collection-pool',
     'io.ox/core/api/collection-loader',
     'io.ox/core/capabilities',
+    'io.ox/core/extensions',
     'settings!io.ox/core',
     'settings!io.ox/files',
     'gettext!io.ox/files'
-], function (http, folderAPI, backbone, Pool, CollectionLoader, capabilities, coreSettings, settings, gt) {
+], function (http, folderAPI, backbone, Pool, CollectionLoader, capabilities, ext, coreSettings, settings, gt) {
 
     'use strict';
 
@@ -125,7 +126,7 @@ define('io.ox/files/api', [
         },
 
         isOffice: function (type) {
-            return /^application\/(msword|vnd.ms-word|vnd.ms-excel|vnd.ms-powerpoint|vnd.oasis|vnd.openxmlformats)/.test(type || this.getMimeType());
+            return /^application\/(msword|excel|powerpoint|vnd\.(ms-word|ms-excel|ms-powerpoint|oasis|openxmlformats))/.test(type || this.getMimeType());
         },
 
         isPDF: function (type) {
@@ -137,7 +138,7 @@ define('io.ox/files/api', [
         },
 
         isPresentation: function (type) {
-            return /^application\/vnd.(ms-powerpoint|openxmlformats-officedocument.presentationml|oasis.opendocument.presentation)/.test(type || this.getMimeType());
+            return /^application\/(powerpoint|vnd.(ms-powerpoint|openxmlformats-officedocument.presentationml|oasis.opendocument.presentation))/.test(type || this.getMimeType());
         },
 
         isGuard: function () {
@@ -322,9 +323,10 @@ define('io.ox/files/api', [
         var url = ox.apiRoot + '/files',
             folder = encodeURIComponent(file.folder_id),
             id = encodeURIComponent(file.id),
-            version = file.version !== undefined && options.version !== false ? '&version=' + file.version : '',
+            sessionData = '&user=' + ox.user_id + '&context=' + ox.context_id + '&sequence=' + file.last_modified,
+            version = file.version !== undefined && options.version !== false && options.version !== null ? '&version=' + file.version : '',
             // basic URL
-            query = '?action=document&folder=' + folder + '&id=' + id + version,
+            query = '?action=document&folder=' + folder + '&id=' + id + version + sessionData,
             // file name
             name = file.filename ? '/' + encodeURIComponent(file.filename) : '',
             // scaling options
@@ -344,7 +346,7 @@ define('io.ox/files/api', [
             case 'preview':
                 return (file.meta && file.meta.previewUrl) || url + query + '&delivery=view' + scaling + '&format=preview_image&content_type=image/jpeg';
             case 'cover':
-                return ox.apiRoot + '/image/file/mp3Cover?folder=' + folder + '&id=' + id + scaling + '&content_type=image/jpeg&' + buster;
+                return ox.apiRoot + '/image/file/mp3Cover?folder=' + folder + '&id=' + id + scaling + sessionData + '&content_type=image/jpeg&' + buster;
             case 'play':
                 return url + query + '&delivery=view';
             // open/view
@@ -360,7 +362,17 @@ define('io.ox/files/api', [
     var pool = Pool.create('files', { Collection: api.Collection, Model: api.Model });
 
     // guess 23 is "meta"
-    var allColumns = '1,2,3,5,20,23,108,700,702,703,704,705,707,711,7040';
+    var allColumns = '1,2,3,5,20,23,108,700,702,703,704,705,707,711,7040',
+        allVersionColumns = http.getAllColumns('files', true);
+
+    var attachmentView = coreSettings.get('folder/mailattachments', {});
+    if (!_.isEmpty(attachmentView)) {
+        // add 7030 if attachment view is active
+        allColumns = allColumns + ',7030';
+    } else {
+        // remove from version columns
+        allVersionColumns = allVersionColumns.replace(',7030', '');
+    }
 
     /**
      * map error codes and text phrases for user feedback
@@ -441,29 +453,45 @@ define('io.ox/files/api', [
                 // folders exceed upper limit?
                 if (folders.length >= stop) return folders.slice(start, stop);
                 // fetch files
-                return http.GET({ module: module, params: _.extend({}, params, { limit: limit }) }).then(
-                    function (files) {
-                        // build virual response of folders, placeholders, and files
-                        // simple solution to get proper slice
-                        var unified = [].concat(
-                            folders,
-                            // fill up with placeholders
-                            new Array(Math.max(0, start - folders.length)),
-                            files
-                        );
-                        return unified.slice(start, stop);
-                    },
-                    function fail(e) {
-                        if (e.code === 'IFO-0400' && e.error_params.length === 0) {
-                            // IFO-0400 is missing the folder in the error params -> adding this manually
-                            e.error_params.push(params.folder);
-                        }
-                        api.trigger('error error:' + e.code, e);
-                        // this one might fail due to lack of permissions; error are transformed to empty array
-                        if (ox.debug) console.warn('files.httpGet', e.error, e);
-                        return [];
+                return $.when(http.GET({ module: module, params: _.extend({}, params, { limit: limit }) }), ox.manifests.loadPluginsFor('io.ox/files/filter'))
+                .then(function (files) {
+                    // apply filter extensions
+                    files = files[0].filter(function (file) {
+                        return ext.point('io.ox/files/filter').filter(function (p) {
+                            return p.invoke('isEnabled', this, file) !== false;
+                        })
+                        .map(function (p) {
+                            return p.invoke('isVisible', this, file);
+                        })
+                        .reduce(function (acc, isVisible) {
+                            return acc && isVisible;
+                        }, true);
+                    });
+
+                    // build virual response of folders, placeholders, and files
+                    // simple solution to get proper slice
+                    var unified = [].concat(
+                        folders,
+                        // fill up with placeholders
+                        new Array(Math.max(0, start - folders.length)),
+                        files
+                    );
+
+                    var result = unified.slice(start, stop);
+                    result.forEach(function (el, index) {
+                        result[index] = mergeDetailInPool(el);
+                    });
+                    return result;
+                }, function fail(e) {
+                    if (e.code === 'IFO-0400' && e.error_params.length === 0) {
+                        // IFO-0400 is missing the folder in the error params -> adding this manually
+                        e.error_params.push(params.folder);
                     }
-                );
+                    api.trigger('error error:' + e.code, e);
+                    // this one might fail due to lack of permissions; error are transformed to empty array
+                    if (ox.debug) console.warn('files.httpGet', e.error, e);
+                    return [];
+                });
             });
         },
         // set higher limit; works much faster than mail
@@ -472,6 +500,12 @@ define('io.ox/files/api', [
         SECONDARY_PAGE_SIZE: 210
     });
 
+    api.collectionLoader.noSelect = function (options) {
+        // check read access
+        var model = folderAPI.pool.getModel(options.folder);
+        return !model.can('read');
+    };
+
     api.collectionLoader.each = function (data) {
         api.pool.add('detail', data);
     };
@@ -498,6 +532,13 @@ define('io.ox/files/api', [
 
     }());
 
+    // merges assigned data in pool
+    // and return the merged result!
+    function mergeDetailInPool(data) {
+        pool.add('detail', data);
+        return pool.get('detail').get(_.cid(data)).toJSON();
+    }
+
     //
     // GET a single file
     //
@@ -526,8 +567,7 @@ define('io.ox/files/api', [
             params: params
         })
         .then(function (data) {
-            pool.add('detail', data);
-            return data;
+            return mergeDetailInPool(data);
         }, function (error) {
             api.trigger('error error:' + error.code, error);
             return error;
@@ -572,10 +612,6 @@ define('io.ox/files/api', [
             return this.get(_.cid(item)).toJSON();
         }
 
-        function add(item) {
-            pool.add('detail', item);
-        }
-
         return function (ids, options) {
 
             var uncached = ids, collection = pool.get('detail');
@@ -597,7 +633,7 @@ define('io.ox/files/api', [
             }))
             .then(function (array) {
                 // add new items to the pool
-                _(array).each(add);
+                _(array).each(mergeDetailInPool);
                 // reconstruct results
                 return _(ids).map(getter, collection);
             });
@@ -773,7 +809,8 @@ define('io.ox/files/api', [
                 module: 'files',
                 params: {
                     action: 'move',
-                    folder: targetFolderId
+                    folder: targetFolderId,
+                    ignoreWarnings: ignoreWarnings
                 },
                 data: items,
                 appendColumns: false
@@ -939,6 +976,8 @@ define('io.ox/files/api', [
 
         // add data
         formData.append('json', JSON.stringify(data));
+        // store folder here for error handling. cannot restore data from formData in Safari or IE
+        formData.folder = data.folder_id;
 
         return http.UPLOAD({
             module: options.module,
@@ -1034,6 +1073,7 @@ define('io.ox/files/api', [
                 module: 'files',
                 params: {
                     action: 'versions',
+                    columns: allVersionColumns,
                     folder: file.folder_id,
                     id: file.id,
                     timezone: 'utc'
@@ -1043,7 +1083,7 @@ define('io.ox/files/api', [
             .then(function (data) {
                 model.set({ versions: data, number_of_versions: data.length });
                 // make sure we always get the same result (just data; not timestamp)
-                return data;
+                return model.toJSON();
             });
         },
 
@@ -1105,9 +1145,8 @@ define('io.ox/files/api', [
             params: _(options).pick('action', 'columns', 'sort', 'order', 'limit', 'folder'),
             data: api.search.getData(query, options)
         })
-        .done(function (data) {
-            pool.add('detail', data);
-            return data;
+        .done(function (d) {
+            _(d).each(mergeDetailInPool);
         });
     };
 
