@@ -16,6 +16,7 @@ define('io.ox/files/main', [
     'io.ox/core/commons',
     'gettext!io.ox/files',
     'settings!io.ox/files',
+    'settings!io.ox/core',
     'io.ox/core/extensions',
     'io.ox/core/folder/api',
     'io.ox/core/folder/tree',
@@ -31,6 +32,7 @@ define('io.ox/files/main', [
     'io.ox/files/api',
     'io.ox/core/tk/sidebar',
     'io.ox/core/viewer/views/sidebarview',
+    'io.ox/backbone/mini-views/quota',
     // prefetch
     'io.ox/files/mobile-navbar-extensions',
     'io.ox/files/mobile-toolbar-actions',
@@ -42,7 +44,7 @@ define('io.ox/files/main', [
     'io.ox/files/upload/dropzone',
     'io.ox/core/folder/breadcrumb',
     'gettext!io.ox/core/viewer'
-], function (commons, gt, settings, ext, folderAPI, TreeView, TreeNodeView, FolderView, FileListView, ListViewControl, Toolbar, actions, Bars, PageController, capabilities, api, sidebar, Sidebarview) {
+], function (commons, gt, settings, coreSettings, ext, folderAPI, TreeView, TreeNodeView, FolderView, FileListView, ListViewControl, Toolbar, actions, Bars, PageController, capabilities, api, sidebar, Sidebarview, QuotaView) {
 
     'use strict';
 
@@ -192,14 +194,34 @@ define('io.ox/files/main', [
 
             if (_.device('smartphone')) return;
 
-            // tree view
-            var tree = new TreeView({ app: app, module: 'infostore', root: settings.get('rootFolderId', 9), contextmenu: true });
-
-            // initialize folder view
-            FolderView.initialize({ app: app, tree: tree });
+            app.treeView = new TreeView({ app: app, module: 'infostore', root: settings.get('rootFolderId', 9), contextmenu: true });
+            FolderView.initialize({ app: app, tree: app.treeView });
             app.folderView.resize.enable();
         },
 
+        'files-quota': function (app) {
+
+            if (_.device('smartphone')) return;
+
+            var quota = new QuotaView({
+                title: gt('File quota'),
+                renderUnlimited: false,
+                module: 'file'
+            });
+            // add some listeners
+            folderAPI.on('clear', function () {
+                quota.getQuota(true);
+            });
+
+            api.on('add:file remove:file', function () {
+                quota.getQuota(true);
+            });
+
+            app.treeView.$el.append(
+                quota.render().$el
+            );
+        },
+
         /*
          * Folder view mobile support
          */
@@ -215,7 +237,7 @@ define('io.ox/files/main', [
             });
 
             var tree = new TreeView({ app: app, contextmenu: true, module: 'infostore', root: settings.get('rootFolderId', 9) });
-
+            app.treeView = tree;
             // initialize folder view
             FolderView.initialize({ app: app, tree: tree, firstResponder: 'main' });
             page.append(tree.render().$el);
@@ -245,9 +267,10 @@ define('io.ox/files/main', [
         'get-view-options': function (app) {
 
             app.getViewOptions = function (folder) {
-                var options = app.settings.get(['viewOptions', folder], {});
+                var options = app.settings.get(['viewOptions', folder], {}),
+                    defaultSort = folder === 'virtual/myshares' ? 5 : 702;
                 if (!/^(list|icon|tile)/.test(options.layout)) options.layout = 'list';
-                return _.extend({ sort: 702, order: 'asc', layout: 'list' }, options);
+                return _.extend({ sort: defaultSort, order: 'asc', layout: 'list' }, options);
             };
         },
 
@@ -290,10 +313,13 @@ define('io.ox/files/main', [
             node.append(
                 app.listControl.render().$el
                 //#. items list (e.g. mails)
-                .attr('aria-label', gt('Item list'))
+                .attr({
+                    role: 'main',
+                    'aria-label': gt('Files')
+                })
                 .find('.toolbar')
                 //#. toolbar with 'select all' and 'sort by'
-                .attr('aria-label', gt('Item list options'))
+                .attr('aria-label', gt('Files options'))
                 .end()
             );
         },
@@ -310,12 +336,10 @@ define('io.ox/files/main', [
          */
         'folder:change': function (app) {
             // see Bug 43512 - Opening a Drive direct link in Safari removes the edit bar
-            if (_.device('safari')) {
-                // hide and show sidepanel for correct layout. Somehow, scroll into view and flexbox-layout have errors in safari
-                app.folderView.tree.selection.view.on('scrollIntoView', function () {
-                    app.getWindow().nodes.sidepanel.hide().show(0);
-                });
-            }
+            // hide and show sidepanel for correct layout. Somehow, scroll into view and flexbox-layout have errors (mostly in safari)
+            app.folderView.tree.selection.view.on('scrollIntoView', function () {
+                app.getWindow().nodes.sidepanel.hide().show(0);
+            });
 
             app.on('folder:change', function (id) {
                 // we clear the list now to avoid flickering due to subsequent layout changes
@@ -326,8 +350,18 @@ define('io.ox/files/main', [
                 app.listView.model.set('folder', null, { silent: true });
                 app.listView.model.set('folder', id);
             });
-        },
 
+            app.on('folder-virtual:change', function (id) {
+                app.listView.empty();
+                var options = app.getViewOptions(id);
+                app.props.set(options);
+
+                app.listView.model.set(options);
+                app.listView.model.set('folder', null, { silent: true });
+                app.listView.model.set('folder', id);
+
+            });
+        },
         /*
          * Respond to virtual myshares
          */
@@ -356,7 +390,7 @@ define('io.ox/files/main', [
                     if (loading) return;
                     loading = true;
 
-                    require(['io.ox/files/share/listview'], function (MySharesView) {
+                    require(['io.ox/files/share/listview', 'io.ox/files/share/api'], function (MySharesView, shareApi) {
 
                         app.mysharesListView = new MySharesView({
                             app: app,
@@ -381,7 +415,11 @@ define('io.ox/files/main', [
                             app.mysharesListView.reload();
                         }), 10);
 
-                        var toolbar = new Toolbar({ title: app.getTitle(), tabindex: 1 });
+                        shareApi.on('remove:link new:link', _.debounce(function () {
+                            app.mysharesListView.reload();
+                        }), 10);
+
+                        var toolbar = new Toolbar({ title: app.getTitle() });
 
                         app.getWindow().nodes.body.prepend(
                             app.mysharesListViewControl.render().$el
@@ -435,13 +473,33 @@ define('io.ox/files/main', [
             });
         },
 
+        'attachmentViewUpdater': function (app) {
+            var attachmentView = coreSettings.get('folder/mailattachments', {});
+            if (_.isEmpty(attachmentView)) return;
+
+            function expireAttachmentView() {
+                _(attachmentView).each(function (folder) {
+                    _(api.pool.getByFolder(folder)).each(function (collection) {
+                        collection.expired = true;
+                    });
+                    if (app.folder.get() === folder) app.listView.reload();
+                });
+            }
+
+            app.folderView.tree.on('change', expireAttachmentView);
+
+            require(['io.ox/mail/api'], function (mailAPI) {
+                mailAPI.on('delete new-mail copy update archive archive-folder', expireAttachmentView);
+            });
+        },
+
         /*
          * Store view options
          */
         'store-view-options': function (app) {
             app.props.on('change', _.debounce(function () {
                 if (app.props.get('find-result')) return;
-                var folder = app.folder.get(), data = app.props.toJSON();
+                var folder = app.folder.get() || 'virtual/myshares', data = app.props.toJSON();
                 app.settings
                     .set(['viewOptions', folder], { sort: data.sort, order: data.order, layout: data.layout });
                 if (_.device('!smartphone')) {
@@ -465,9 +523,16 @@ define('io.ox/files/main', [
          */
         'change:sort': function (app) {
             app.props.on('change:sort', function (m, value) {
+                if (!app.treeView) return;
                 // set proper order first
-                var model = app.listView.model;
-                model.set('order', (/^(5|704)$/).test(value) ? 'desc' : 'asc', { silent: true });
+                var model = app.listView.model,
+                    viewOptions = app.getViewOptions(app.treeView.selection.get());
+                if (viewOptions) {
+                    model.set('order', viewOptions.order, { silent: true });
+                } else {
+                    // set default
+                    model.set('order', (/^(5|704)$/).test(value) ? 'desc' : 'asc', { silent: true });
+                }
                 app.props.set('order', model.get('order'));
                 // now change sort columns
                 model.set('sort', value);
@@ -638,8 +703,10 @@ define('io.ox/files/main', [
             var ev = _.device('touch') ? 'tap' : 'dblclick';
 
             app.listView.$el.on(ev, '.file-type-folder .list-item-content', function (e) {
-                var obj = _.cid($(e.currentTarget).parent().attr('data-cid'));
-                app.folder.set(obj.id);
+                // simple id check for folders, prevents errors if folder id contains '.'
+                var id = $(e.currentTarget).parent().attr('data-cid').replace(/^folder./, '');
+
+                app.folder.set(id);
             });
 
             app.listView.$el.on(ev, '.list-item:not(.file-type-folder) .list-item-content', function (e) {
@@ -660,11 +727,13 @@ define('io.ox/files/main', [
             // folders
             app.listView.$el.on('keydown', '.file-type-folder', function (e) {
                 if (e.which === 13) {
-                    var obj = _.cid($(e.currentTarget).attr('data-cid'));
+                    // simple id check for folders, prevents errors if folder id contains '.'
+                    var id = $(e.currentTarget).attr('data-cid').replace(/^folder./, '');
+
                     app.listView.once('collection:load', function () {
                         app.listView.selection.select(0);
                     });
-                    app.folder.set(obj.id);
+                    app.folder.set(id);
                 }
             });
 
@@ -824,41 +893,8 @@ define('io.ox/files/main', [
         /*
          * change to default folder on no permission or folder not found errors
          */
-        'no-permission': function (app) {
-            // use debounce, so errors from folder and app api are only handled once.
-            var handleError = _.debounce(function (error) {
-                // work with (error) and (event, error) arguments
-                if (error && !error.error) {
-                    if (arguments[1] && arguments[1].error) {
-                        error = arguments[1];
-                    } else {
-                        return;
-                    }
-                }
-                // only change if folder is currently displayed
-                if (error.error_params[0] && String(app.folder.get()) !== String(error.error_params[0])) {
-                    return;
-                }
-                require(['io.ox/core/yell'], function (yell) {
-                    yell(error);
-                    // try to load the default folder
-                    // guests do not have a default folder, so the first visible one is chosen
-                    app.folder.setDefault();
-                });
-            }, 300);
-
-            folderAPI.on('error:FLD-0008 error:FLD-0003', handleError);
-            api.on('error:FLD-0008', handleError);
-            api.on('error:IFO-0400', function (error) {
-                // check if folder is currently displayed
-                if (String(app.folder.get()) !== String(error.error_params[0])) {
-                    return;
-                }
-                // see if we can still access the folder, although we are not allowed to view the contents
-                // this is important because otherwise we would not be able to change permissions (because the view jumps to the default folder all the time)
-                // if the useer is nto allowed to view this folder, the folderapi will trigger error:FLD-0003
-                folderAPI.get(app.folder.get(), { cache: false });
-            });
+        'folder-error': function (app) {
+            app.folder.handleErrors();
         },
 
         /*
@@ -956,10 +992,20 @@ define('io.ox/files/main', [
             );
         },
 
-        'premium-area': function (app) {
-            commons.addPremiumFeatures(app, {
-                upsellId: 'folderview/infostore/bottom',
-                upsellRequires: 'boxcom || google || msliveconnect'
+        'premium-area': function () {
+
+            ext.point('io.ox/files/sidepanel').extend({
+                id: 'premium-area',
+                index: 10000,
+                draw: function (baton) {
+                    this.append(
+                        commons.addPremiumFeatures(baton.app, {
+                            append: false,
+                            upsellId: 'folderview/infostore/bottom',
+                            upsellRequires: 'boxcom || google || msliveconnect'
+                        })
+                    );
+                }
             });
         },
 
@@ -1049,6 +1095,22 @@ define('io.ox/files/main', [
                 .attr('data-dropzones', '.selectable.file-type-folder');
         },
 
+        'sidepanel': function (app) {
+            if (_.device('smartphone')) return;
+
+            ext.point('io.ox/files/sidepanel').extend({
+                id: 'tree',
+                index: 100,
+                draw: function (baton) {
+                    // add border & render tree and add to DOM
+                    this.addClass('border-right').append(baton.app.treeView.$el);
+                }
+            });
+
+            var node = app.getWindow().nodes.sidepanel;
+            ext.point('io.ox/files/sidepanel').invoke('draw', node, ext.Baton({ app: app }));
+        },
+
         'metrics': function (app) {
             require(['io.ox/metrics/main'], function (metrics) {
                 if (!metrics.isEnabled()) return;
@@ -1192,6 +1254,26 @@ define('io.ox/files/main', [
                     app.folder.set(obj.folder_id);
                 }
             };
+        },
+
+        'a11y': function (app) {
+            // mail list: focus mail detail view on <enter>
+            // mail list: focus folder on <escape>
+            app.listView.$el.on('keydown', '.list-item', function (e) {
+                // if a message is selected (mouse or keyboard) the focus is set on body
+                if (e.which === 27) {
+                    app.folderView.tree.$('.folder.selected').focus();
+                    return false;
+                }
+            });
+            // folder tree: focus list view on <enter>
+            // folder tree: focus top-bar on <escape>
+            app.folderView.tree.$el.on('keydown', '.folder', function (e) {
+                // check if it's really the folder - not the contextmenu toggle
+                if (!$(e.target).hasClass('folder')) return;
+                if (e.which === 13) app.listView.restoreFocus(true);
+                if (e.which === 27) $('#io-ox-topbar .active-app > a').focus();
+            });
         }
     });
 
@@ -1223,7 +1305,16 @@ define('io.ox/files/main', [
         win.nodes.outer.on('selection:drop', function (e, baton) {
             // convert composite keys to objects
             baton.data = _(baton.data).map(function (item) {
-                return _.isString(item) ? _.cid(item) : item;
+
+                // simple id check for folders, prevents errors if folder id contains '.'
+                if (_.isString(item)) {
+                    if (item.indexOf('folder.') === 0) {
+                        return { folder_id: 'folder', id: item.replace(/^folder./, '') };
+                    }
+                    return _.cid(item);
+                }
+
+                return item;
             });
             // empty?
             if (!baton.data.length) return;
@@ -1250,6 +1341,20 @@ define('io.ox/files/main', [
             });
     });
 
+    // set what to do if the app is started again
+    // this way we can react to given options, like for example a different folder
+    app.setResume(function (options) {
+        // only consider folder option for now
+        if (options && options.folder && options.folder !== this.folder.get()) {
+            var appNode = this.getWindow();
+            appNode.busy();
+            return this.folder.set(options.folder).always(function () {
+                appNode.idle();
+            });
+        }
+        return $.when();
+    });
+
     return {
         getApp: app.getInstance
     };
