@@ -25,15 +25,12 @@ define('io.ox/find/extensions-facets', [
 
         toolbar: function (baton) {
             if (_.device('smartphone')) return;
-
             // rightside place for dropdowns
-            var toolbar = new Toolbar({ title: gt('Search'), tabindex: 1 });
-
-            this.append(
-                toolbar.render().$list
-            );
-
-            ext.point('io.ox/find/facets/list').invoke('draw', toolbar.$list.empty(), baton);
+            var toolbar = new Toolbar({ title: gt('Search'), tabindex: 1 }),
+                // clone empty toolbar
+                $list = toolbar.render().$list.clone();
+            this.append($list);
+            ext.point('io.ox/find/facets/list').invoke('draw', $list, baton);
         },
 
         list: function (baton) {
