@@ -73,12 +73,14 @@ define('io.ox/mail/actions', [
             var cid = _.cid(baton.data),
                 // needs baton view
                 view = baton.view,
+                // reply to all, so count, to, from, cc and bcc and subtract 1 (you don't sent the mail to yourself)
+                numberOfRecipients = _.union(baton.data.to, baton.data.from, baton.data.cc, baton.data.bcc).length - 1,
                 // hide inline link
                 link = view.$('[data-ref="io.ox/mail/actions/inplace-reply"]').hide();
 
             require(['io.ox/mail/inplace-reply'], function (InplaceReplyView) {
                 view.$('section.body').before(
-                    new InplaceReplyView({ tagName: 'section', cid: cid })
+                    new InplaceReplyView({ tagName: 'section', cid: cid, numberOfRecipients: numberOfRecipients })
                     .on('send', function (cid) {
                         view.$el.closest('.thread-view-control').data('open', cid);
                     })
@@ -203,6 +205,43 @@ define('io.ox/mail/actions', [
         }
     });
 
+    new Action('io.ox/mail/actions/filter', {
+        capabilities: 'mailfilter',
+        requires: function (e) {
+            // must be at least one message and top-level
+            if (!e.collection.has('some') || !e.collection.has('toplevel')) return;
+            // multiple selection
+            if (e.baton.selection && e.baton.selection.length > 1) return;
+            // multiple and not a thread?
+            if (!e.collection.has('one') && !e.baton.isThread) return;
+            return true;
+        },
+        action: function (baton) {
+            require(['io.ox/mail/mailfilter/settings/filter'
+                ], function (filter) {
+
+                filter.initialize().then(function (data, config, opt) {
+                    var factory = opt.model.protectedMethods.buildFactory('io.ox/core/mailfilter/model', opt.api),
+                        args = { data: { obj: factory.create(opt.model.protectedMethods.provideEmptyModel()) } },
+                        preparedTest = {
+                            id: 'allof',
+                            tests: [
+                                _.copy(opt.filterDefaults.tests.Subject),
+                                opt.filterDefaults.tests.address ? _.copy(opt.filterDefaults.tests.address) : _.copy(opt.filterDefaults.tests.From)
+                            ]
+                        };
+
+                    preparedTest.tests[0].values = [baton.data.subject];
+                    preparedTest.tests[1].values = [baton.data.from[0][1]];
+
+                    args.data.obj.set('test', preparedTest);
+
+                    ext.point('io.ox/settings/mailfilter/filter/settings/detail').invoke('draw', undefined, args, config[0]);
+                });
+            });
+        }
+    });
+
     new Action('io.ox/mail/actions/print', {
         requires: function (e) {
             // not on smartphones
@@ -265,8 +304,8 @@ define('io.ox/mail/actions', [
 
     new Action('io.ox/mail/actions/mark-unread', {
         requires: function (e) {
-            // must be top-level
-            if (!e.collection.has('toplevel', 'modify')) return;
+            // must be top-level; change seen flag
+            if (!e.collection.has('toplevel', 'change:seen')) return false;
             // partiallySeen? has at least one email that's seen?
             return _(e.baton.array()).reduce(function (memo, obj) {
                 return memo || !util.isUnseen(obj);
@@ -281,8 +320,8 @@ define('io.ox/mail/actions', [
 
     new Action('io.ox/mail/actions/mark-read', {
         requires: function (e) {
-            // must be top-level
-            if (!e.collection.has('toplevel', 'modify')) return;
+            // must be top-level; change seen flag
+            if (!e.collection.has('toplevel', 'change:seen')) return false;
             // partiallyUnseen? has at least one email that's seen?
             return _(e.baton.array()).reduce(function (memo, obj) {
                 return memo || util.isUnseen(obj);
@@ -521,7 +560,7 @@ define('io.ox/mail/actions', [
         index: INDEX += 100,
         prio: 'hi',
         id: 'inplace-reply',
-        mobile: 'hi',
+        mobile: 'lo',
         //#. Quick reply to a message; maybe "Direkt antworten" or "Schnell antworten" in German
         label: gt('Quick reply'),
         ref: 'io.ox/mail/actions/inplace-reply',
@@ -532,7 +571,7 @@ define('io.ox/mail/actions', [
         index: INDEX += 100,
         prio: 'lo',
         id: 'reply',
-        mobile: 'hi',
+        mobile: 'lo',
         label: gt('Reply'),
         ref: 'io.ox/mail/actions/reply',
         section: 'standard'
@@ -542,7 +581,7 @@ define('io.ox/mail/actions', [
         index: INDEX += 100,
         prio: 'hi',
         id: 'reply-all',
-        mobile: 'hi',
+        mobile: 'lo',
         label: gt('Reply All'),
         ref: 'io.ox/mail/actions/reply-all',
         drawDisabled: true,
@@ -553,7 +592,7 @@ define('io.ox/mail/actions', [
         index: INDEX += 100,
         prio: 'hi',
         id: 'forward',
-        mobile: 'hi',
+        mobile: 'lo',
         label: gt('Forward'),
         ref: 'io.ox/mail/actions/forward',
         section: 'standard'
@@ -564,7 +603,7 @@ define('io.ox/mail/actions', [
         index: INDEX += 100,
         prio: 'hi',
         id: 'edit',
-        mobile: 'hi',
+        mobile: 'lo',
         label: gt('Edit'),
         ref: 'io.ox/mail/actions/edit',
         section: 'standard'
@@ -574,7 +613,7 @@ define('io.ox/mail/actions', [
         index: INDEX += 100,
         prio: 'hi',
         id: 'delete',
-        mobile: 'hi',
+        mobile: 'lo',
         label: gt('Delete'),
         ref: 'io.ox/mail/actions/delete',
         section: 'standard'
@@ -589,7 +628,7 @@ define('io.ox/mail/actions', [
     ext.point('io.ox/mail/links/inline').extend(new links.Link({
         index: INDEX += 100,
         prio: 'lo',
-        mobile: 'hi',
+        mobile: 'lo',
         id: 'spam',
         label: gt('Mark as spam'),
         ref: 'io.ox/mail/actions/spam',
@@ -599,7 +638,7 @@ define('io.ox/mail/actions', [
     ext.point('io.ox/mail/links/inline').extend(new links.Link({
         index: INDEX + 1,
         prio: 'lo',
-        mobile: 'hi',
+        mobile: 'lo',
         id: 'nospam',
         label: gt('Not spam'),
         ref: 'io.ox/mail/actions/nospam',
@@ -660,7 +699,7 @@ define('io.ox/mail/actions', [
     ext.point('io.ox/mail/links/inline').extend(new links.Link({
         index: INDEX += 100,
         prio: 'lo',
-        mobile: 'hi',
+        mobile: 'lo',
         id: 'archive',
         //#. Verb: (to) archive messages
         label: gt.pgettext('verb', 'Archive'),
@@ -699,6 +738,16 @@ define('io.ox/mail/actions', [
         section: 'export'
     }));
 
+    ext.point('io.ox/mail/links/inline').extend(new links.Link({
+        index: INDEX += 100,
+        prio: 'lo',
+        mobile: 'none',
+        id: 'filter',
+        label: gt('Create filter rule'),
+        ref: 'io.ox/mail/actions/filter',
+        section: 'file-op'
+    }));
+
     ext.point('io.ox/mail/links/inline').extend(new links.Link({
         index: INDEX += 100,
         prio: 'lo',
@@ -747,6 +796,7 @@ define('io.ox/mail/actions', [
 
     ext.point('io.ox/mail/attachment/links').extend(new links.Link({
         id: 'open',
+        enabled: _.device('!IE'),
         index: 300,
         mobile: 'high',
         label: gt('Open in browser'),
