@@ -24,34 +24,31 @@ define('io.ox/mail/autoforward/settings/model', [
     function providePreparedData(attributes) {
         if (!attributes.forwardmail) {
             return {};
-        } else {
-            var preparedData = {
-                    'rulename': 'autoforward',
-
-                    'position': attributes.position,
-
-                    'test': {
-                        'id': 'true'
-                    },
-                    'actioncmds': [
-                        {
-                            'id': 'redirect',
-                            'to': attributes.forwardmail
-                        }
-                    ],
-                    'flags': ['autoforward'],
-                    'active': attributes.active ? true : false
-                };
-            if (attributes.keep) {
-                preparedData.actioncmds.push({ 'id': 'keep' });
-            }
-            //first rule gets 0
-            if (!_.isUndefined(attributes.id) && !_.isNull(attributes.id)) {
-                preparedData.id = attributes.id;
-            }
-
-            return preparedData;
         }
+        var preparedData = {
+            'rulename': 'autoforward',
+
+            'position': attributes.position,
+
+            'test': {
+                'id': 'true'
+            },
+            'actioncmds': [{
+                'id': 'redirect',
+                'to': attributes.forwardmail
+            }],
+            'flags': ['autoforward'],
+            'active': !!attributes.active
+        };
+        if (attributes.keep) {
+            preparedData.actioncmds.push({ 'id': 'keep' });
+        }
+        //first rule gets 0
+        if (!_.isUndefined(attributes.id) && !_.isNull(attributes.id)) {
+            preparedData.id = attributes.id;
+        }
+
+        return preparedData;
 
     }
 
@@ -69,11 +66,10 @@ define('io.ox/mail/autoforward/settings/model', [
                     return settingsUtil.yellOnReject(
                         api.deleteRule(model.attributes.id)
                     );
-                } else {
-                    return settingsUtil.yellOnReject(
-                        api.update(providePreparedData(model.attributes))
-                    );
                 }
+                return settingsUtil.yellOnReject(
+                    api.update(providePreparedData(model.attributes))
+                );
             },
             create: function (model) {
                 //make the active element lose focus to get the changes of the field a user was editing
@@ -93,7 +89,7 @@ define('io.ox/mail/autoforward/settings/model', [
     var fields = {
         headline: gt('Auto Forward'),
         forwardmail: gt('Forward all incoming emails to this address'),
-        active: gt('Enabled'),
+        active: gt('Enable'),
         keep: gt('Keep a copy of the message')
     };
 
