@@ -101,6 +101,10 @@ define('io.ox/mail/common-extensions', [
 
         date: function (baton, options) {
             var data = baton.data, t = data.received_date;
+            options = _.extend({
+                fulldate: baton.app && baton.app.props.get('exactDates'),
+                smart: !(baton.app && baton.app.props.get('exactDates'))
+            }, options);
             if (!_.isNumber(t)) return;
             this.append(
                 $('<time class="date">')
@@ -109,15 +113,6 @@ define('io.ox/mail/common-extensions', [
             );
         },
 
-        dateOrSize: function (baton) {
-            // show date or size depending on sort option
-            var fn = 'size';
-            if (baton.app && baton.app.props.get('sort') !== 608) {
-                fn = baton.app.props.get('exactDates') ? 'fulldate' : 'smartdate';
-            }
-            extensions[fn].call(this, baton);
-        },
-
         smartdate: function (baton) {
             extensions.date.call(this, baton, { fulldate: false, smart: true });
         },
@@ -127,27 +122,48 @@ define('io.ox/mail/common-extensions', [
         },
 
         from: function (baton) {
-
-            var data = baton.data,
-                single = !data.threadSize || data.threadSize === 1,
-                field = single && !isSearchActive(baton) && account.is('sent|drafts', data.folder_id) ? 'to' : 'from',
-                // get folder data to check capabilities:
-                // if bit 4096 is set, the server sort by local part not display name
-                capabilities = folderAPI.pool.getModel(data.folder_id).get('capabilities') || 0,
-                useDisplayName = baton.options.sort !== 'from-to' || !(capabilities & 4096);
-
+            var opt = { folder: baton.data.folder_id, field: 'from', showDisplayName: true };
+            // push options through fromPipeline
+            _.each(extensions.fromPipeline, function (fn) { fn.call(this, baton, opt); });
             this.append(
                 $('<div class="from">').append(
-                    util.getFrom(data, { field: field, reorderDisplayName: useDisplayName, showDisplayName: useDisplayName })
+                    util.getFrom(baton.data, _.pick(opt, 'field', 'reorderDisplayName', 'showDisplayName', 'unescapeDisplayName'))
                 )
             );
         },
 
+        fromPipeline: {
+            // field: from vs. to
+            field: function (baton, opt) {
+                if (baton.data.threadSize > 1) return;
+                if (account.is('sent|drafts', opt.folder)) opt.field = 'to';
+            },
+            // field: from vs. to
+            fieldSearch: function (baton, opt) {
+                if (!isSearchActive(baton)) return;
+                var app = baton.app && baton.app.get('find');
+                opt.field = app && account.is('sent|drafts', app.getFolderFacetValue()) ? 'to' : 'from';
+            },
+            // showDisplayName, reorderDisplayName and unescapeDisplayName
+            displayName: function (baton, opt) {
+                opt.reorderDisplayName = opt.unescapeDisplayName = (baton.options.sort !== 'from-to');
+                if (baton.options.sort !== 'from-to') return;
+                // get folder data to check capabilities:
+                // if bit 4096 is set, the server sorts by display name; if unset, it sorts by local part.
+                var capabilities = folderAPI.pool.getModel(opt.folder).get('capabilities') || 0;
+                opt.showDisplayName = (capabilities & 4096);
+            }
+        },
+
         size: function (baton) {
+            //show size if option is enabled or sorting by size
+            if (baton.app && (baton.app.props.get('sort') !== 608 && !baton.app.props.get('alwaysShowSize'))) return;
+
             var data = baton.data;
             if (!_.isNumber(data.size)) return;
+            var size = util.threadFileSize(data.thread || [data]);
             this.append(
-                $('<span class="size">').text(strings.fileSize(data.size, 1))
+                $('<span class="size">').text(strings.fileSize(size, 1))
             );
         },
 
@@ -174,8 +190,8 @@ define('io.ox/mail/common-extensions', [
         threadSize: function (baton) {
             // only consider thread-size if app is in thread-mode
             var isThreaded = baton.app && baton.app.isThreaded();
-            if (!isThreaded) return;
-            if (baton.options.threaded !== true && (!baton.app || !baton.app.isThreaded())) return;
+            // seems that threaded option is used for tests only
+            if (!isThreaded && !baton.options.threaded) return;
 
             var size = api.threads.size(baton.data);
             if (size <= 1) return;
@@ -194,6 +210,13 @@ define('io.ox/mail/common-extensions', [
             );
         },
 
+        sharedAttachement: function (baton) {
+            if (!baton.model || !_.has(baton.model.get('headers'), 'X-Open-Xchange-Share-URL')) return;
+            this.append(
+                $('<i class="fa fa-cloud-download is-shared-attachement" aria-hidden="true">')
+            );
+        },
+
         pgp: {
             encrypted: function (baton) {
                 //simple check for encrypted mail
@@ -280,6 +303,9 @@ define('io.ox/mail/common-extensions', [
             );
         },
 
+        //#. empty message for list view
+        empty: function () { this.text(gt('Empty')); },
+
         // add orignal folder as label to search result items
         folder: function (baton) {
             // missing data or find currently inactive
@@ -460,7 +486,12 @@ define('io.ox/mail/common-extensions', [
                 };
 
             return function (baton) {
+
                 if (baton.attachments.length === 0) return $.when();
+                // ensure there's a model when reading headers
+                var headers = baton.model ? baton.model.get('headers') : baton.data.headers || {};
+                // hide attachments for our own share invitations
+                if (headers['X-Open-Xchange-Share-Type']) this.hide();
 
                 var $el = this;
 
@@ -521,10 +552,7 @@ define('io.ox/mail/common-extensions', [
         unreadToggle: (function () {
 
             function getAriaLabel(data) {
-                return util.isUnseen(data) ?
-                    gt('This message is unread, press this button to mark it as read.') :
-                    gt('This message is read, press this button to mark it as unread.');
-
+                return util.isUnseen(data) ? gt('Unread') : gt('Read');
             }
 
             function toggle(e) {
@@ -532,19 +560,31 @@ define('io.ox/mail/common-extensions', [
                 var data = e.data.model.toJSON();
                 // toggle 'unseen' bit
                 if (util.isUnseen(data)) api.markRead(data); else api.markUnread(data);
-                $(this).attr('aria-label', getAriaLabel(data));
+                $(this).attr({
+                    'aria-label': getAriaLabel(data),
+                    'aria-pressed': util.isUnseen(data)
+                });
             }
 
             return function (baton) {
 
                 if (util.isEmbedded(baton.data)) return;
-
-                this.append(
-                    $('<a href="#" role="button" class="unread-toggle" tabindex="1">')
-                    .attr('aria-label', getAriaLabel(baton.data))
-                    .append('<i class="fa" aria-hidden="true">')
-                    .on('click', { model: baton.view.model }, toggle)
-                );
+                var self = this;
+                folderAPI.get(baton.data.folder_id).done(function (data) {
+                    // see if the user is allowed to modify the read/unread status
+                    // always allows for unifeid folder
+                    var showUnreadToggle = folderAPI.can('write', data) || folderAPI.is('unifiedfolder', data);
+                    if (!showUnreadToggle) return;
+                    self.append(
+                        $('<a href="#" role="button" class="unread-toggle" tabindex="1">')
+                        .attr({
+                            'aria-label': getAriaLabel(baton.data),
+                            'aria-pressed': util.isUnseen(baton.data)
+                        })
+                        .append('<i class="fa" aria-hidden="true">')
+                        .on('click', { model: baton.view.model }, toggle)
+                    );
+                });
             };
         }()),
 
@@ -654,7 +694,7 @@ define('io.ox/mail/common-extensions', [
 
                 this.append(
                     $('<div class="alert alert-info disposition-notification">').append(
-                        $('<button type="button" class="close" data-dismiss="alert">&times;</button>'),
+                        $('<button type="button" class="close" data-dismiss="alert" tabindex="1">&times;</button>'),
                         $('<button type="button" class="btn btn-primary btn-sm" tabindex="1">').text(
                             //#. Respond to a read receipt request; German "Lesebestätigung senden"
                             gt('Send a read receipt')
