@@ -42,6 +42,7 @@ define('io.ox/mail/detail/view', [
         id: 'subject',
         index: INDEX += 100,
         draw: function (baton) {
+
             var subject = util.getSubject(baton.data),
                 node = $('<h1 class="subject">').text(subject);
 
@@ -83,7 +84,7 @@ define('io.ox/mail/detail/view', [
     });
 
     /* move the actions menu to the top in sidepanel on smartphones */
-    var extPoint = _.device('smartphone') ? 'io.ox/mail/detail' : 'io.ox/mail/detail/header/row3';
+    var extPoint = _.device('smartphone') ? 'io.ox/mail/detail' : 'io.ox/mail/detail/header/row4';
 
     ext.point(extPoint).extend(new links.InlineLinks({
         id: 'actions',
@@ -115,7 +116,7 @@ define('io.ox/mail/detail/view', [
             id: 'rows',
             index: INDEX_header += 100,
             draw: function (baton) {
-                for (var i = 1, node; i <= 3; i++) {
+                for (var i = 1, node; i <= 4; i++) {
                     node = $('<div class="detail-view-row row-' + i + ' clearfix">');
                     ext.point('io.ox/mail/detail/header/row' + i).invoke('draw', node, baton);
                     this.append(node);
@@ -128,17 +129,6 @@ define('io.ox/mail/detail/view', [
     // Row 1
     //
     ext.point('io.ox/mail/detail/header/row1').extend(
-        {
-            id: 'from',
-            index: INDEX_header += 100,
-            draw: function (baton) {
-                this.append(
-                    $('<div class="from">').append(
-                        util.serializeList(baton.data, 'from')
-                    )
-                );
-            }
-        },
         {
             id: 'flag-picker',
             index: INDEX_header += 100,
@@ -153,6 +143,18 @@ define('io.ox/mail/detail/view', [
             id: 'priority',
             index: INDEX_header += 100,
             draw: extensions.priority
+        },
+        {
+            // from is last one in the list for proper ellipsis effect
+            id: 'from',
+            index: INDEX_header += 100,
+            draw: function (baton) {
+                this.append(
+                    $('<div class="from">').append(
+                        util.serializeList(baton.data, 'from')
+                    )
+                );
+            }
         }
     );
 
@@ -162,22 +164,46 @@ define('io.ox/mail/detail/view', [
     ext.point('io.ox/mail/detail/header/row2').extend(
         {
             id: 'recipients',
-            index: INDEX_header += 100,
+            index: 100,
             draw: function (baton) {
                 ext.point('io.ox/mail/detail/header/recipients').invoke('draw', this, baton);
             }
         }
     );
 
-    //
-    // Row 3
-    //
     ext.point('io.ox/mail/detail/header/recipients').extend({
         id: 'default',
         index: 100,
         draw: extensions.recipients
     });
 
+    //
+    // Row 3
+    //
+    ext.point('io.ox/mail/detail/header/row3').extend(
+        {
+            id: 'different-subject',
+            index: 100,
+            draw: function (baton) {
+                var data = baton.data, baseSubject, threadSubject, mailSubject;
+
+                // no thread?
+                if (data.threadSize === 1) return;
+
+                // identical subject?
+                baseSubject = api.threads.subject(data);
+                threadSubject = util.getSubject(baseSubject, false);
+                mailSubject = util.getSubject(data, false);
+                if (baseSubject === '' || threadSubject === mailSubject) return;
+
+                this.append(
+                    $('<span class="io-ox-label">').text(gt('Subject') + '\u00a0 '),
+                    $('<span class="different-subject">').text(mailSubject)
+                );
+            }
+        }
+    );
+
     // Inplace/quick reply
 
     ext.point('io.ox/mail/detail').extend({
@@ -236,7 +262,7 @@ define('io.ox/mail/detail/view', [
             this.append(
                 $('<section class="attachments">'),
                 // must have tabindex=1, otherwise tabindex inside Shadow DOM doesn't work
-                $body = $('<section class="body user-select-text" tabindex="1">')
+                $body = $('<section class="body user-select-text focusable" tabindex="1">')
             );
             // rendering mails in chrome is slow if we do not use a shadow dom
             if ($body[0].createShadowRoot && _.device('chrome') && !_.device('smartphone')) {
@@ -298,7 +324,7 @@ define('io.ox/mail/detail/view', [
             // add to DOM
             this.idle().append(node);
             // ensure, that the scrollable is a lazyload scrollpane
-            if (this[0].host) {
+            if (this[0] && this[0].host) {
                 // if it is a shadow dom, we must trigger add.lazyload to ensure, that lazyloading is updated at least once
                 $(this[0].host).closest('.scrollable').lazyloadScrollpane().trigger('add.lazyload');
                 // copy events
@@ -342,7 +368,7 @@ define('io.ox/mail/detail/view', [
 
     var View = DisposableView.extend({
 
-        className: 'list-item mail-item mail-detail f6-target',
+        className: 'list-item mail-item mail-detail f6-target focusable',
 
         events: {
             'keydown': 'onToggle',
@@ -382,6 +408,12 @@ define('io.ox/mail/detail/view', [
             return $(shadowRoot || body);
         },
 
+        onChangeSubject: function () {
+            var subject = this.$el.find('h1.subject');
+            subject.text(this.model.get('subject'));
+            return subject;
+        },
+
         onChangeContent: function () {
             var data = this.model.toJSON(),
                 baton = ext.Baton({
@@ -446,6 +478,9 @@ define('io.ox/mail/detail/view', [
             // as an indicator whether this view has been destroyed meanwhile
             if (this.model === null) return;
 
+            // merge data (API updates the model in most cases, but we need this for nested mails)
+            if (data) this.model.set(data);
+
             var unseen = this.model.get('unseen') || util.isUnseen(this.model.get('flags'));
 
             // done
@@ -453,12 +488,11 @@ define('io.ox/mail/detail/view', [
             this.trigger('load:done');
 
             // draw
+            // nested mails do not have a subject before loading, so trigger change as well
+            this.onChangeSubject();
             this.onChangeAttachments();
             this.onChangeContent();
 
-            // merge data (probably unnecessary here since API updates the model)
-            if (data) this.model.set(data);
-
             // process unseen flag
             if (unseen) {
                 this.onUnseen();
@@ -506,10 +540,19 @@ define('io.ox/mail/detail/view', [
                 if (this.loaded) {
                     this.onLoad();
                 } else {
-                    api.get(_.cid(this.model.cid)).then(
-                        this.onLoad.bind(this),
-                        this.onLoadFail.bind(this)
-                    );
+                    var cid = _.cid(this.model.cid);
+                    // check if we have a nested email here, those are requested differently
+                    if (_(cid).size() === 1 && cid.id !== undefined && this.model.has('parent')) {
+                        api.getNestedMail(this.model.attributes).then(
+                            this.onLoad.bind(this),
+                            this.onLoadFail.bind(this)
+                        );
+                    } else {
+                        api.get(cid).then(
+                            this.onLoad.bind(this),
+                            this.onLoadFail.bind(this)
+                        );
+                    }
                 }
             }
 
@@ -573,7 +616,7 @@ define('io.ox/mail/detail/view', [
                 'data-cid': this.model.cid,
                 'aria-expanded': 'false',
                 'data-loaded': 'false',
-                'role': 'group',
+                'role': 'article',
                 'aria-label': title
             });
 
