@@ -11,20 +11,20 @@
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
 
-define('io.ox/mail/import',
-    ['io.ox/core/extensions',
-     'io.ox/mail/api',
-     'io.ox/core/tk/upload',
-     'io.ox/core/dropzone',
-     'io.ox/core/notifications',
-     'gettext!io.ox/mail'
-    ], function (ext, api, upload, dropzone, notifications, gt) {
+define('io.ox/mail/import', [
+    'io.ox/core/extensions',
+    'io.ox/mail/api',
+    'io.ox/core/tk/upload',
+    'io.ox/core/dropzone',
+    'io.ox/core/notifications',
+    'gettext!io.ox/mail'
+], function (ext, api, upload, dropzone, notifications, gt) {
 
     'use strict';
 
     ext.point('io.ox/mail/mediator').extend({
         id: 'import-eml',
-        index: 'last',
+        index: 1000000000000,
         setup: function (app) {
 
             if (app.settings.get('features/importEML') === false) return;
