@@ -160,6 +160,11 @@ define('io.ox/mail/listview', [
             index: 200,
             draw: extensions.flag
         },
+        {
+            id: 'optionalSize',
+            index: 250,
+            draw: extensions.size
+        },
         {
             id: 'thread-size',
             index: 300,
@@ -170,6 +175,11 @@ define('io.ox/mail/listview', [
             index: 400,
             draw: extensions.paperClip
         },
+        {
+            id: 'shared-attachement',
+            index: 450,
+            draw: extensions.sharedAttachement
+        },
         {
             id: 'pgp-encrypted',
             index: 600,
@@ -188,9 +198,9 @@ define('io.ox/mail/listview', [
     );
 
     ext.point('io.ox/mail/listview/item/small/col6').extend({
-        id: 'date/size',
+        id: 'date',
         index: 100,
-        draw: extensions.dateOrSize
+        draw: extensions.date
     });
 
     /* default */
@@ -237,9 +247,9 @@ define('io.ox/mail/listview', [
 
     ext.point('io.ox/mail/listview/item/default/row1').extend(
         {
-            id: 'date/size',
+            id: 'date',
             index: 100,
-            draw: extensions.dateOrSize
+            draw: extensions.date
         },
         {
             id: 'from',
@@ -269,6 +279,11 @@ define('io.ox/mail/listview', [
             index: 200,
             draw: extensions.flag
         },
+        {
+            id: 'optionalSize',
+            index: 250,
+            draw: extensions.size
+        },
         {
             id: 'thread-size',
             index: 300,
@@ -279,6 +294,11 @@ define('io.ox/mail/listview', [
             index: 400,
             draw: extensions.paperClip
         },
+        {
+            id: 'shared-attachement',
+            index: 350,
+            draw: extensions.sharedAttachement
+        },
         {
             id: 'pgp-encrypted',
             index: 450,
@@ -307,6 +327,12 @@ define('io.ox/mail/listview', [
         }
     );
 
+    ext.point('io.ox/mail/listview/empty').extend({
+        id: 'default',
+        index: 100,
+        draw: extensions.empty
+    });
+
     var MailListView = ListView.extend({
 
         ref: 'io.ox/mail/listview',
@@ -417,12 +443,13 @@ define('io.ox/mail/listview', [
             }, 0);
             data.color_label = color;
             // set subject to first message in thread so a Thread has a constant subject
-            data.subject = thread[thread.length - 1].subject;
+            data.subject = api.threads.subject(data);
             // done
             return data;
         },
 
         getCompositeKey: function (model) {
+            // seems that threaded option is used for tests only
             return this.options.threaded ? 'thread.' + model.cid : model.cid;
         }
     });
