@@ -18,8 +18,9 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
     'io.ox/mail/mailfilter/settings/filter/defaults',
     'io.ox/backbone/mini-views',
     'io.ox/core/folder/picker',
-    'io.ox/backbone/mini-views/datepicker'
-], function (notifications, gt, ext, DEFAULTS, mini, picker, DatePicker) {
+    'io.ox/backbone/mini-views/datepicker',
+    'io.ox/core/folder/api'
+], function (notifications, gt, ext, DEFAULTS, mini, picker, DatePicker, folderAPI) {
 
     'use strict';
 
@@ -44,6 +45,14 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
             'regex': gt('Regex')
         },
 
+        addressValues = {
+            'user': gt('User'),
+            'detail': gt('Detail'),
+            'all': gt('All'),
+            'localpart': gt('Localpart'),
+            'domain': gt('Domain')
+        },
+
         timeValues = {
             'ge': gt('starts on'),
             'le': gt('ends on'),
@@ -61,7 +70,8 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
             'envelope': gt('Envelope - To'),
             'size': gt('Size (bytes)'),
             'body': gt('Content'),
-            'currentdate': gt('Current Date')
+            'currentdate': gt('Current Date'),
+            'address': gt('Sender address')
         },
 
         conditionsMapping = {
@@ -69,7 +79,8 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
             'envelope': ['envelope'],
             'size': ['size'],
             'body': ['body'],
-            'currentdate': ['currentdate']
+            'currentdate': ['currentdate'],
+            'address': ['address']
         },
 
         actionsTranslations = {
@@ -128,7 +139,7 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
 
         setFocus = function (el, type) {
             var listelement = $(el).find('[data-' + type + '-id]').last();
-            if (type === 'test') listelement.find('input[tabindex="1"]').first().focus();
+            if (type === 'test') listelement.find('[tabindex="1"]').first().focus();
 
             if (type === 'action') listelement.find('[tabindex="1"]').first().focus();
         },
@@ -143,10 +154,16 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
             node.append(warning);
         },
 
-        prepareFolderForDisplay = function (folder) {
-            var arrayOfParts = folder.split('/');
-            arrayOfParts.shift();
-            return arrayOfParts.join('/');
+        prepareFolderForDisplay = function (folder, input) {
+            folderAPI.get(folder).done(function (data) {
+                var arrayOfParts = folder.split('/');
+                arrayOfParts.shift();
+                if (data.standard_folder) {
+                    input.val(data.title);
+                } else {
+                    input.val(arrayOfParts.join('/'));
+                }
+            });
         },
 
         toggleSaveButton = function (footer, pane) {
@@ -175,9 +192,7 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
                 $('<ul class="dropdown-menu" role="menu">').append(
                     _(values).map(function (name, value) {
                         return $('<li>').append(
-                            $('<a>', { href: '#', 'data-action': 'change-dropdown-value', 'data-value': value, 'tabindex': '1' }).data(options).append(
-                                $.txt(name)
-                            )
+                            $('<a href="#" data-action="change-dropdown-value" tabindex="1">').attr('data-value', value).data(options).text(name)
                         );
                     })
                 )
@@ -306,9 +321,12 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
 
                 this.model.save().then(function (id) {
                     //first rule gets 0
-                    if (!_.isUndefined(id) && !_.isNull(id)) {
+                    if (!_.isUndefined(id) && !_.isNull(id) && !_.isUndefined(self.listView)) {
                         self.model.set('id', id);
                         self.listView.collection.add(self.model);
+                    } else if (!_.isUndefined(id) && !_.isNull(id) && !_.isUndefined(self.collection)) {
+                        self.model.set('id', id);
+                        self.collection.add(self.model);
                     }
                     self.dialog.close();
                 }, self.dialog.idle);
@@ -373,35 +391,25 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
             },
 
             onFolderSelect: function (e) {
-
                 e.preventDefault();
 
                 var self = this,
+                    model = $(e.currentTarget).data('model'),
                     list = $(e.currentTarget).closest('li'),
-                    actionID = list.attr('data-action-id'),
-                    inputField = list.find('input'),
-                    currentFolder =  this.model.get('actioncmds')[actionID].into,
-                    actionArray =  this.model.get('actioncmds');
+                    actionID = list.attr('data-action-id');
 
                 this.dialog.getPopup().hide();
 
                 picker({
                     context: 'filter',
                     done: function (id) {
-
-                        var prepared = prepareFolderForDisplay(id);
-
-                        actionArray[actionID].into = id;
-                        self.model.set('actioncmds', actionArray);
-
-                        inputField.val(prepared);
-                        inputField.attr('title', id);
+                        model.set('into', id);
                     },
                     close: function () {
                         self.dialog.getPopup().show();
                         self.$el.find('[data-action-id="' + actionID + '"] .folderselect').focus();
                     },
-                    folder: currentFolder,
+                    folder: model.get('into'),
                     module: 'mail',
                     root: '1'
                 });
@@ -617,7 +625,8 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
                         if (cmodel.get('datevalue')[0] === null || cmodel.get('datevalue').length === 0) conditionList.find('[data-test-id="' + num + '"] input.datepicker-day-field').closest('.row').addClass('has-error');
                         break;
                     case 'header':
-                        var title;
+                        var title,
+                            translation;
                         secondInputId = _.uniqueId('values');
 
                         inputId = _.uniqueId('headers');
@@ -627,7 +636,12 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
                         } else if (cmodel.get('headers').length === 2) {
                             title = headerTranslation.any;
                         } else {
-                            title = cmodel.get('headers')[0] === '' ? headerTranslation.cleanHeader : headerTranslation[condition.headers[0]];
+
+                            translation = _.chain(headerTranslation).pick(function (value, key) {
+                                return cmodel.get('headers')[0].toUpperCase() === key.toUpperCase();
+                            }).values().first().value();
+
+                            title = cmodel.get('headers')[0] === '' ? headerTranslation.cleanHeader : translation;
                         }
 
                         if (cmodel.get('headers')[0] === '' || title === undefined) {
@@ -671,6 +685,19 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
                             })
                         );
                         break;
+                    case 'address':
+                        inputId = _.uniqueId('values');
+                        conditionList.append(
+                            drawCondition({
+                                inputId: inputId,
+                                title: headerTranslation.address,
+                                dropdownOptions: { name: 'comparison', model: cmodel, values: filterValues(condition.id, addressValues) },
+                                inputLabel: headerTranslation.address + ' ' + addressValues[cmodel.get('comparison')],
+                                inputOptions: { name: 'values', model: cmodel, className: 'form-control', id: inputId },
+                                errorView: true
+                            })
+                        );
+                        break;
                     // no default
                 }
                 // inintial validation to disable save button
@@ -730,7 +757,7 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
                             if (/customflag_/g.test(this.id)) {
                                 this.$el.val(this.model.get('flags')[0].replace(/^\$+/, ''));
                             } else if (/move_/g.test(this.id)) {
-                                this.$el.val(prepareFolderForDisplay(this.model.get('into')));
+                                prepareFolderForDisplay(this.model.get('into'), this.$el);
                             } else {
                                 this.$el.val($.trim(this.model.get(this.name)));
                             }
@@ -792,7 +819,7 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
                             $('<div>').addClass('col-sm-8').append(
                                 $('<div>').addClass('row').append(
                                     $('<div>').addClass('col-sm-4 rightalign').append(
-                                        $('<a href="#" tabindex="1">').addClass('folderselect').text(gt('Select folder'))
+                                        $('<a href="#" class="folderselect">').text(gt('Select folder')).data({ 'model': o.inputOptions.model })
                                     ),
                                     $('<div class=" col-sm-8">').append(
                                         $('<label for="' + o.inputId + '" class="sr-only">').text(o.inputLabel),
@@ -948,13 +975,14 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
 
             var headlineTest = $('<legend>').addClass('sectiontitle expertmode conditions').text(gt('Conditions')),
                 headlineActions = $('<legend>').addClass('sectiontitle expertmode actions').text(gt('Actions')),
-                notificationConditions = $('<div>'),
-                notificationActions = $('<div>');
+                notificationConditions = $('<div class="notification-for-conditions">'),
+                notificationActions = $('<div class="notification-for-actions">');
 
             if (_.isEqual(appliedConditions[0], { id: 'true' })) {
                 renderWarningForEmptyTests(notificationConditions);
             }
 
+            //disable save button if no action is set
             if (_.isEmpty(baton.model.get('actioncmds'))) {
                 renderWarningForEmptyActions(notificationActions);
             }
@@ -1011,7 +1039,17 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
         index: 200,
         id: 'stopaction',
         draw: function (baton) {
-            var checkStopAction = function (e) {
+            var self = this,
+                toggleWarning = function () {
+                    if (baton.model.get('actioncmds').length >= 1) {
+                        self.find('.alert.alert-danger').remove();
+                    } else {
+                        self.find('.alert.alert-danger').remove();
+                        renderWarningForEmptyActions(self.find('.notification-for-actions'));
+                    }
+                    toggleSaveButton(baton.view.dialog.getFooter(), baton.view.$el);
+                },
+                checkStopAction = function (e) {
                     currentState = $(e.currentTarget).find('[type="checkbox"]').prop('checked');
                     var arrayOfActions = baton.model.get('actioncmds');
 
@@ -1032,16 +1070,18 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
                         arrayOfActions.push({ id: 'stop' });
                     }
                     baton.model.set('actioncmds', arrayOfActions);
+                    toggleWarning();
                 },
 
                 drawcheckbox = function (value) {
-                    return $('<div>').addClass('control-group mailfilter checkbox').append(
-                        $('<div>').addClass('controls'),
+                    return $('<div class="control-group mailfilter checkbox">').append(
+                        $('<div class="controls">'),
                         $('<label>').text(gt('Process subsequent rules')).prepend(
-                            $('<input type="checkbox" tabindex="1">').attr({ 'data-action': 'check-for-stop', 'checked': value })
+                            $('<input type="checkbox" data-action="check-for-stop" tabindex="1">').attr('checked', value)
                         )
                     );
                 },
+
                 target = baton.view.dialog.getFooter(),
                 arrayOfActions = baton.model.get('actioncmds');
 
@@ -1064,9 +1104,12 @@ define('io.ox/mail/mailfilter/settings/filter/view-form', [
                 return stopAction;
             }
 
-            if (!target.find('[type="checkbox"]').length) {
-                target.append(drawcheckbox(checkForStopAction(arrayOfActions)).on('change', checkStopAction));
-            }
+            toggleWarning();
+            _.defer(function () {
+                if (!target.find('[type="checkbox"]').length) {
+                    target.prepend(drawcheckbox(checkForStopAction(arrayOfActions)).on('change', checkStopAction));
+                }
+            });
 
         }
     });
