@@ -21,10 +21,11 @@ define('io.ox/portal/main', [
     'io.ox/portal/widgets',
     'io.ox/portal/util',
     'io.ox/portal/settings/pane',
+    'io.ox/portal/settings/widgetview',
     'gettext!io.ox/portal',
     'settings!io.ox/portal',
     'less!io.ox/portal/style'
-], function (ext, capabilities, userAPI, contactAPI, dialogs, widgets, util, settingsPane, gt, settings) {
+], function (ext, capabilities, userAPI, contactAPI, dialogs, widgets, util, settingsPane, WidgetSettingsView, gt, settings) {
 
     'use strict';
 
@@ -126,14 +127,11 @@ define('io.ox/portal/main', [
                     });
                     // please no button
                     $btn.find('.btn-group-portal').after($greeting);
-                    $btn.find('.btn-group-portal')
-                        .prepend($('<button type="button" class="btn btn-primary">')
-                        .attr({
-                            'data-action': 'customize',
-                            tabindex: 1
-                        })
-                        .text(gt('Customize this page'))
-                        .on('click', openSettings));
+                    $btn.find('.btn-group-portal').prepend(
+                        $('<button type="button" class="btn btn-primary" tabindex="1" data-action="customize">')
+                            .text(gt('Customize this page'))
+                            .on('click', openSettings)
+                    );
                 });
             } else {
                 $btn.append($greeting);
@@ -291,6 +289,12 @@ define('io.ox/portal/main', [
         .on('add', function (model) {
             app.drawScaffold(model, true);
             widgets.loadUsedPlugins().done(function () {
+                // See Bugs: 47816 / 47230
+                if (ox.ui.App.getCurrentApp().get('name') === 'io.ox/portal') {
+                    var widgetSettingsView = new WidgetSettingsView({ model: model, collection: model.collection });
+                    ext.point('io.ox/portal/widget/' + model.get('type') + '/settings')
+                        .invoke('edit', this, model, widgetSettingsView);
+                }
                 if (model.has('candidate') !== true) {
                     app.drawWidget(model);
                     widgets.save(appBaton.$.widgets);
@@ -324,7 +328,6 @@ define('io.ox/portal/main', [
             }
         })
         .on('sort', function () {
-            this.sort({ silent: true });
             // loop over collection for resorting DOM tree
             this.each(function (model) {
                 // just re-append all in proper order
@@ -616,7 +619,9 @@ define('io.ox/portal/main', [
     app.refresh = _.throttle(function () {
         _(widgets.getEnabled()).chain().filter(function (model) {
             // don't refresh widgets with loading errors automatically so logs don't get spammed (see bug 41740)
-            return !(model.attributes.baton && model.attributes.baton.options && model.attributes.baton.options.loadingError);
+            // also handle ignoreGlobalRefresh option (See Bug 49562)
+            var options = model.attributes.baton && model.attributes.baton.options;
+            return !options.loadingError && !model.get('ignoreGlobalRefresh');
         }).each(app.refreshWidget);
     }, 30000);
 
@@ -639,7 +644,9 @@ define('io.ox/portal/main', [
         }));
 
         win.nodes.main.addClass('io-ox-portal f6-target').attr({
-            'tabindex': '1'
+            'tabindex': '1',
+            role: 'main',
+            'aria-label': gt('Portal widgets')
         });
 
         win.setTitle(gt('Portal'));
