@@ -20,35 +20,21 @@ define('io.ox/portal/settings/pane', [
     'gettext!io.ox/portal',
     'settings!io.ox/portal',
     'io.ox/backbone/mini-views/listutils',
+    'io.ox/backbone/mini-views/settings-list-view',
     'static/3rd.party/jquery-ui.min.js',
     'less!io.ox/portal/style'
-], function (ext, manifests, WidgetSettingsView, upsell, widgets, gt, settings, listUtils) {
+], function (ext, manifests, WidgetSettingsView, upsell, widgets, gt, settings, listUtils, ListView) {
 
     'use strict';
 
     var POINT = 'io.ox/portal/settings/detail', pane;
 
     var collection = widgets.getCollection(),
-        list = $('<ol class="list-group list-unstyled widget-list">'),
         notificationId = _.uniqueId('notification_');
 
     collection
-        .on('remove', function (model) {
-            var id = model.get('id');
-            if (views[id]) {
-                views[id].remove();
-            }
+        .on('remove', function () {
             repopulateAddButton();
-        })
-        .on('add', function (model) {
-            var view = createView(model).render(),
-                lastProtected = list.find('li.protected').last();
-            if (lastProtected.length) {
-                lastProtected.after(view.el);
-            } else {
-                list.prepend(view.el);
-            }
-            view.edit();
         });
 
     ext.point(POINT).extend({
@@ -107,7 +93,7 @@ define('io.ox/portal/settings/pane', [
                 $('<ul class="dropdown-menu io-ox-portal-settings-dropdown" role="menu">').on('click', 'a:not(.io-ox-action-link)', addWidget)
             ),
             $('<div class="clearfix">'),
-            $('<div class="sr-only" role="log" aria-live="polite" aria-relevant="all">').attr('id', notificationId)
+            $('<div class="sr-only" role="log" aria-live="assertive" aria-relevant="additions text">').attr('id', notificationId)
         );
         repopulateAddButton();
         button.dropdown();
@@ -128,7 +114,7 @@ define('io.ox/portal/settings/pane', [
                         // add disabld class if requires upsell
                         .addClass(!upsell.has(options.requires) ? 'requires-upsell' : undefined)
                         .append(
-                            $('<a>', { href: '#', 'data-type': options.type, role: 'menuitem', tabindex: 1 }).text(options.title)
+                            $('<a href="#" role="menu-item" tabindex="1">').attr('data-type', options.type).text(options.title)
                         );
                 })
             );
@@ -160,14 +146,10 @@ define('io.ox/portal/settings/pane', [
         return function (activeColor, title) {
             return $('<div class="action dropdown colors">').append(
                 listUtils.appendIconText(
-                    $('<a>').attr({
-                        href: '#',
-                        role: 'button',
-                        tabindex: 1,
-                        'data-toggle': 'dropdown',
-                        'aria-haspopup': 'true',
-                        'aria-label': title + ', ' + gt('Color')
-                    }).addClass('dropdown-toggle'),
+                    $('<a href="#" role="button" tabindex="1" class="dropdown-toggle" data-toggle="dropdown" aria-haspopup="true">').attr({
+                        //#. %1$s is the title of the item, which should be colored
+                        'aria-label': gt('Color %1$s', title)
+                    }),
                     gt('Color'),
                     'color',
                     activeColor
@@ -175,7 +157,7 @@ define('io.ox/portal/settings/pane', [
                 $('<ul class="dropdown-menu" role="menu">').append(
                     _(colorNames).map(function (name, color) {
                         return $('<li>').append(
-                            $('<a>', { href: '#', 'data-action': 'change-color', 'data-color': color, 'tabindex': 1, role: 'menuitem' }).append(
+                            $('<a href="#" data-action="change-color" tabindex="1" role="menuitem">').attr('data-color', color).append(
                                 $('<span class="color-example">').addClass('color-' + color),
                                 $.txt(name)
                             )
@@ -196,67 +178,44 @@ define('io.ox/portal/settings/pane', [
         }
     });
 
-    function dragViaKeyboard(e) {
-
-        var node = $(this),
-            list = node.closest('.widget-list'),
-            items = list.children('.draggable'),
-            current = node.parent(),
-            index = items.index(current),
-            id = current.attr('data-widget-id'),
-            notification = pane.find('#' + notificationId);
-
-        function cont() {
-            widgets.save(list);
-            list.find('[data-widget-id="' + id + '"] .drag-handle').focus();
-            notification.text(gt('the item has been moved'));
-        }
-
-        switch (e.which) {
-            case 38:
-                if (index > 0) {
-                    // up
-                    e.preventDefault();
-                    current.insertBefore(current.prevAll('.draggable:first'));
-                    cont();
-                }
-                break;
-            case 40:
-                if (index < items.length) {
-                    // down
-                    e.preventDefault();
-                    current.insertAfter(current.nextAll('.draggable:first'));
-                    cont();
-                }
-                break;
-            default:
-                break;
-        }
-
-    }
-
     ext.point(POINT + '/view').extend({
         id: 'drag-handle',
         index: 200,
         draw: function (baton) {
             if (_.device('smartphone')) return;
+            var data = baton.model.toJSON();
+            // seems to be added in MW silently..
+            // a protectedWidget might be editable. If it is the "index" allow d&d for reorder
+            var protectedButDraggable = data.protectedWidget && (data.changeable && data.changeable.index);
 
+            this
+                .addClass(data.protectedWidget && !protectedButDraggable ? ' protected' : ' draggable')
+                .append(
+                    data.protectedWidget && !protectedButDraggable ? $('<div class="spacer">') :
+                    listUtils.dragHandle(gt('Drag to reorder widget'), baton.model.collection.length <= 1 ? 'hidden' : '')
+                );
+
+        }
+    });
+
+    ext.point(POINT + '/view').extend({
+        id: 'title',
+        index: 400,
+        draw: function (baton) {
             var data = baton.model.toJSON(),
                 point = ext.point(baton.view.point),
                 title = widgets.getTitle(data, point.prop('title'));
-            this
-                .addClass(data.protectedWidget && data.protectedWidget === true ? ' protected' : ' draggable')
-                .append(
-                    data.protectedWidget && data.protectedWidget === true ? $() :
-                    listUtils.dragHandle(gt('Drag to reorder widget'), title + ', ' + gt('Use cursor keys to change the item position. Virtual cursor mode has to be disabled.'), baton.model.collection.length <= 1 ? 'hidden' : '')
-                    .on('keydown', dragViaKeyboard)
-                );
+            this.append(
+                listUtils.makeTitle(title)
+                    .addClass('widget-color-' + (data.color || 'black') + ' widget-' + data.type)
+                    .removeClass('pull-left')
+            );
         }
     });
 
     ext.point(POINT + '/view').extend({
         id: 'controls',
-        index: 300,
+        index: 400,
         draw: function (baton) {
             var data = baton.model.toJSON(),
                 point = ext.point(baton.view.point),
@@ -268,7 +227,7 @@ define('io.ox/portal/settings/pane', [
                 return;
             }
 
-            var $controls = listUtils.widgetControlls(),
+            var $controls = listUtils.makeControls(),
                 $link = listUtils.controlsToggle();
 
             if (data.enabled) {
@@ -276,7 +235,7 @@ define('io.ox/portal/settings/pane', [
                 if (baton.view.options.editable) {
                     $controls.append(
                         listUtils.appendIconText(
-                            listUtils.controlsEdit(title, gt('Edit')),
+                            listUtils.controlsEdit({ 'aria-label': gt('Edit %1$s', title) }),
                             gt('Edit'),
                             'edit'
                         )
@@ -297,96 +256,65 @@ define('io.ox/portal/settings/pane', [
 
                 if (_.device('!smartphone')) {
                     $controls.append(
-                        listUtils.appendIconText($link.attr({ 'aria-label': title + ', ' + gt('Disable') }), gt('Disable'), 'disable')
+                        listUtils.appendIconText($link.attr({
+                            'aria-label': gt('Disable %1$s', title)
+                        }), gt('Disable'), 'disable')
                     );
                 }
             } else {
                 $controls.append(
-                    listUtils.appendIconText($link.attr({ 'aria-label': title + ', ' + gt('Enable') }), gt('Enable'), 'enable')
+                    listUtils.appendIconText($link.attr({
+                        'aria-label': gt('Enable %1$s', title)
+                    }), gt('Enable'), 'enable')
                 );
             }
 
             $controls.append(
-                listUtils.controlsDelete(title, gt('remove'))
+                listUtils.controlsDelete({ title: gt('Remove %1$s', title) })
             );
 
             this.append($controls);
         }
     });
 
-    ext.point(POINT + '/view').extend({
-        id: 'title',
-        index: 400,
-        draw: function (baton) {
-            var data = baton.model.toJSON(),
-                point = ext.point(baton.view.point),
-                title = widgets.getTitle(data, point.prop('title'));
-            this.append(
-                listUtils.widgetTitle(title)
-                    .addClass('widget-color-' + (data.color || 'black') + ' widget-' + data.type)
-                    .removeClass('pull-left')
-            );
-        }
-    });
-
-    var views = {};
-
-    function createView(model) {
-        var id = model.get('id'),
-            point = 'io.ox/portal/widget/' + model.get('type');
-        return (views[id] = new WidgetSettingsView({ model: model, point: point, test: 'test' }));
-    }
-
     ext.point(POINT + '/pane').extend({
         index: 300,
         id: 'list',
         draw: function () {
 
-            this.append(list.empty());
-
-            collection.each(function (model) {
-                if (model.get('protectedWidget') !== true || model.get('enabled') !== false) {
-                    list.append(createView(model).render().el);
-                }
-            });
-
-            // make sortable
-            list.sortable({
-                axis: 'y',
-                containment: list.parent(),
-                delay: 150,
-                handle: '.drag-handle',
-                cancel: 'li.protected',
-                items: '> li.draggable',
-                start: function (e, ui) {
-                    ui.item.attr('aria-grabbed', 'true');
+            this.append(new ListView({
+                collection: collection,
+                sortable: true,
+                containment: this,
+                notification: pane.find('#' + notificationId),
+                childView: WidgetSettingsView,
+                dataIdAttribute: 'data-widget-id',
+                childOptions: function (model) {
+                    return {
+                        point: 'io.ox/portal/widget/' + model.get('type')
+                    };
                 },
-                stop: function (e, ui) {
-                    ui.item.attr('aria-grabbed', 'false');
+                filter: function (model) {
+                    //TODO: some tests?
+                    var enabledIsChangeable = _.isObject(model.get('changeable')) && model.get('changeable').enabled === true,
+                        anyChangeable = _.any(model.get('changeable'), function (val) {
+                            return val === true;
+                        });
+                    //do not show protected widgets which are disabled and the disabled state can not be changed
+                    if (model.get('protectedWidget') === true && (model.get('enabled') !== true || enabledIsChangeable)) return false;
+                    //do not show protected widgets which are enabled but don't have any attribute changeable
+                    if (model.get('protectedWidget') === true && model.get('enabled') === true && !anyChangeable) return false;
+                    return true;
                 },
-                scroll: true,
                 update: function () {
                     widgets.getCollection().trigger('order-changed', 'settings');
-                    widgets.save(list);
+                    widgets.save(this.$el);
                 }
-            });
-
-            collection
-                .on('change', function () {
-                    // re-render all views
-                    _(views).each(function (view) {
-                        view.render();
-                    });
-                })
-                .on('sort', function () {
-                    this.sort({ silent: true });
-                    list.empty();
-                    this.each(function (model) {
-                        if (model.get('protectedWidget') !== true || model.get('enabled') !== false) {
-                            list.append(createView(model).render().el);
-                        }
-                    });
-                });
+            }).on('add', function (view) {
+                // See Bugs: 47816 / 47230
+                if (ox.ui.App.getCurrentApp().get('name') === 'io.ox/portal') return;
+                view.edit();
+            }).render().$el);
         }
     });
 
@@ -396,21 +324,19 @@ define('io.ox/portal/settings/pane', [
         draw: function () {
 
             var buildCheckbox = function () {
-                var checkbox = $('<input type="checkbox" tabindex="1">')
-                .on('change', function () {
-                    settings.set('mobile/summaryView', checkbox.prop('checked')).save();
-                }).addClass('input-xlarge');
-                checkbox.prop('checked', settings.get('mobile/summaryView'));
-                return checkbox;
-
+                return $('<input type="checkbox" tabindex="1" class="input-xlarge">')
+                    .prop('checked', settings.get('mobile/summaryView'))
+                    .on('change', function () {
+                        settings.set('mobile/summaryView', $(this).prop('checked')).save();
+                    });
             };
             this.append(
                 $('<fieldset>').append(
-                    $('<legend>').addClass('sectiontitle').append(
+                    $('<legend class="sectiontitle">').append(
                         $('<h2>').text(gt('Smartphone settings:'))
                     ),
-                    $('<div>').addClass('form-group').append(
-                        $('<div>').addClass('checkbox').append(
+                    $('<div class="form-group">').append(
+                        $('<div class="checkbox">').append(
                             $('<label>').text(gt('Reduce to widget summary')).prepend(
                                 buildCheckbox('showHidden')
                             )
