@@ -16,9 +16,10 @@ define('io.ox/tasks/edit/main', [
     'io.ox/core/extensions',
     'io.ox/tasks/model',
     'io.ox/tasks/edit/view',
+    'io.ox/tasks/api',
     'io.ox/core/extPatterns/dnd',
     'less!io.ox/tasks/edit/style'
-], function (gt, ext, model, view, dnd) {
+], function (gt, ext, model, view, api, dnd) {
 
     'use strict';
 
@@ -116,7 +117,7 @@ define('io.ox/tasks/edit/main', [
             win.nodes.main.addClass('scrollable');
 
             win.on('show', function () {
-                if (app.dropZone) {app.dropZone.include(); }
+                if (app.dropZone) app.dropZone.include();
                 // no autofocus on smartphone and for iOS in special (see bug #36921)
                 if (taskView && _.device('!smartphone && !iOS')) {
                     taskView.$el.find('.title-field').focus();
@@ -140,11 +141,25 @@ define('io.ox/tasks/edit/main', [
                 this.edit = true;
                 app.cid = 'io.ox/tasks:edit.' + _.cid(taskData);
 
-                model.factory.realm('edit').retain().get(taskData).done(function (task) {
-                    app.model = taskModel = task;
-                    taskModel.getParticipants();
+                // get fresh data to see if the task changed meanwhile
+                api.get({ id: taskData.id, folder_id: taskData.folder_id || taskData.folder }, false).done(function (task) {
+                    if (taskData.last_modified !== task.last_modified) {
+                        // clear cashes
+                        var key = _.cid(taskData);
+                        api.removeFromCache(key).then(function () {
+                            api.caches.all.clear();
 
-                    startApp();
+                            app.model = taskModel = model.factory.create(task);
+                            taskModel.getParticipants();
+
+                            startApp();
+                        });
+                    } else {
+                        app.model = taskModel = model.factory.create(task);
+                        taskModel.getParticipants();
+
+                        startApp();
+                    }
                 });
             } else {
                 app.attributes.title = gt('Create task');
@@ -168,7 +183,7 @@ define('io.ox/tasks/edit/main', [
                 taskView.trigger('dispose');
                 //important so no events are executed on non existing models
                 taskModel.off();
-                if (app.dropZone) {app.dropZone.remove(); }
+                if (app.dropZone) app.dropZone.remove();
                 app = win = taskModel = taskView = null;
             };
 
@@ -193,16 +208,12 @@ define('io.ox/tasks/edit/main', [
                             }
                         });
                 });
+            } else if (app.edit) {
+                clean();
+                def.resolve();
             } else {
-                if (app.edit) {
-                    clean();
-                    //old model no longer needed
-                    model.factory.realm('edit').release();
-                    def.resolve();
-                } else {
-                    clean();
-                    def.resolve();
-                }
+                clean();
+                def.resolve();
             }
 
             return def;
