@@ -27,7 +27,7 @@ define('io.ox/tasks/edit/view-template', [
     'io.ox/tasks/util',
     'io.ox/core/folder/api',
     'settings!io.ox/tasks'
-], function (gt, views, yell, mini, DatePicker, util, RecurrenceView, AddParticipant, pViews, attachments, api, ext, taskUtil, folderAPI, settings) {
+], function (gt, views, yell, mini, DatePicker, util, RecurrenceView, AddParticipantView, pViews, attachments, api, ext, taskUtil, folderAPI, settings) {
 
     'use strict';
 
@@ -52,7 +52,7 @@ define('io.ox/tasks/edit/view-template', [
                 //title
                 headline = $('<h1 class="sr-only">').text(headlineText),
                 //save button
-                saveBtn = $('<button type="button" data-action="save" class="btn btn-primary task-edit-save">')
+                saveBtn = $('<button type="button" data-action="save" class="btn btn-primary task-edit-save" tabindex="1">')
                     .text(saveBtnText)
                     .on('click', function () {
                         app.getWindow().busy();
@@ -73,7 +73,7 @@ define('io.ox/tasks/edit/view-template', [
 
                     }),
                 //cancel button
-                $('<button type="button" data-action="discard" class="btn btn-default cancel task-edit-cancel">')
+                $('<button type="button" data-action="discard" class="btn btn-default cancel task-edit-cancel" tabindex="1">')
                     .text(gt('Discard'))
                     .on('click', function (e) {
                         e.stopPropagation();
@@ -177,6 +177,16 @@ define('io.ox/tasks/edit/view-template', [
                         // trigger change to update input fields on mobile
                         baton.model.trigger('change:start_time change:end_time');
                     }
+                }).on('click:time', function () {
+                    var target = this.$el.find('.dropdown-menu.calendaredit'),
+                        container = target.scrollParent(),
+                        pos = target.offset().top - container.offset().top;
+
+                    if ((pos < 0) || (pos + target.height() > container.height())) {
+                        // scroll to Node, leave 16px offset
+                        container.scrollTop(container.scrollTop() + pos - 16);
+                    }
+
                 }).render().$el.attr('data-extension-id', 'start_time')
             );
         }
@@ -201,6 +211,16 @@ define('io.ox/tasks/edit/view-template', [
                         // trigger change to update input fields on mobile
                         baton.model.trigger('change:start_time change:end_time');
                     }
+                }).on('click:time', function () {
+                    var target = this.$el.find('.dropdown-menu.calendaredit'),
+                        container = target.scrollParent(),
+                        pos = target.offset().top - container.offset().top;
+
+                    if ((pos < 0) || (pos + target.height() > container.height())) {
+                        // scroll to Node, leave 16px offset
+                        container.scrollTop(container.scrollTop() + pos - 16);
+                    }
+
                 }).render().$el.attr('data-extension-id', 'end_time')
             );
         }
@@ -242,7 +262,7 @@ define('io.ox/tasks/edit/view-template', [
                     .append($('<option>')
                     //#. Text that is displayed in a select box for task reminders, when the user does not use a predefined time, like in 15minutes
                     .text(gt('Manual input')), taskUtil.buildDropdownMenu(),
-                    $('<option>').text('No reminder'))
+                    $('<option>').text(gt('No reminder')))
                     .on('change', function () {
                         if (selector.prop('selectedIndex') === 0) {
                             // manual input selected, change nothing
@@ -291,6 +311,16 @@ define('io.ox/tasks/edit/view-template', [
                     attribute: 'alarm',
                     label: gt('Reminder date'),
                     clearButton: true
+                }).on('click:time', function () {
+                    var target = this.$el.find('.dropdown-menu.calendaredit'),
+                        container = target.scrollParent(),
+                        pos = target.offset().top - container.offset().top;
+
+                    if ((pos < 0) || (pos + target.height() > container.height())) {
+                        // scroll to Node, leave 16px offset
+                        container.scrollTop(container.scrollTop() + pos - 16);
+                    }
+
                 }).render().$el.attr('data-extension-id', 'alarm')
             );
         }
@@ -384,16 +414,16 @@ define('io.ox/tasks/edit/view-template', [
         render: function () {
             var guid = _.uniqueId('form-control-label-'),
                 options = [
-                    { label: gt('None'), value: 'null' },
-                    { label: gt('Low'), value: 1 },
-                    { label: gt('Medium'), value: 2 },
-                    { label: gt('High'), value: 3 }
+                    { label: gt.pgettext('Tasks priority', 'None'), value: 'null' },
+                    { label: gt.pgettext('Tasks priority', 'Low'), value: 1 },
+                    { label: gt.pgettext('Tasks priority', 'Medium'), value: 2 },
+                    { label: gt.pgettext('Tasks priority', 'High'), value: 3 }
                 ];
             this.$el.append(
                 $('<label>').attr({
                     class: 'control-label',
                     for: guid
-                }).text(gt('Priority')),
+                }).text(gt.pgettext('Tasks', 'Priority')),
                 $('<div>').append(
                     new mini.SelectView({
                         list: options,
@@ -449,7 +479,7 @@ define('io.ox/tasks/edit/view-template', [
         index: 1700,
         row: '11',
         draw: function (baton) {
-            var view = new AddParticipant({
+            var view = new AddParticipantView({
                 apiOptions: {
                     contacts: true,
                     users: true,
@@ -464,6 +494,22 @@ define('io.ox/tasks/edit/view-template', [
             );
             view.render().$el.addClass('col-xs-12 collapsed');
             view.$el.find('input.add-participant').addClass('task-participant-input-field');
+
+            view.typeahead.on('typeahead-custom:dropdown-rendered', function () {
+
+                var target = view.$el.find('.tt-dropdown-menu'),
+                    container = target.scrollParent(),
+                    pos = target.offset().top - container.offset().top;
+
+                if (!target.is(':visible')) {
+                    return;
+                }
+
+                if ((pos < 0) || (pos + target.height() > container.height())) {
+                    // scroll to Node, leave 16px offset
+                    container.scrollTop(container.scrollTop() + pos - 16);
+                }
+            });
         }
     });
 
@@ -716,6 +762,40 @@ define('io.ox/tasks/edit/view-template', [
         }
     }, { row: '20' });
 
+    // metrics
+    point.extend({
+        id: 'metrics',
+        index: 3000,
+        render: function () {
+            var self = this;
+            require(['io.ox/metrics/main'], function (metrics) {
+                if (!metrics.isEnabled()) return;
+                self.baton.app.getWindow().nodes.footer.delegate('[data-action]', 'mousedown', function (e) {
+                    var node =  $(e.target);
+                    metrics.trackEvent({
+                        app: 'task',
+                        target: 'edit/toolbar',
+                        type: 'click',
+                        action: node.attr('data-action') || node.attr('data-name'),
+                        detail: node.attr('data-value')
+                    });
+                });
+                self.baton.app.getWindow().nodes.main.find('.file-input')
+                    .on('change', function track() {
+                        // metrics
+                        require(['io.ox/metrics/main'], function (metrics) {
+                            metrics.trackEvent({
+                                app: 'task',
+                                target: 'edit',
+                                type: 'click',
+                                action: 'add-attachment'
+                            });
+                        });
+                    });
+            });
+        }
+    });
+
     ext.point('io.ox/tasks/edit/dnd/actions').extend({
         id: 'attachment',
         index: 100,
