@@ -12,11 +12,11 @@
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
  */
 
-define('plugins/halo/view-detail',
-    ['plugins/halo/api',
-     'io.ox/core/extensions',
-     'less!plugins/halo/style'
-    ], function (api, ext) {
+define('plugins/halo/view-detail', [
+    'plugins/halo/api',
+    'io.ox/core/extensions',
+    'less!plugins/halo/style'
+], function (api, ext) {
 
     'use strict';
 
