@@ -42,6 +42,12 @@ define('plugins/portal/birthdays/register', [
         return cid(name, birthday) in hash;
     }
 
+    // use same code to get the date (see bug 50414)
+    function getBirthday(contact) {
+        // birthday comes along in utc, so moment.utc(t); not moment(t).utc(true)
+        return moment.utc(contact.birthday).startOf('day');
+    }
+
     ext.point('io.ox/portal/widget/birthdays').extend({
 
         title: gt('Birthdays'),
@@ -73,15 +79,16 @@ define('plugins/portal/birthdays/register', [
 
         preview: function (baton) {
 
-            var $list = $('<ul class="content list-unstyled" tabindex="1" role="button" aria-label="' + gt('Press [enter] to jump to complete list of Birthdays.') + '">'),
+            var $list = $('<ul class="content list-unstyled io-ox-portal-birthdays" tabindex="1" role="button" aria-label="' + gt('Press [enter] to jump to complete list of Birthdays.') + '">'),
                 hash = {},
                 contacts = baton.data,
                 numOfItems = _.device('smartphone') ? 5 : 15;
 
             // ignore broken birthdays
             contacts = _(contacts).filter(function (contact) {
-                // null, undefined, empty string, 0 (yep 1.1.1970).
-                return !!contact.birthday;
+                // null, undefined, empty string
+                // 0 is valid (1.1.1970)
+                return _.isNumber(contact.birthday);
             });
 
             if (contacts.length === 0) {
@@ -92,7 +99,7 @@ define('plugins/portal/birthdays/register', [
                 $list.addClass('pointer');
                 _(contacts.slice(0, numOfItems)).each(function (contact) {
                     //just to be sure hours are the same
-                    var birthday = moment(contact.birthday).utc(true).startOf('day'),
+                    var birthday = getBirthday(contact),
                         birthdayText = '',
                         //it's not really today, its today in the year of the birthday
                         today = moment().utc(true).startOf('day').year(birthday.year()),
@@ -113,6 +120,7 @@ define('plugins/portal/birthdays/register', [
                     if (!isDuplicate(name, birthday, hash)) {
                         $list.append(
                             $('<li class="line">').append(
+                                birthday.isSame(today, 'day') ? $('<span class="bold">').append('<i class="cake fa fa-birthday-cake">') : $(),
                                 $('<span class="bold">').text(name), $.txt(' '),
                                 $('<span class="accent">').text(_.noI18n(birthdayText))
                             )
@@ -149,23 +157,26 @@ define('plugins/portal/birthdays/register', [
                         )
                     );
                 }
+
                 // loop
                 _(baton.data).each(function (contact) {
-                    var birthday = moment.utc(contact.birthday).local(true),
+
+                    var birthday = getBirthday(contact),
                         // we use fullname here to avoid having duplicates like "Jon Doe" and "Doe, Jon"
-                        name = util.getFullName(contact);
+                        name = util.getFullName(contact),
+                        now = moment();
 
                     if (!isDuplicate(name, birthday, hash)) {
 
-                        var nextBirthday = moment().month(birthday.month()).date(birthday.date()),
-                            delta = nextBirthday.diff(moment(), 'day');
+                        var nextBirthday = now.clone().month(birthday.month()).date(birthday.date()),
+                            delta = nextBirthday.diff(now, 'day');
                         //avoid negative deltas to not display negative days till birthday (-300 for example)
                         //delta -1 is ok, we display this as yesterday
                         if (delta < -1) {
                             //increase Birthday by one year to be sure it's in the future and calculate again
                             //we don't just do a + 365 days here because we we don't know if it's a leapyear
                             nextBirthday.add(1, 'year');
-                            delta = nextBirthday.diff(moment(), 'day');
+                            delta = nextBirthday.diff(now, 'day');
                         }
                         /*eslint no-nested-ternary: 0*/
                         delta = delta === 0 ? gt('Today') : delta === 1 ? gt('Tomorrow') : delta === -1 ? gt('Yesterday') : gt('In %1$d days', Math.ceil(delta));
