@@ -86,8 +86,7 @@ define('plugins/portal/oxdriveclients/register', [
     }
 
     function createAppIcon() {
-        var icon = settings.get('appIconAsBase64');
-        return $('<div class="appicon">').css('background-image', icon);
+        return $('<div class="appicon">').css('background-image', settings.get('appIconAsBase64'));
     }
 
     ext.point('io.ox/portal/widget/oxdriveclients').extend({
@@ -108,13 +107,10 @@ define('plugins/portal/oxdriveclients/register', [
 
         preview: function (baton) {
             var platform = getPlatform(),
-                link = getShopLinkWithImage(platform, settings.get('linkTo/' + platform)),
-                icon = settings.get('appIconAsBase64');
+                link = getShopLinkWithImage(platform, settings.get('linkTo/' + platform));
             this.append(
                 $('<ul class="oxdrive content pointer list-unstyled">').append(
-                    $('<li class="first">').append(
-                        $('<div class="appicon">').css('background-image', icon)
-                    ),
+                    $('<li class="first">').append(createAppIcon()),
                     $('<li class="message">').append($('<h4>').text(baton.message)),
                     $('<li class="teaser">').text(baton.teaser),
                     $('<li class="link">').append(link)
