@@ -138,6 +138,7 @@ module.exports = function (grunt) {
                             // 3rd wave
                             'apps/io.ox/core/extPatterns/links.js',
                             'apps/io.ox/core/adaptiveLoader.js',
+                            'apps/io.ox/core/a11y.js',
                             'apps/io.ox/core/tk/dialogs.js',
                             'apps/io.ox/core/tk/draghelper.js',
                             // mobile stuff
@@ -281,29 +282,14 @@ module.exports = function (grunt) {
                 files: [
                     {
                         src: [
-                            'bower_components/tinymce-dist/tinymce.jquery.min.js',
+                            'bower_components/tinymce-dist/tinymce.min.js',
                             'lib/tinymce/themes/unobtanium/theme.min.js',
-                            'bower_components/tinymce-dist/plugins/{autolink,link,paste,textcolor,lists}/plugin.min.js',
+                            'bower_components/tinymce-dist/plugins/{autolink,code,link,paste,textcolor,lists}/plugin.min.js',
                             'lib/tinymce/plugins/oximage/plugin.min.js',
                             'lib/tinymce/plugins/oxpaste/plugin.min.js',
                             'lib/tinymce/plugins/oxdrop/plugin.min.js'
                         ],
-                        dest: 'build/apps/3rd.party/tinymce/tinymce.jquery.min.js',
-                        nonull: true
-                    }
-                ]
-            },
-            pdfjs: {
-                options: {
-                    banner: 'define("3rd.party/pdfjs/pdf.combined", function () {\n\n',
-                    footer: 'return PDFJS;\n});\n'
-                },
-                files: [
-                    {
-                        src: [
-                            'bower_components/pdfjs-dist/build/pdf.combined.js'
-                        ],
-                        dest: 'build/apps/3rd.party/pdfjs/pdf.combined.js',
+                        dest: 'build/apps/3rd.party/tinymce/tinymce.min.js',
                         nonull: true
                     }
                 ]
