@@ -42,7 +42,9 @@ module.exports = function (grunt) {
                     'csstransforms3d',
                     'filereader',
                     'localstorage',
-                    'websqldatabase'
+                    'websqldatabase',
+                    'websockets',
+                    'pointerevents'
                 ],
                 options: [
                     'prefixed',
