@@ -24,7 +24,7 @@
 require({
     // inject version
     baseUrl: ox.base + "/apps",
-    waitSeconds: document.cookie.indexOf("selenium=true") != -1 ? 60 : 15 //_.browser.IE ? 20 : 10
+    waitSeconds: document.cookie.indexOf("selenium=true") != -1 ? (60 * 10) : 15 //_.browser.IE ? 20 : 10
 });
 
 // jQuery AMD fix
