@@ -60,120 +60,31 @@ define(['io.ox/core/api/autocomplete'], function (api) {
             describe.skip('has some parsing functionality', function () {
                 it('should return an array for processItem', function () {
                     var args = [
-                        'contact',
-                        {
-                            'data': [{
-                                'id': 486089,
-                                'folder_id': 14830,
-                                'private_flag': false,
-                                'display_name': 'Hawthorne, Pierce',
-                                'first_name': 'Pierce',
-                                'last_name': 'Hawthorne',
-                                'title': null,
-                                'position': null,
-                                'internal_userid': 0,
-                                'email1': 'pierce.hawthorne@greendalecommunitycollege.com',
-                                'email2': null,
-                                'email3': null,
-                                'company': null,
-                                'distribution_list': null,
-                                'mark_as_distributionlist': false,
-                                'image1_url': '/ajax/image/contact/picture?folder=14830&id=486089&timestamp=1370252041765',
-                                'sort_name': 'HawthornePierce'
-                            }],
-                            'timestamp': 1370252041765
-                        }
-                    ],
+                            'contact', {
+                                'data': [{
+                                    'id': 486089,
+                                    'folder_id': 14830,
+                                    'private_flag': false,
+                                    'display_name': 'Hawthorne, Pierce',
+                                    'first_name': 'Pierce',
+                                    'last_name': 'Hawthorne',
+                                    'title': null,
+                                    'position': null,
+                                    'internal_userid': 0,
+                                    'email1': 'pierce.hawthorne@greendalecommunitycollege.com',
+                                    'email2': null,
+                                    'email3': null,
+                                    'company': null,
+                                    'distribution_list': null,
+                                    'mark_as_distributionlist': false,
+                                    'image1_url': '/ajax/image/contact/picture?folder=14830&id=486089&timestamp=1370252041765',
+                                    'sort_name': 'HawthornePierce'
+                                }],
+                                'timestamp': 1370252041765
+                            }
+                        ],
 
-                    result = [{
-                        'data': {
-                            'id': 486089,
-                            'folder_id': 14830,
-                            'private_flag': false,
-                            'display_name': 'Hawthorne, Pierce',
-                            'first_name': 'Pierce',
-                            'last_name': 'Hawthorne',
-                            'title': null,
-                            'position': null,
-                            'internal_userid': 0,
-                            'email1': 'pierce.hawthorne@greendalecommunitycollege.com',
-                            'email2': null,
-                            'email3': null,
-                            'company': null,
-                            'distribution_list': null,
-                            'mark_as_distributionlist': false,
-                            'image1_url': '/ajax/image/contact/picture?folder=14830&id=486089&timestamp=1370252041765',
-                            'sort_name': 'HawthornePierce'
-                        },
-                        'type': 'contact'
-                    }];
-                    expect(instance.processItem.apply(this, args)).to.deep.equal(result);
-                });
-                it('should return an array for processContactResults', function () {
-                    var args = [
-                        'contact',
-                        [{
-                            'data': {
-                                'id': 486089,
-                                'folder_id': 14830,
-                                'private_flag': false,
-                                'display_name': 'Hawthorne, Pierce',
-                                'first_name': 'Pierce',
-                                'last_name': 'Hawthorne',
-                                'title': null,
-                                'position': null,
-                                'internal_userid': 0,
-                                'email1': 'pierce.hawthorne@greendalecommunitycollege.com',
-                                'email2': null,
-                                'email3': null,
-                                'company': null,
-                                'distribution_list': null,
-                                'mark_as_distributionlist': false,
-                                'image1_url': '/ajax/image/contact/picture?folder=14830&id=486089&timestamp=1370252041765',
-                                'sort_name': 'HawthornePierce'
-                            },
-                            'type': 'contact'
-                        }],
-                        'hawthorn',
-                        {
-                            'emailAutoComplete': false
-                        }
-                    ],
-
-                    result = [{
-                        'type': 'contact',
-                        'first_name': 'Pierce',
-                        'last_name': 'Hawthorne',
-                        'display_name': 'Pierce Hawthorne',
-                        'data': {
-                            'id': 486089,
-                            'folder_id': 14830,
-                            'private_flag': false,
-                            'display_name': 'Hawthorne, Pierce',
-                            'first_name': 'Pierce',
-                            'last_name': 'Hawthorne',
-                            'title': null,
-                            'position': null,
-                            'internal_userid': 0,
-                            'email1': 'pierce.hawthorne@greendalecommunitycollege.com',
-                            'email2': null,
-                            'email3': null,
-                            'company': null,
-                            'distribution_list': null,
-                            'mark_as_distributionlist': false,
-                            'image1_url': '/ajax/image/contact/picture?folder=14830&id=486089&timestamp=1370252041765',
-                            'sort_name': 'HawthornePierce'
-                        },
-                        'field': 'email1',
-                        'email': 'pierce.hawthorne@greendalecommunitycollege.com',
-                        'phone': ''
-                    }];
-                    expect(instance.processContactResults(args[0], args[1], args[2], args[3])).to.deep.equal(result);
-                });
-                it('should add elements to submitted array', function () {
-                    var args = [
-                            'contact',
-                            [],
+                        result = [
                             {
                                 'data': {
                                     'id': 486089,
@@ -195,14 +106,99 @@ define(['io.ox/core/api/autocomplete'], function (api) {
                                     'sort_name': 'HawthornePierce'
                                 },
                                 'type': 'contact'
-                            },
-                            'email',
-                            [
-                                'email1',
-                                'email2',
-                                'email3'
-                            ]
+                            }
+                        ];
+                    expect(instance.processItem.apply(this, args)).to.deep.equal(result);
+                });
+                it('should return an array for processContactResults', function () {
+                    var args = [
+                            'contact',
+                            [{
+                                'data': {
+                                    'id': 486089,
+                                    'folder_id': 14830,
+                                    'private_flag': false,
+                                    'display_name': 'Hawthorne, Pierce',
+                                    'first_name': 'Pierce',
+                                    'last_name': 'Hawthorne',
+                                    'title': null,
+                                    'position': null,
+                                    'internal_userid': 0,
+                                    'email1': 'pierce.hawthorne@greendalecommunitycollege.com',
+                                    'email2': null,
+                                    'email3': null,
+                                    'company': null,
+                                    'distribution_list': null,
+                                    'mark_as_distributionlist': false,
+                                    'image1_url': '/ajax/image/contact/picture?folder=14830&id=486089&timestamp=1370252041765',
+                                    'sort_name': 'HawthornePierce'
+                                },
+                                'type': 'contact'
+                            }],
+                            'hawthorn', {
+                                'emailAutoComplete': false
+                            }
                         ],
+
+                        result = [{
+                            'type': 'contact',
+                            'first_name': 'Pierce',
+                            'last_name': 'Hawthorne',
+                            'display_name': 'Pierce Hawthorne',
+                            'data': {
+                                'id': 486089,
+                                'folder_id': 14830,
+                                'private_flag': false,
+                                'display_name': 'Hawthorne, Pierce',
+                                'first_name': 'Pierce',
+                                'last_name': 'Hawthorne',
+                                'title': null,
+                                'position': null,
+                                'internal_userid': 0,
+                                'email1': 'pierce.hawthorne@greendalecommunitycollege.com',
+                                'email2': null,
+                                'email3': null,
+                                'company': null,
+                                'distribution_list': null,
+                                'mark_as_distributionlist': false,
+                                'image1_url': '/ajax/image/contact/picture?folder=14830&id=486089&timestamp=1370252041765',
+                                'sort_name': 'HawthornePierce'
+                            },
+                            'field': 'email1',
+                            'email': 'pierce.hawthorne@greendalecommunitycollege.com',
+                            'phone': ''
+                        }];
+                    expect(instance.processContactResults(args[0], args[1], args[2], args[3])).to.deep.equal(result);
+                });
+                it('should add elements to submitted array', function () {
+                    var args = ['contact', [], {
+                            'data': {
+                                'id': 486089,
+                                'folder_id': 14830,
+                                'private_flag': false,
+                                'display_name': 'Hawthorne, Pierce',
+                                'first_name': 'Pierce',
+                                'last_name': 'Hawthorne',
+                                'title': null,
+                                'position': null,
+                                'internal_userid': 0,
+                                'email1': 'pierce.hawthorne@greendalecommunitycollege.com',
+                                'email2': null,
+                                'email3': null,
+                                'company': null,
+                                'distribution_list': null,
+                                'mark_as_distributionlist': false,
+                                'image1_url': '/ajax/image/contact/picture?folder=14830&id=486089&timestamp=1370252041765',
+                                'sort_name': 'HawthornePierce'
+                            },
+                            'type': 'contact'
+                        },
+                        'email', [
+                            'email1',
+                            'email2',
+                            'email3'
+                        ]
+                    ],
                         //expected result
                         result = [{
                             'type':  'contact',
