@@ -14,6 +14,11 @@
 
  /* global DocumentTouch */
 
+/**
+ * This lib is dependency free, do not use underscore or some
+ * other lib here
+ */
+
 (function () {
 
     var us = {},
@@ -51,6 +56,17 @@
         return true;
     }
 
+    function memoize(func, hasher) {
+        var memoize = function (key) {
+            var cache = memoize.cache;
+            var address = '' + (hasher ? hasher.apply(this, arguments) : key);
+            if (!_.has(cache, address)) cache[address] = func.apply(this, arguments);
+            return cache[address];
+        };
+        memoize.cache = {};
+        return memoize;
+    }
+
     function detectBrowser(nav) {
         var error = false;
         try {
@@ -168,15 +184,15 @@
     // first detection
     detectBrowser(navigator);
 
-    function detectTouch() {
-
+    var detectTouch = memoize(function () {
         // Windows 8 Chrome does report touch events which leads to
         // a wrong feature set (disabled stuff) as AppSuite thinks
         // this is a Smartphone or tablet without a mouse.
         if (us.browser.chrome && us.browser.windows8) return false;
-
+        // don't report desktop browsers with pointerevent to be touch devices
+        if ('onpointerdown' in window && !us.browser.android && !us.browser.ios) return false;
         return ('ontouchstart' in window) || window.DocumentTouch && document instanceof DocumentTouch;
-    }
+    });
 
     // do media queries here
     // TODO define sizes to match pads and phones
@@ -219,6 +235,8 @@
     // define devices as combination of screensize and OS
     display.smartphone = isSmartphone();
     display.tablet = display.medium && mobileOS; // maybe to fuzzy...
+    // as there is no android desktop yet, this must be a tablet
+    if (us.browser.android && display.large) display.tablet = true;
     display.desktop = !mobileOS;
     us.displayInfo = display;
     // extend underscore utilities
@@ -255,7 +273,7 @@
         },
 
         // combination of browser & display
-        device: function (condition, debug) {
+        device: _.memoize(function (condition, debug) {
             // add support for language checks
             var misc = {}, lang = (ox.language || 'en_US').toLowerCase();
             misc[lang] = true;
@@ -284,7 +302,7 @@
                 console.error('_.device()', condition, e);
                 return false;
             }
-        }
+        })
     };
     underscoreExtends.device.loadUA = function (nav) {
         detectBrowser(nav);
