@@ -34,7 +34,7 @@
 
     function runCode(name, code) {
         /*eslint no-eval: 0*/
-        eval('//@ sourceURL=' + name + '.js\n' + code);
+        eval('//# sourceURL=' + name + '.js\n' + code);
     }
 
     // needs to be reviewed: "force websql for mobile" (July 2013)
@@ -465,6 +465,21 @@
                                 }
                             })();
                         });
+                    }).fail(function loadingFailed() {
+                        var modules = module.split(',');
+                        if (modules.length > 1) {
+                            console.warn('Problem loading concatenated modules, falling back to separate file loading');
+                            modules.forEach(function (m) {
+                                var name = m.replace(/\.js$/, '');
+                                load(m, name);
+                            });
+                        } else {
+                            runCode([ox.apiRoot, '/apps/load/', ox.version, ',', module].join(''),
+                                'define("' + modulename + '", function () { console.error("Could not load module ' +
+                                    modulename + '. Defining dummy module.");})'
+                            );
+                            context.completeLoad(modulename);
+                        }
                     });
             }
         };
@@ -540,9 +555,9 @@
                     icon120: 'icon120.png',
                     icon144: 'icon144.png',
                     icon152: 'icon152.png',
-                    splash460: 'splashscreen_460.jpg',
-                    splash920: 'splashscreen_920.jpg',
-                    splash1096: 'splashscreen_1096.jpg',
+                    icon167: 'icon167.png',
+                    icon180: 'icon180.png',
+                    icon192: 'icon192.png',
                     win8Icon: 'icon144_win.png'
                 };
             for (var i in icons) {
@@ -606,7 +621,7 @@
                 var f2 = function () { return f.apply(this, arguments); };
                 // _.each by foot to avoid capturing members of f in closures
                 var f3 = function (i) {
-                    f2[i] = function () { f[i].apply(f, arguments); };
+                    f2[i] = function () { return f[i].apply(f, arguments); };
                 };
                 for (var i in f) {
                     f3(i);
